/* $Workfile: A66HwBasic.h $       $Revision: 9 $      $Modtime: 2/27/06 1:42p $  */
/*******************************************************************************

  Odin TeleSystems Inc.

  OTX Telecom Adapter Driver

  @doc PublicDemo

  @module

    A66HwBasic.h

    A basic example console application demonstrating the use of OTX Driver
    with the Arni-6x6-PCI or the Arni-6x6-PCI board.

    The sample application configures 6 FXO POTS Line Interfaces and FXS line.
    The application provides a simple console interface to manage the POTS 
    Line Interface (LI) devices.
   
    The user can use the following simple keystrokes as commands to go 
    off-hook and on-hook, to dial numbers, etc.

    In this basic demo the FXO POTS LIs are supposed to be connected to a  
    telephone line or a telephone line simulator.
    
    The main command keys are listed in the following:
     - Press 'h' or '?' for help. 'q' to quit.
     

*******************************************************************************/
#ifndef A66_HW_BASIC_h
#define A66_HW_BASIC_h


#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdarg.h>
#include <OtxErr.h>
#include <OtxDrv.h>
#include <OtxDataD.h>
#include <OtxCstD.h>

#define DEMO_DSP_MAX 6   // Number of FXO interfaces used
#define DEMO_FXO_MAX DEMO_DSP_MAX   // Number of FX0 interfaces used
#define DEMO_FXS_MAX 0   // Number of FXS interfaces used
#define DEMO_LI_MAX  6   // Number of POTS lines supported by hardware

#define DEMO_TASK_REF  1000L // Base Task Reference ID for a non-blocking call
#define DEMO_DEFAULT_LOG_FILE  "A66HwBasic.log"     // Name of the LOG file
#define DEMO_DEFAULT_BOARD_NO  0
#define DEMO_DSP_FIRST 0 // Eval boards DSP0 & 1 are not known bad for Rev 1.0
#define DEMO_DEFAULT_FXO_NO    DEMO_DSP_FIRST
#define DEMO_MAX_CALLER_ID_STRING  40
#define DEMO_MAX_DTMF_STRING       40

// It is expected that the user will need to perform some
// additional processing of the following events. The user 
// could modify the source code as well in A66HwBasic.c.

#define DEMO_STATE_OFFSET 0
// Call states for device FXO and FXS interfaces
enum DemoDeviceCallState { 
  DEMO_CALL_START_OF_STATES        = DEMO_STATE_OFFSET + 0,
  DEMO_STATE_CHANGE                = DEMO_STATE_OFFSET + 1,
  DEMO_INITIALIZING                = DEMO_STATE_OFFSET + 2,
  DEMO_MAKE_BUSY                   = DEMO_STATE_OFFSET + 3, 
  DEMO_MAKE_RING_BACK              = DEMO_STATE_OFFSET + 4,
  DEMO_MAKE_REORDER                = DEMO_STATE_OFFSET + 5, 
  DEMO_MAKE_CONGESTION             = DEMO_STATE_OFFSET + 6,
  DEMO_MAKE_OFFHOOK                = DEMO_STATE_OFFSET + 7,
  DEMO_MAKE_ONHOOK                 = DEMO_STATE_OFFSET + 8,
  DEMO_ONHOOK                      = DEMO_STATE_OFFSET + 9,
  DEMO_OFFHOOK                     = DEMO_STATE_OFFSET + 10,
  DEMO_FLASHHOOK                   = DEMO_STATE_OFFSET + 11,
  DEMO_DIGIT_AVAILABLE             = DEMO_STATE_OFFSET + 12,
  DEMO_LOOP_TRANSITION             = DEMO_STATE_OFFSET + 13, 
  DEMO_CALLER_ID                   = DEMO_STATE_OFFSET + 14,
  DEMO_MAKE_RINGING                = DEMO_STATE_OFFSET + 15,
  DEMO_RINGING                     = DEMO_STATE_OFFSET + 16,
  DEMO_STOP_RINGING                = DEMO_STATE_OFFSET + 17,
  DEMO_SEND_DTMF                   = DEMO_STATE_OFFSET + 18,
  DEMO_DTMF_TRANISTION             = DEMO_STATE_OFFSET + 19,
  DEMO_LI_INIT_COMPLETE            = DEMO_STATE_OFFSET + 20,
  DEMO_FAR_END_HANGUP              = DEMO_STATE_OFFSET + 21,
  DEMO_TONE_DETECTED               = DEMO_STATE_OFFSET + 22,
  DEMO_EVENT_ERROR                 = DEMO_STATE_OFFSET + 23,
  DEMO_DIGIT_START_AVAILABLE       = DEMO_STATE_OFFSET + 24,
  DEMO_NO_ACTION_NEEDED            = DEMO_STATE_OFFSET + 25,
  DEMO_CALL_END_OF_STATES          = DEMO_STATE_OFFSET + 26
};
typedef enum DemoDeviceCallState DemoDeviceCallState;


// Call states for device FXO and FXS interface
extern char *g_sqszDeviceCallState[];


enum DemoDevicePotsType{
  DEMO_FXO_POTS_TYPE,
  DEMO_FXS_POTS_TYPE,
  DEMO_BURST_DATA_TYPE,
  DEMO_ILLIGAL_POTS_TYPE
};

/*
** The following structure allows the user to change the
** default settings for the driver application. The normal
** OTX demo application would be passed these setting as 
** part ot the command line arguments. 
**
** Supported Voice Compression Codec:
**   OTX_DATA_FORMAT_COMPAND8_A_LAW or OTX_DATA_FORMAT_COMPAND8_U_LAW
** 
** Country specific setting:
**   OTX_CST_POTS_CFG_SET_USA 
**   OTX_CST_POTS_CFG_SET_GERMANY
**   OTX_CST_POTS_CFG_SET_UK
**   OTX_CST_POTS_CFG_SET_FRANCE
**   OTX_CST_POTS_CFG_SET_AUSTRALIA
**   OTX_CST_POTS_CFG_SET_JAPAN        
*/
struct DemoEnvT {
  char                   *pszInputStr; // Not needed in C++ application
  OTX_BOOL               bExitOnError; // Not needed in C++ application
  OTX_BOOL               bContinueOnError; // Not needed in C++ application
  char                   *logFileName; // Log file name
  char                   *outFileName; // DSP Load file (for debugging)
  int                    boardNo;      // Board number (for multiple boards)
  int                    fxoStartNo;   // First FXO number to configure
  int                    fxoMaxNo;     // Total number of FXO Li to configure
  int                    fxsMaxNo;     // Total number of FXS Li to configure
  OtxPhysicalDeviceTypeE nBoardType;   // Board Type used
  OtxDataFormatE         law;          // Voice Compression Codec
  OtxCstPotsCfgSetE      nSetId;       // Country specific setting
};


// This type specifies events that objects will send.
enum DemoHwEvent
{
  HwEvent_unused = 0,

  // Incoming call event
  HwEvent_ring,

  // Incoming call connected
  HwEvent_connect,

  // Call disconnected
  HwEvent_disconnect,

  // DTMF digit is available 
  HwEvent_digit_avail,

  // Error of some sort
  HwEvent_error,

  // Channel initialization is completed
  HwEvent_init_completed,

  // Data buffer arrived
  HwEvent_buffer_arrived,

  // Playing of the DTMF tone is completed
  HwEvent_ptone_completed,

  // Ring Tone detected
  HwEvent_ring_tone,

  // busy Tone detected
  HwEvent_busy_tone,

  // Other end is now active
  HwEvent_call_answer
};     

#ifdef __cplusplus
#define DEMO_EXTERN extern "C"
#else
typedef struct DemoEnvT DemoEnvT;
typedef enum DemoHwEvent DemoHwEvent;
typedef enum DemoDevicePotsType DemoDevicePotsType;

#define DEMO_EXTERN extern
#endif



/*******************************************************************************
 Exported Function Prototypes
*******************************************************************************/
DEMO_EXTERN OTX_RESULT DemoExampleUserFunction( void );  

DEMO_EXTERN OTX_RESULT DemoInitializeDebugConsole( void );  

DEMO_EXTERN OTX_RESULT DemoInitializeEventHandler(
              OTX_UINT32 potsLiNumber,
              void *hwBase, 
              void (*EventHandler)(void *, void *, void *, void *)); 

DEMO_EXTERN OTX_RESULT DemoConfigureHardware( struct DemoEnvT *DemoSetup,
                                              void (*LogUtility)(char *formatStr, va_list argList) );   

DEMO_EXTERN OTX_RESULT DemoInitialize( void );

DEMO_EXTERN OTX_RESULT DemoAppExit( void );  

DEMO_EXTERN OTX_RESULT DemoProcessDrvEvent( DemoDeviceCallState DemoEventCode,        
                                       DemoDevicePotsType potsType, 
                                       OTX_UINT32 potsLiNumber, 
                                       OtxEventDataS *pEventData );

DEMO_EXTERN OTX_RESULT DemoProcessFxsEvent( DemoDeviceCallState DemoEventCode,        
                                       DemoDevicePotsType potsType, 
                                       OTX_UINT32 potsLiNumber,
                                       OtxEventDataS *pEventData ); 

DEMO_EXTERN OTX_RESULT DemoProcessFxoEvent( DemoDeviceCallState DemoEventCode,        
                                       DemoDevicePotsType potsType, 
                                       OTX_UINT32 potsLiNumber,
                                       OtxEventDataS *pEventData);  

DEMO_EXTERN OTX_RESULT DemoFxoGetLiState( OTX_UINT32 potsLiNumber,
                                     DemoDeviceCallState *nLiState,
                                     OTX_RESULT *lastRecordedError );
 
DEMO_EXTERN OTX_RESULT DemoFxoIsLiOffHook( OTX_UINT32 potsLiNumber,
                                           OTX_BOOL *nLiOffHook,
                                           OTX_RESULT *lastRecordedError ); 

DEMO_EXTERN OTX_RESULT DemoFxoAnswerCall( OTX_UINT32 potsLiNumber,
                                     DemoDeviceCallState *nLiState );  

DEMO_EXTERN OTX_RESULT DemoFxoTerminateCall( OTX_UINT32 potsLiNumber,
                                        DemoDeviceCallState *nLiState );  

DEMO_EXTERN OTX_RESULT DemoFxoMakeCall( OTX_UINT32 potsLiNumber,
                                   DemoDeviceCallState *nLiState, 
                                   char *strDtmfDigits );  

DEMO_EXTERN OTX_RESULT DemoFxoRejectCall( OTX_UINT32 potsLiNumber,
                                     DemoDeviceCallState *nLiState );  

DEMO_EXTERN OTX_RESULT DemoFxoSendDtmfDigits( OTX_UINT32 potsLiNumber,
                                         DemoDeviceCallState *nLiState,  
                                         char *strDtmfDigits );  

DEMO_EXTERN OTX_RESULT DemoFxoGetDataBlock( OTX_UINT32 potsLiNumber,
                                       DemoDeviceCallState *nLiState ); 

DEMO_EXTERN OTX_RESULT DemoFxoSetupBurstSendReceive(char *pRecvFile, 
                                                    char *pSendFile,
                                                    OTX_INT32 nTsToRecord,
                                                    OTX_INT32 nTsToSend);

DEMO_EXTERN OTX_RESULT DemoFxoGetCallerId(OTX_UINT32 potsLiNumber, 
                                          DemoDeviceCallState *nLiState,
                                          char *strCallerId);

DEMO_EXTERN OTX_RESULT DemoFxoHaltBurstSendReceive(void);

DEMO_EXTERN OTX_BOOL DemoIsBurstDeviceEnabled(void);


#ifdef __cplusplus
}
#endif

#endif
/* End of A66_HW_BASIC_h header file */

