/* $Workfile: A66HwBasic.c $       $Revision: 12 $      $Modtime: 2/27/06 5:43p $  */
/*******************************************************************************

  Odin TeleSystems Inc.

  OTX Telecom Adapter Driver

  @doc PublicDemo

  @module

    A66HwBasic.c

    A basic example console application demonstrating the use of OTX Driver
    with the Arni-6x6-PCI board.

    The sample application configures 6 FXO POTS Line Interfaces and 6 FXS line.
    The application provides a simple console interface to manage the POTS 
    Line Interface (LI) devices.
   
    The user can use the following keystrokes as commands to go 
    off-hook and on-hook, to dial numbers, etc.

    In this basic demo the FXO POTS LIs are supposed to be connected to a  
    telephone line or a telephone line simulator. It does not use any of 
    EX function that allow the user to modify the CPT, VAD, or voice mixer.
    It currently only support the u-law and A-law Voice Compression Codec.
    The linear 16 bit data option is not available with this demo.
    
    The main command keys are listed in the following:
     - Press 'h' or '?' for help. 'q' to quit.
     

*******************************************************************************/

#include <windows.h>
#include <process.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include <time.h>
#include <assert.h>

#include "OsaStd.h"
#include "OsaCon.h"
#include "OsaThrd.h"
#include "OtxErr.h"
#include "OtxType.h"
#include "OtxDrv.h"
#include "OtxBrd.h"
#include "OtxCst.h"
#include "OtxDsp.h"
#include "OtxBurst.h"
#include "OtxBurstD.h"
#include "OtxSlic.h"

#include "A66HwBasic.h"

#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
  Macros, Types
*******************************************************************************/
#define DEMO_NO_LI_CONNECTED    0xFF

#define DEMO_BURST_BUF_SIZE     0x8000    // 32k

#define DEMO_U_LAW_SILENCE 0xFF // Sending this byte produces silence in u-law 
#define DEMO_A_LAW_SILENCE 0xD5 // Sending this byte produces silence in a-law 

#define DEMO_HWY_DSP0   0
#define DEMO_HWY_DSP1   1
#define DEMO_HWY_DSP2   2
#define DEMO_HWY_DSP3   3
#define DEMO_HWY_DSP4   4
#define DEMO_HWY_DSP5   5
#define DEMO_HWY_FXS    6 // All 6 SLIC devices are connected to highway 6
#define DEMO_HWY_BURST  8

#define DEMO_ANSWER_WAIT_TIME 65L
#define DEMO_RETRY_COUNT 25     // Number of times to retry sending I/O command
#define DEMO_LOOP_DONE   (DEMO_RETRY_COUNT * 2)    // used to exit retry loop

#define VOICE_MIXER0 1 // 1=Voice mixer connected to voice path on init
                       // 0=DTMF dialer only connected to voice path on init

#define DEMO_DBG_LEVEL_ALL -1 // Enable all debug prints
#define DEMO_DBG_LEVEL_0    0 // Enable most debug prints
#define DEMO_DBG_LEVEL_1    1 // Enable only level one (less debug message)
#define DEMO_DBG_LEVEL_2    2 // Enable only level two (Almost no extra debug messages)

// Demo timeslot (TS) definition.
// The TS below were configured for u-law and A-law which only needs
// a single TS. If 16 bit data is needed the following TS will need 
// to be modified to allow two TS per connection.
// The following table is used to assign each connection the base TS.
#define DEMO_TS_DSP_POTS_LI_TX         2   // Input
#define DEMO_TS_DSP_DTMF_DETECTOR     23   // Input
#define DEMO_TS_DSP_CPT               24   // Input
#define DEMO_TS_DSP_VAD               25   // Input
#define DEMO_TS_DSP_CID               27   // Input
#define DEMO_TS_DSP_EC_INPUT_NE       28   // Input EC(0) Near end
#define DEMO_TS_DSP_EC_INPUT_FE       29   // Input EC(1) Far end
#define DEMO_TS_DSP_VOICE_MIX_INPUT0  20   // Input  
#define DEMO_TS_DSP_VOICE_MIX_INPUT1  21   // Input  
#define DEMO_TS_DSP_VOICE_MIX_INPUT2  22   // Input  
#define DEMO_TS_DSP_POTS_LI_RX         0   // Output
#define DEMO_TS_DSP_VOICE_MIX_OUTPUT   1   // Output
#define DEMO_TS_DSP_EC_OUTPUT         10   // Output Echo Cancel
#define DEMO_TS_DSP_DTMF_DIALER       20   // Output  
/*
**  Debug connection for burst Li(n) TSn-->FXO(n), TS(n+6)-->FXS(n)
**  Setup the burst device on all FXO and FXS line input sides.
**      Burst Input time slot.
**      0-->FXO(0)     6-->FXS(0)
**      1-->FXO(1)     7-->FXS(1)
**      2-->FXO(2)     8-->FXS(2)
**      3-->FXO(3)     9-->FXS(3)
**      4-->FXO(4)    10-->FXS(4)
**      5-->FXO(5)    11-->FXS(5)
*/


/*******************************************************************************
 Function Prototypes
*******************************************************************************/
static OTX_BOOL DemoSetup64kPipeOneEnd(OTX_HANDLE hPipe, 
                                       OTX_HANDLE hDevice, 
                                       OTX_UINT32 nHighway, 
                                       OTX_UINT32 nTs, 
                                       OtxPipeEndE nInOut);   
static void DemoCreateEventQueue(OTX_EVENT *hEvent, OTX_HANDLE *hEventQueue);
static void DemoOpenPhysicalDevices(void);
static void DemoEnablePhysicalDevices(void);
static void DemoCreateLogicalDevices(void);
static void DemoConnectDevices(void);
static OTX_RESULT DemoConnectFxoToFxsDevices(OTX_INT32 potsLi);
static OTX_RESULT DemoConnectFxsVoicePath(OTX_INT32 potsLi);
static OTX_RESULT DemoConnectFxsDtmfDialer(OTX_INT32 potsLi);
static void DemoInitializeLogicalDevices(void);
static void DemoEnableLogicalDevices(void);
static void DemoPrintEvent(IN OtxEventDataS *pEventData);
static void DemoExitQuestion(void);
static void DemoPrintTimeStamp(OTX_DATETIME nTimeStamp);
static void  *DemoLineSensingFunction(void *lpParameter);
static char DemoDtmfParamToChar(int nParam);
static void DemoCheckRc(IN OTX_HANDLE hDevice, IN OTX_RESULT otxRc);
static void DemoGetLastFailure(OTX_RESULT *result);
static OTX_INT32 DemoProcessUserCommand(char commandChar);
static OTX_INT32 DemoSlicReceiveConfigMenu(char commandChar);
static void DemoParseCmdLineArgs(int argc, char *argv[], DemoEnvT *envP);
static void DemoHelpPanel(void);
static void DemoLogf(char *formatStr, ...);
static int DemoExit(int nExitCode);
static void DemoFxoStateMachine(OTX_UINT32 deviceNumber);
static void DemoSetState(DemoDeviceCallState newState, 
                         OTX_UINT32 deviceNumber, 
                         DemoDevicePotsType potsType,
                         DemoDeviceCallState checkState);

/*******************************************************************************
 Global Data
*******************************************************************************/
OTX_EVENT   g_hNotificationEvent = OTX_INVALID_EVENT_VALUE;
OTX_HANDLE  g_hEventQueue        = OTX_INVALID_HANDLE_VALUE;
DemoEnvT    g_demoEnv;
FILE       *g_pDemoLogFile       = NULL;
FILE       *g_fStreamFile        = NULL;
OTX_BOOL    g_nContinuousAnswer  = OTX_FALSE; // Not running
OTX_BOOL    g_nContinuousCalling = OTX_FALSE; // Not running
OTX_BOOL    g_bWatchDogThreadActive = OTX_FALSE;
OTX_BOOL    g_bConsoleEnabled = OTX_FALSE;   // Start with consol disabled
OTX_BOOL    g_bLineSensingThreadActive = OTX_FALSE;
OTX_BOOL    g_bLineSensePending[DEMO_LI_MAX];
OTX_UINT32  g_liConNumber_1 = DEMO_NO_LI_CONNECTED;
OTX_UINT32  g_liConTimeSlot = 0;
OTX_UINT32  g_firstUsableLi = DEMO_DSP_FIRST;
OTX_INT32   g_fxsLiInitialized = DEMO_FXS_MAX;
OTX_INT32   g_fxoLiInitialized = DEMO_FXO_MAX;
OTX_UINT32  g_nDmaEventCnt = 0;
OTX_UINT32  g_nCmdTimeoutCnt = 0; // Keep track of total number of timeouts
OTX_INT32   g_nDbgSetting = DEMO_DBG_LEVEL_1; // Turn off extra debug messages
DemoHwEvent g_nFxoTaskCallEvent[DEMO_LI_MAX];
OTX_UINT8   g_rawDigit;
OTX_RESULT  g_nDemoAppResultCode = OTX_S_OK; // Start with good status
void (*g_fLogUtility)(char *formatStr, ...) = NULL; // log utility function

char g_szCallerId[DEMO_LI_MAX][DEMO_MAX_CALLER_ID_STRING];

char g_nDefaultParms[] = "DEFAULT FXO";
char g_DtmfPhoneStr[32] = "201";
char g_pRecvFile[OTX_MAX_PATH] = "tstData.dat"; // used by DemoFxoCalling task
char g_pSendFile[OTX_MAX_PATH] = "hwBasic.snd"; // used by DemoFxoCalling task
char g_pLogFile[OTX_MAX_PATH]  = DEMO_DEFAULT_LOG_FILE; // used for degug

static OsaMutexS g_demoLogfCritSec;

struct {
  OTX_HANDLE hHandle;
  OTX_INT32 busyCount;  // Should always be zero in this app

  OTX_INT32  nFxo;
  OTX_INT32  nFxs;
  OTX_INT32  nDsp;
} g_sqPotsLiTask[DEMO_LI_MAX];


struct {  // Handles to Physical Devices
  OTX_HANDLE hBoardController0;
  OTX_HANDLE hDsp[DEMO_LI_MAX];
  OTX_HANDLE hSlicLi[DEMO_LI_MAX];
  OTX_HANDLE hBurst;
  OTX_HANDLE hTss;
} g_hPhysDevs;


// direct Burst DMA send
struct sBurstSender {
  OTX_UINT32  nSourceId;
  OTX_BOOL    bVerbose;
  OTX_BOOL    bActive;
  OTX_UINT8   sqTxBuf[DEMO_BURST_BUF_SIZE];
  FILE        *pTxFile;
  OTX_INT32   nTsToSend;  
  OTX_UINT32  cbTxBuf;
  OTX_BOOL    bFileLoop;
};

// direct Burst DMA receive
struct sBurstReceiver {
  OTX_UINT32  nSourceId;
  OTX_BOOL    bVerbose;
  OTX_BOOL    bActive;
  FILE        *pRxFile;
  OTX_INT32   nTsToRecord;  
};

// Pots Li device
struct sPotsLi {
  char                *pDtmfStr;       // pointer to DTMF string to be sent
  OTX_BOOL             bOffHook;       // True if phone is off-hook
  OTX_UINT32           nLiConnected;   // Shows LI is connected and to which port
  OTX_UINT32           nLiLastSense;   // Last received sense value
  DemoDeviceCallState  nCallState;     // Current state
  DemoDeviceCallState  nPrevCallState; // Previous state
  DemoDeviceCallState  nNextCallState; // Next state
  DemoDeviceCallState  nLastCallState; // Last state 
  OTX_TASK_REF  hwBase;  // part of callback for event handler
  OTX_UINT32    hwParms; // part of callback for event handler
  char      *evtTxtParms; // Event text string (debug)
  void (*EventHandler)(void *hwBase, // Assigned by user, returned with event
                       DemoHwEvent *hwEvent, // Event code
                       void *hwParms, // Value returned by event if needed
                       void *potsLiNum); // FXO line number
};

struct {  // Handles to Logical Devices
  OTX_HANDLE hPotsLi[DEMO_LI_MAX];

  OTX_HANDLE hVaDetector[DEMO_LI_MAX];
  OTX_HANDLE hCptDetector[DEMO_LI_MAX];

  OTX_HANDLE hCidDetector[DEMO_LI_MAX];
  OTX_HANDLE hVoiceMixer[DEMO_LI_MAX];
  
  OTX_HANDLE hDtmfDetector[DEMO_LI_MAX];
  OTX_HANDLE hDtmfDialer[DEMO_LI_MAX];

  OTX_HANDLE hEchoCancel[DEMO_LI_MAX];

  OTX_HANDLE hUserApp[DEMO_LI_MAX]; // used for debugging of the DSP program
} g_hLogicDevs;

struct {
  struct sBurstSender   mBurstSender;        
  struct sBurstReceiver mBurstReceiver;    
} g_sBurstDevs;

struct {
  struct sPotsLi mFxoLi;
  struct sPotsLi mFxsLi;
  OTX_EVENT      hNotificationEvent;
  OTX_HANDLE     hEventQueue;
} g_sPotsDevs[DEMO_LI_MAX];

struct {  // Handles to Pipes
  // Pipe used to carry data
  OTX_HANDLE hPotsRx[DEMO_LI_MAX];
  OTX_HANDLE hPotsDaaRx[DEMO_LI_MAX];
  OTX_HANDLE hPotsVaRx[DEMO_LI_MAX];
  OTX_HANDLE hPotsEcRx[DEMO_LI_MAX];
  OTX_HANDLE hPotsDtmfRx[DEMO_LI_MAX];
  OTX_HANDLE hPotsCptRx[DEMO_LI_MAX];
  OTX_HANDLE hPipeRecDaaRx[DEMO_LI_MAX];

  OTX_HANDLE hPotsTx[DEMO_LI_MAX];
  OTX_HANDLE hPotsFxsTx[DEMO_LI_MAX];
  OTX_HANDLE hPotsDialerTx[DEMO_LI_MAX];
  OTX_HANDLE hMixer1[DEMO_LI_MAX];

  // Debug connection FXS/FXO input signals
  OTX_HANDLE hBurstDaaRx[DEMO_LI_MAX];
  OTX_HANDLE hBurstSlicTx[DEMO_LI_MAX];
  
  // Dummy Pipes used for Logical Device Setup
  OTX_HANDLE hDsp2Ts2In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts20In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts21In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts22In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts23In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts24In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts25In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts27In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts28In[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts29In[DEMO_LI_MAX];

  OTX_HANDLE hDsp2Ts0Out[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts1Out[DEMO_LI_MAX];
  OTX_HANDLE hDsp2Ts20Out[DEMO_LI_MAX];
} g_hPipes;

char *g_sqNumber0 = "201";


// Call states for device FXO and FXS interface
char *g_sqszDeviceCallState[] = { 

   // Demo App states               
  "(app)DEMO_CALL_START_OF_STATES   "    ,  // 0
  "(app)STATE_CHANGE                "    ,  // 1
  "(app)INITIALIZING                "    ,  // 2
  "(app)MAKE_BUSY                   "    ,  // 3
  "(app)MAKE_RING_BACK              "    ,  // 4
  "(app)MAKE_REORDER                "    ,  // 5
  "(app)MAKE_CONGESTION             "    ,  // 6
  "(app)MAKE_OFFHOOK                "    ,  // 7
  "(app)MAKE_ONHOOK                 "    ,  // 8
  "(app)ONHOOK                      "    ,  // 9
  "(app)OFFHOOK                     "    ,  // 10
  "(app)FLASHHOOK                   "    ,  // 11
  "(app)DIGIT_DECODING              "    ,  // 12
  "(app)LOOP_TRANSITION             "    ,  // 13
  "(app)CALLER_ID                   "    ,  // 14
  "(app)MAKE_RINGING                "    ,  // 15
  "(app)RINGING                     "    ,  // 16
  "(app)STOP_RINGING                "    ,  // 17
  "(app)SEND_DTMF                   "    ,  // 18
  "(app)DTMF_TRANISTION             "    ,  // 19
  "(app)LI_INIT_COMPLETE            "    ,  // 20
  "(app)FAR_END_HANGUP              "    ,  // 21
  "(app)DEMO_TONE_DETECTED          "    ,  // 22
  "(app)EVENT_ERROR                 "    ,  // 23
  "(app)NO_ACTION_NEEDED            "    ,  // 24
  "(app)DEMO_CALL_END_OF_STATES     "       // 25                                
};




/*******************************************************************************
*******************************************************************************/

OTX_BOOL DemoSetup64kPipeOneEnd(OTX_HANDLE hPipe, 
                                OTX_HANDLE hDevice, 
                                OTX_UINT32 nHighway, 
                                OTX_UINT32 nTs, 
                                OtxPipeEndE nInOut)   
/*******************************************************************************
  @func
    Setup connection for one end of a 64k bits/second pipe.

*******************************************************************************/
{
  OTX_RESULT result;
  OTX_UINT8 sqTimeSlotMask[32];
  memset(sqTimeSlotMask, 0, sizeof(sqTimeSlotMask) * sizeof(sqTimeSlotMask[0]));
  sqTimeSlotMask[nTs] = 0xFF;
  result = OtxDrvConnectPipe(hPipe, 
                             nInOut, 
                             hDevice, 
                             nHighway, 
                             sqTimeSlotMask, 
                             32);
  DemoCheckRc(hPipe, result);
  return OTX_TRUE;
}


void DemoCreateEventQueue(OTX_EVENT *hEvent, OTX_HANDLE *hEventQueue)
/*******************************************************************************
  @func
    Create the event queue to be used by the driver to inform the application
    about events, such as line status changes, or detected DMTF digits.
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;

  // Create a notification Event
  result = OtxDrvCreateEvent(hEvent); 
  DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);

  // Create Event Queue for driver notifications
  result = OtxDrvCreateEventQueue(128, *hEvent, hEventQueue); 
  DemoCheckRc(*hEventQueue, result);

}



void DemoOpenPhysicalDevices(void)
/*******************************************************************************
  @func
    Opens the Physical Devices on the Arni-16-PCI board

  @comm
    Calls function <f OtxDrvOpenPhysicalDevice> returning a handle to a
    Device Object representing a physical device, which can be the
    entire board or an integrated circuit (chip) on the board. The number of
    physical devices is set per board and cannot change dynamically.
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32 i;

  // Get Handle to the Physical ARNI Board Controller
  switch (g_demoEnv.nBoardType) {
  case OTX_DEVICE_ARNI_6X6_PCI_PLUS:
    DemoLogf("Opening Arni-6x6-PCI-Plus board\n");
    break;
  case OTX_DEVICE_ARNI_6_FXO_PCI_PLUS:
    DemoLogf("Opening Arni-6-FXO-PCI-Plus board\n");
    break;
  case OTX_DEVICE_ARNI_6_FXS_PCI_PLUS:
    DemoLogf("Opening Arni-6-FXS-PCI-Plus board\n");
    break;
  case OTX_DEVICE_ARNI_6X3_PCI_PLUS:
    DemoLogf("Opening Arni-6x3-PCI-Plus board\n");
    break;
  case OTX_DEVICE_ARNI_6X6_PCI:
    DemoLogf("Opening Arni-6x6-PCI board\n");
    break;
  default:
    DemoLogf("Board Type (%d) not supported by this demo program\n", 
             g_demoEnv.nBoardType);
    exit(1);
    break;
  }
  result = OtxDrvOpenPhysicalDevice(0, 
                                   (OtxPhysicalDeviceTypeE) g_demoEnv.nBoardType, 
                                   g_demoEnv.boardNo, 
                                   g_demoEnv.boardNo, 
                                   g_hEventQueue, 
                                   &g_hPhysDevs.hBoardController0); 
  DemoCheckRc(g_hPhysDevs.hBoardController0, result);


  // Check if the watchdog timer has triggered before we continue
  {
    OTX_UINT32 readVal;
    result = OtxDrvReadReg32(g_hPhysDevs.hBoardController0, 0x04, &readVal); 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if(readVal == 0) {
      DemoLogf("The watchdog timer has triggered. A reboot of the PC is necessary.\n");
      result = OTX_E_NOT_INITIALIZED;
      // Log error
      DemoCheckRc(g_hPhysDevs.hBoardController0, result);
      return;
    }
  }


  // Disable the Watchdog Timer, and enable it 
  // when we have completed the configuration
  result = OtxDrvSetAttributeValueBool(g_hPhysDevs.hBoardController0, 
                                       OTX_ATTR_BRD_WATCHDOG_TIMER_ENABLED,  
                                       OTX_FALSE); 
  DemoCheckRc(g_hPhysDevs.hBoardController0, result);

  // Get a handle to the Time-Space Switch (TSS) on the board 
  // (just for debugging purposes)
  DemoLogf("Open OTX_DEVICE_TSS\n");
  result = OtxDrvOpenPhysicalDevice(g_hPhysDevs.hBoardController0, 
                                    OTX_DEVICE_TSS, 
                                    0, 
                                    0, 
                                    g_hEventQueue, 
                                    &g_hPhysDevs.hTss); 
  DemoCheckRc(g_hPhysDevs.hBoardController0, result);


  for (i = g_firstUsableLi; i < DEMO_DSP_MAX; i++) {
    DemoLogf("Open OTX_DEVICE_DSP #%d\n", i);
    result = OtxDrvOpenPhysicalDevice(g_hPhysDevs.hBoardController0, 
                                      OTX_DEVICE_DSP, 
                                      i, 
                                      i, 
                                      g_sPotsDevs[i].hEventQueue, 
                                      &g_hPhysDevs.hDsp[i]); 
    DemoCheckRc(g_hPhysDevs.hDsp[i], result);
  }

  for (i = g_firstUsableLi; i < DEMO_DSP_MAX; i++) {
    if (g_demoEnv.outFileName) {
      DemoLogf("Loading program file %s to DSP#%d \n", 
               g_demoEnv.outFileName, 
               i);
      result = OtxDspRunProgram(g_hPhysDevs.hDsp[i], 
                                g_demoEnv.outFileName, 
                                "_c_int00"); 
      DemoCheckRc(g_hPhysDevs.hDsp[i], result);
    } else {
      DemoLogf("Loading OTX_DSP_SPM_OTXCST2 to DSP#%d \n", i);
      result = OtxDspRunSpm(g_hPhysDevs.hDsp[i], 
                           OTX_DSP_SPM_OTXCST2); 
      DemoCheckRc(g_hPhysDevs.hDsp[i], result);
    }
  }

  // Get a handle to the physical Burst device.
  result = OtxDrvOpenPhysicalDevice(g_hPhysDevs.hBoardController0, 
                                    OTX_DEVICE_BURST, 
                                    0, 
                                    0, 
                                    g_hEventQueue, 
                                    &g_hPhysDevs.hBurst); 
  DemoCheckRc(g_hPhysDevs.hBoardController0, result);

  // set device buffer event trigger levels
  result = OtxDrvSetAttributeValueUint32(g_hPhysDevs.hBurst, 
                                         OTX_ATTR_BURST_RECEIVER_FIFO_TRIGGER,  
                                         DEMO_BURST_BUF_SIZE); 
  DemoCheckRc(g_hPhysDevs.hBurst, result);
  result = OtxDrvSetAttributeValueUint32(g_hPhysDevs.hBurst, 
                                         OTX_ATTR_BURST_SENDER_FIFO_TRIGGER,    
                                         DEMO_BURST_BUF_SIZE); 
  DemoCheckRc(g_hPhysDevs.hBurst, result);

  // Open SLICs
  for (i = g_firstUsableLi ; i < g_fxsLiInitialized; i++) {
    DemoLogf("Open OTX_DEVICE_LI_SLIC  #%d \n", i);
    result = OtxDrvOpenPhysicalDevice(g_hPhysDevs.hBoardController0, 
                                      OTX_DEVICE_LI_SLIC, 
                                      i, 
                                      i, 
                                      g_sPotsDevs[i].hEventQueue, 
                                      &g_hPhysDevs.hSlicLi[i]); 
    DemoCheckRc(g_hPhysDevs.hSlicLi[i], result);
    
    // Take the fail-over relays out of the pass-through state 
    // (i.e. engage the SLIC on the line)
    DemoLogf("Take the fail-over relay out of "
             "the pass-through state for SLIC #%d\n", i);
    result = OtxDrvSetAttributeValueBool(g_hPhysDevs.hSlicLi[i], 
                                         OTX_ATTR_SLIC_RELAY_CONTROL, 
                                         OTX_TRUE); 
    DemoCheckRc(g_hPhysDevs.hSlicLi[i], result);    
  }
}



void DemoEnablePhysicalDevices(void)
/*******************************************************************************
  @func
    Enable Configured Physical Devices
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32  i;

  DemoLogf("In DemoEnablePhysicalDevices\n");
  result = OtxDrvEnable(g_hPhysDevs.hBoardController0, OTX_TASK_SYNC, 5000L); 
  DemoCheckRc(g_hPhysDevs.hBoardController0, result);

  for (i = g_firstUsableLi; i < DEMO_DSP_MAX; i++) {
    result = OtxDrvEnable(g_hPhysDevs.hDsp[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hPhysDevs.hDsp[i], result);
  }


  for (i = g_firstUsableLi; i < g_fxsLiInitialized; i++) {
    result = OtxDrvEnable(g_hPhysDevs.hSlicLi[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hPhysDevs.hSlicLi[i], result);
  }
}


/*******************************************************************************
  @func
    Create the needed Logical Devices

  @comm
    The logical devices are different from the phyiscal devices in that the
    the number of logical devices is not fixed. More of them can be requested
    by the user and allocated by the system if needed.
*******************************************************************************/
void DemoCreateLogicalDevices(
  void
)
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32  nDsp;

  for (nDsp = g_firstUsableLi; nDsp < DEMO_DSP_MAX; nDsp++) {
        
    DemoLogf("Creating Logical Devices on Dsp%d\n", nDsp);
    
    if (g_demoEnv.outFileName) {
      // For debug prints
      result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                          OTX_LDEVICE_USER_APPLICATION, 
                                          g_sPotsDevs[nDsp].hEventQueue, 
                                          nDsp, 
                                          &g_hLogicDevs.hUserApp[nDsp]); 
      DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);
      DemoLogf("Created User App device [%d], Handle = 0x%X (debug printfs)\n", 
               nDsp, 
               g_hLogicDevs.hUserApp[nDsp]);
    }
    
    // Create Pots Li Logical Devices
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_LI_POTS, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hPotsLi[nDsp]); 
    DemoCheckRc(g_hLogicDevs.hPotsLi[nDsp], result);

    // Create Voice Activity Detector Logical Devices
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hVaDetector[nDsp]); 
    DemoCheckRc(g_hLogicDevs.hVaDetector[nDsp], result);

    
    // Creatr CID Detector devices
    //DemoLogf("Creating CID Detector device [%d]\n", i);
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_CALLER_ID_DETECTOR, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hCidDetector[nDsp]); 
    DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);

    // Create Cpt Detector Logical Devices
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_CPT_DETECTOR, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hCptDetector[nDsp]); 
    DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);
    
    // Create Dtmf Detector Logical Devices
    //DemoLogf("Create Logical Device DTMF DETECTOR #%d (nDsp=%d)\n", nLi, nDsp);
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_DTMF_DETECTOR, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hDtmfDetector[nDsp]); 
    DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);

    // Create Voice Mixer Logical Devices
    //DemoLogf("Create Logical Device VOICE MIXER #%d (nDsp=%d)\n", nLi, nDsp);
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_VOICE_MIXER, 
                                        g_sPotsDevs[nDsp].hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hVoiceMixer[nDsp]); 
    DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);

    
    // Create DTMF Dialers Logical Devices
    //DemoLogf("Create Logical Device DTMFDIALER #%d (nDsp=%d)\n", nLi, nDsp);
    result = OtxDrvCreateLogicalDevice(g_hPhysDevs.hDsp[nDsp], 
                                       OTX_LDEVICE_CST_DTMF_DIALER, 
                                       g_sPotsDevs[nDsp].hEventQueue, 
                                       nDsp, 
                                       &g_hLogicDevs.hDtmfDialer[nDsp]); 
    DemoCheckRc(g_hLogicDevs.hDtmfDialer[nDsp], result);

    // Create Echo Cancel Device Logical Devices
    result = OtxDrvCreateLogicalDevice( g_hPhysDevs.hDsp[nDsp], 
                                        OTX_LDEVICE_CST_ECHO_CANCEL, 
                                        g_hEventQueue, 
                                        nDsp, 
                                        &g_hLogicDevs.hEchoCancel[nDsp]); 
    DemoCheckRc(g_hPhysDevs.hDsp[nDsp], result);

  }   
}



void DemoConnectDevices(void)
/*******************************************************************************
  @func
    Create the needed Pipe Devices and connect the physical and 
    logical devices to the pipes. The logical devices use dummy 
    pipes for internal connections. These pipes are only used to
    configure the logical device to the correct time slot. The 
    physical device that is hosting the logical device is already 
    connected to the highway. The dummy pipe is used to define the 
    TS with in the highway. This is needed to define multiple 
    copies of the same logical device.

  @comm
    A Pipe Device is a logical entity representing a serial bit-stream 
    (a subset of a Highway) with a data rate between 8 kbit/s and 2.048Mbit/s. 
    A pipe is a characterized by its capacity (in 8 kbit/s increments). The 
    user can create a pipe with the driver function <f OtxDrvCreatePipe>. A 
    pipe is connected to physical or logical devices and mapped to specific 
    time-slots with the driver function <f OtxDrvConnectPipe>.
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32 nTs;
  OTX_INT32 potsLi;
  OTX_INT32 nDsp;

  // Create the pipes that will be needed in this application
  for(potsLi = g_firstUsableLi; potsLi < DEMO_LI_MAX; potsLi++) {
    // Create the All Pipes needed for connection and Dummy Pipes
    // used to setup Logical devices within the DSP
    result = OtxDrvCreatePipe(64, &g_hPipes.hBurstDaaRx[potsLi]); 
    DemoCheckRc(g_hPipes.hBurstDaaRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hBurstSlicTx[potsLi]); 
    DemoCheckRc(g_hPipes.hBurstSlicTx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsVaRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsVaRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsEcRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsEcRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsDtmfRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsDtmfRx[potsLi], result);
    
    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsCptRx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsCptRx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsTx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsTx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsFxsTx[potsLi]); 
    DemoCheckRc(g_hPipes.hPotsFxsTx[potsLi], result);
    
    result = OtxDrvCreatePipe(64, &g_hPipes.hPotsDialerTx[potsLi]);
    DemoCheckRc(g_hPipes.hPotsDialerTx[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hMixer1[potsLi]);
    DemoCheckRc(g_hPipes.hMixer1[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts0Out[potsLi]); 
    DemoCheckRc(g_hPipes.hDsp2Ts0Out[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts1Out[potsLi]); 
    DemoCheckRc(g_hPipes.hDsp2Ts1Out[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts20Out[potsLi]); 
    DemoCheckRc(g_hPipes.hDsp2Ts20Out[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts20Out[potsLi]); 
    DemoCheckRc(g_hPipes.hDsp2Ts20Out[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts2In[potsLi]); 
    DemoCheckRc(g_hPipes.hDsp2Ts2In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts20In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts20In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts21In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts21In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts22In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts22In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts23In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts23In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts24In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts24In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts25In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts25In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts27In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts27In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts28In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts28In[potsLi], result);

    result = OtxDrvCreatePipe(64, &g_hPipes.hDsp2Ts29In[potsLi]);
    DemoCheckRc(g_hPipes.hDsp2Ts29In[potsLi], result);
  }

  for(potsLi = g_firstUsableLi; potsLi < g_fxsLiInitialized; potsLi++) {
    g_liConNumber_1 = potsLi;
    // Connect all FXO(n) devices to  FXS(n) devices.
    DemoConnectFxoToFxsDevices(potsLi);
  }
  g_liConNumber_1 = DEMO_NO_LI_CONNECTED;

  // Create the Pipes (one for each direction) 
  // between the Logical DSP Devices and the DSPs
  for (nDsp = g_firstUsableLi; nDsp < DEMO_LI_MAX; nDsp++) {

    // Create pipes (one for each direction)
    DemoLogf("Connection pipes for logical devices in DSP%d\n", nDsp);

    // CONNECT LOGICAL DEVICES WITHIN THE DSP
    // --------------------------------------
    // -------------------------
    // Connect pipe: Dsp  -> Dummy pipe (Pipe does not actually connect any devices)

    // -------------------------
    // CONNECT INPUT/OUTPUT PIPE TO LOGICAL DEVICES WITHIN THE DSP
    // --------------------------------------
    // Create the following Connections :
    //   Dummy PIPE  --> Pots Li 
    //   Pots Li  --> Dummy Pipe
    nTs = DEMO_TS_DSP_POTS_LI_TX;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts2In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    nTs = DEMO_TS_DSP_POTS_LI_RX;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts0Out[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_INPUT);   

    result = OtxDrvConnectLogicalDevice(g_hLogicDevs.hPotsLi[nDsp], 
                                        -1,    // Out
                                        g_hPipes.hDsp2Ts0Out[nDsp], 
                                        -1);   // In on connection device
    DemoCheckRc(g_hLogicDevs.hPotsLi[nDsp], result);

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts2In[nDsp], 
                                        -1,    // Out
                                        g_hLogicDevs.hPotsLi[nDsp], 
                                        -1);   // In on connection device
    DemoCheckRc(g_hPipes.hDsp2Ts2In[nDsp], result);

    // Logically connect the 3 inputs to the Voice Mixer and 1 output
    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT0;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts20In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   
    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT1;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts21In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   
    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT2;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts22In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    nTs = DEMO_TS_DSP_VOICE_MIX_OUTPUT;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts1Out[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_INPUT);   

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts20In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hVoiceMixer[nDsp], 
                                        0); 
    DemoCheckRc(g_hPipes.hDsp2Ts20In[nDsp], result);
    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts21In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hVoiceMixer[nDsp], 
                                        1); 
    DemoCheckRc(g_hPipes.hDsp2Ts21In[nDsp], result);
    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts22In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hVoiceMixer[nDsp], 
                                        2); 
    DemoCheckRc(g_hPipes.hDsp2Ts22In[nDsp], result);
    result = OtxDrvConnectLogicalDevice(g_hLogicDevs.hVoiceMixer[nDsp], 
                                        -1, 
                                        g_hPipes.hDsp2Ts1Out[nDsp], 
                                        -1); 
    DemoCheckRc(g_hPipes.hDsp2Ts1Out[nDsp], result);


    // CONNECT INPUT PIPE TO LOGICAL DEVICES WITHIN THE DSP
    // --------------------------------------
    // Create the following Connections:
    //   Dummy Pipe  --->  logical DSP device 

    // DTMF Detector Device
    nTs = DEMO_TS_DSP_DTMF_DETECTOR;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts23In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts23In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hDtmfDetector[nDsp], 
                                        -1); 
    DemoCheckRc(g_hPipes.hDsp2Ts23In[nDsp], result);

    // Call Progress Tone (CPT) Device
    nTs = DEMO_TS_DSP_CPT;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts24In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts24In[nDsp], 
                                        -1,     // Out
                                        g_hLogicDevs.hCptDetector[nDsp], 
                                        -1);    // In on connection device 
    DemoCheckRc(g_hPipes.hDsp2Ts24In[nDsp], result);

    // Voice Activity (VA) Device
    nTs = DEMO_TS_DSP_VAD;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts25In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts25In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hVaDetector[nDsp], 
                                        -1); 
    DemoCheckRc(g_hPipes.hDsp2Ts25In[nDsp], result);

    // CID Device
    nTs = DEMO_TS_DSP_CID;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts27In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts27In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hCidDetector[nDsp], 
                                        -1); 
    DemoCheckRc(g_hPipes.hDsp2Ts27In[nDsp], result);


    // CONNECT OUTPUT PIPE TO LOGICAL DEVICES WITHIN THE DSP
    // --------------------------------------
    // Create the following Connections:
    // Make the following connections in transmit direction:
    //   DtmfDialer  --> Dummy Pipe
    // DTMF Device
    nTs = DEMO_TS_DSP_DTMF_DIALER;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts20Out[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_INPUT);   

    result = OtxDrvConnectLogicalDevice(g_hLogicDevs.hDtmfDialer[nDsp], 
                                        -1, 
                                        g_hPipes.hDsp2Ts20Out[nDsp], 
                                        -1); 
    DemoCheckRc(g_hLogicDevs.hDtmfDialer[nDsp], result);

#if VOICE_MIXER0 == 1
    // -------------------------
    // Connect pipe: Dsp Voice Mixer -> Dsp LI transmit to DAA
    // -------------------------
    nTs = DEMO_TS_DSP_VOICE_MIX_OUTPUT;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = DEMO_TS_DSP_POTS_LI_TX;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   
#endif

    // -------------------------
    // Connect pipe: (DAA -> LI) Dsp --> Dsp (DTMF detector)
    // -------------------------
    nTs = DEMO_TS_DSP_POTS_LI_RX;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDtmfRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = DEMO_TS_DSP_DTMF_DETECTOR;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDtmfRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   

#if VOICE_MIXER0 == 1
    // -------------------------
    // Connect pipe: Dsp DTMF Dialer --> Dsp (Voice Mixer 0 input)
    // -------------------------
    nTs = DEMO_TS_DSP_DTMF_DIALER;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT0;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   
#else
    /*
    ** DTMF directly to PotsLi device. Voice mixer not needed until voice channel
    ** is connected.
    */
    // -------------------------
    // Connect pipe: Dsp DTMF Dialer --> Dsp (PotsLi)
    // -------------------------
    nTs = DEMO_TS_DSP_DTMF_DIALER;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = DEMO_TS_DSP_POTS_LI_TX;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   
#endif





    // CONNECT OUTPUT PIPE TO LOGICAL DEVICES WITHIN THE DSP
    // --------------------------------------
    // Create the following Connections:
    // Make the following connections in transmit direction:
    //   echo cancel (EC)  --> Dummy Pipe
    nTs = DEMO_TS_DSP_EC_INPUT_NE;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts28In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_INPUT);
    
    nTs = DEMO_TS_DSP_EC_INPUT_FE;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts29In[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_INPUT);

    nTs = DEMO_TS_DSP_EC_OUTPUT;
    DemoSetup64kPipeOneEnd(g_hPipes.hDsp2Ts1Out[nDsp], 
                           g_hPhysDevs.hDsp[nDsp], 
                           -1, 
                           nTs, 
                           OTX_PIPE_OUTPUT);
/*
    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts29In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hEchoCancel[nDsp], 
                                        OTX_CST_ECHO_CANCEL_FAR_END_PIPE); 
    DemoCheckRc(g_hPipes.hDsp2Ts29In[nDsp], result);
    result = OtxDrvConnectLogicalDevice(g_hPipes.hDsp2Ts28In[nDsp], 
                                        -1, 
                                        g_hLogicDevs.hEchoCancel[nDsp], 
                                        OTX_CST_ECHO_CANCEL_NEAR_END_PIPE); 
    DemoCheckRc(g_hPipes.hDsp2Ts28In[nDsp], result);

    result = OtxDrvConnectLogicalDevice(g_hLogicDevs.hEchoCancel[nDsp], 
                                        -1, 
                                        g_hPipes.hDsp2Ts1Out[nDsp], 
                                        -1); 
    DemoCheckRc(g_hLogicDevs.hEchoCancel[nDsp], result);
*/

    // -------------------------
    // Connect pipe: Burst -> Dsp (Voice Mixer 1 input)
    // -------------------------
    // Burst highway number 8 TS[0] used to send burst data to all FXO devices
    nTs = 0;
    DemoLogf("Connection burst TS%d to Mixer DSP%d\n", nTs, nDsp);
    DemoSetup64kPipeOneEnd(g_hPipes.hMixer1[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_BURST,   
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT1;
    DemoSetup64kPipeOneEnd(g_hPipes.hMixer1[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   

    // -------------------------
    // Connect pipe: Dsp CptDetector -> Pots LI receive 
    // -------------------------
    nTs = DEMO_TS_DSP_POTS_LI_RX;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsCptRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT); 
    
    DemoLogf("Connection DSP TS%d to CPT detector TS%d DSP%d\n", 
             nTs, 
             DEMO_TS_DSP_CPT, 
             nDsp);
    nTs = DEMO_TS_DSP_CPT;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsCptRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);
    /*
    **  Debug connection for burst Li n only TSn-->FXOn, TS(n+6)-->FXSn
    **  Setup the burst device on all FXO and FXS line input sides.
    **      Burst Input time slot.
    **      0 FXO(0)     6 FXS(0)
    **      1 FXO(1)     7 FXS(1)
    **      2 FXO(2)     8 FXS(2)
    **      3 FXO(3)     9 FXS(3)
    **      4 FXO(4)    10 FXS(4)
    **      5 FXO(5)    11 FXS(5)
    */
    
    // Also connect the DAA(n) samples to the burst via a TSS connection
    nTs = DEMO_TS_DSP_POTS_LI_RX;  // All PotsLi's are connected to TS0 of DSP highway
    DemoSetup64kPipeOneEnd(g_hPipes.hBurstDaaRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           nDsp,          // Physical Highway (DSP=HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = nDsp;
    DemoSetup64kPipeOneEnd(g_hPipes.hBurstDaaRx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_BURST,  
                           nTs, 
                           OTX_PIPE_OUTPUT);

    // Also connect the FXS SLIC(n) samples to the burst via a TSS connection
    // starting at burst TS 6.
    // FXS time slots are offset from each other by 3
    nTs = nDsp * 3;
    DemoSetup64kPipeOneEnd(g_hPipes.hBurstSlicTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_FXS,     // All six FXS devices use the same highway
                           nTs, 
                           OTX_PIPE_INPUT);   

    nTs = nDsp + 6;
    DemoSetup64kPipeOneEnd(g_hPipes.hBurstSlicTx[nDsp], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_BURST,  
                           nTs, 
                           OTX_PIPE_OUTPUT);
  }

}


static OTX_RESULT DemoConnectFxoToFxsDevices( OTX_INT32 potsLi )
/*******************************************************************************
  @func
    Connect the physical and logical devices to pipes.

    This function connects FXO to FXS. If FXS handset 2 is taken off hook
    the FXO 2 will be connected. Each FXS (SLIC) is directly mapped to the
    it corresponding FXO POTS line.

    All six of the SLIC devices use highway 6, 
    DSP highways are 0-5 with DSP zero connected to highway 0.

  @comm
    A Pipe Device is a logical entity representing a serial bit-stream 
    (a subset of a Highway) with a data rate between 8 kbit/s and 2.048Mbit/s. 
    A pipe is a characterized by its capacity (in 8 kbit/s increments). 
    The user can create a pipe with the driver function <f OtxDrvCreatePipe>.
    A pipe is connected to physical or logical devices and mapped to
    specific time-slots with the driver function <f OtxDrvConnectPipe>.
    
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32 nTs;

  // This Demo connect two devices together
  DemoLogf("DemoConnectFxoToFxsDevices POTS LI %d\n", potsLi);


  // Data from and to POTS LIs
  if(DEMO_NO_LI_CONNECTED == g_liConNumber_1)  {
    // The demo has a sequence issue no connects are set
    DemoLogf("Warning DemoConnectLiToLiDevices: No connections were set!\n");
  }
  else {    
    g_liConTimeSlot = (OTX_UINT16) ((potsLi * 3));    
    DemoLogf("  Time slot %d\n", g_liConTimeSlot);
    
    // Connect FXO X to the FXS X as an output
    nTs = DEMO_TS_DSP_POTS_LI_RX;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsRx[potsLi], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           potsLi,    // Physical Highway (DSP HWY 0-5)
                           nTs, 
                           OTX_PIPE_INPUT);   

    // Connect Pipes
    // Connect FXO X to the FXS X as an input
    nTs = g_liConTimeSlot;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsRx[potsLi], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_FXS,     // Physical Highway,
                           nTs, 
                           OTX_PIPE_OUTPUT);   


    // Connect FXS X to the FXO X as an output
    nTs = g_liConTimeSlot;
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsFxsTx[potsLi], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           DEMO_HWY_FXS,     // Physical Highway
                           nTs, 
                           OTX_PIPE_INPUT);   

    // Connect FXS X to the FX0 X as an input
    nTs = DEMO_TS_DSP_VOICE_MIX_INPUT2;       // Use Voice Mixer
    DemoSetup64kPipeOneEnd(g_hPipes.hPotsFxsTx[potsLi], 
                           g_hPhysDevs.hTss, // Use TSS device to connect pipe
                           potsLi,    // Physical Highway (DSP HWY 0-5)
                           nTs, 
                           OTX_PIPE_OUTPUT);   
  }

  DemoLogf("Done\n");

  return(result);
}

static OTX_RESULT DemoConnectFxsVoicePath( OTX_INT32 potsLi )
/*******************************************************************************
  @func
    Connect the physical and logical devices to pipes.

    This function connects the FXS voice path using the voice mixer
    device provided by the DSP. The voice mixer has three inputs and
    one output. The burst device is connected to input 1, the FXS uses
    input 2 and input 0 is used by the DTMF Dialer.

    All six of the SLIC devices use highway 6, 
    DSP highways are 0-5 with DSP zero connected to highway 0.
    The Burst device uses highway 8.

  @comm
    A Pipe Device is a logical entity representing a serial bit-stream 
    (a subset of a Highway) with a data rate between 8 kbit/s and 2.048Mbit/s. 
    A pipe is a characterized by its capacity (in 8 kbit/s increments). 
    The user can create a pipe with the driver function <f OtxDrvCreatePipe>.
    A pipe is connected to physical or logical devices and mapped to
    specific time-slots with the driver function <f OtxDrvConnectPipe>.
    
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;

  OTX_INT32 nTs;
  OTX_INT32 nDsp;

  // This Demo connect two devices together
  DemoLogf("DemoConnectFxsVoicePath FXS LI %d\n", potsLi);
  nDsp = potsLi;

  // Need to disconnect the 2 sets of pipes. The DTMF Dialer and the
  // PotsLi connection.
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_INPUT);        // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_OUTPUT);       // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsDialerTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_INPUT);        // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsDialerTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_OUTPUT);       // Which end of the pipe 

  // -------------------------
  // Connect pipe: Dsp Voice Mixer -> Dsp LI transmit to DAA
  // -------------------------
  nTs = DEMO_TS_DSP_VOICE_MIX_OUTPUT;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_INPUT);   

  nTs = DEMO_TS_DSP_POTS_LI_TX;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_OUTPUT);   

  // -------------------------
  // Connect pipe: Dsp DTMF Dialer --> Dsp (Voice Mixer 0 input)
  // -------------------------
  nTs = DEMO_TS_DSP_DTMF_DIALER;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_INPUT);   

  nTs = DEMO_TS_DSP_VOICE_MIX_INPUT0;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_OUTPUT);   
  return(result);

}


static OTX_RESULT DemoConnectFxsDtmfDialer( OTX_INT32 potsLi )
/*******************************************************************************
  @func
    Connect the physical and logical devices to pipes.

    This function connects the FXS voice path to the DTMF dialer.

    DSP highways are 0-5 with DSP zero connected to highway 0.

  @comm
    A Pipe Device is a logical entity representing a serial bit-stream 
    (a subset of a Highway) with a data rate between 8 kbit/s and 2.048Mbit/s. 
    A pipe is a characterized by its capacity (in 8 kbit/s increments). 
    The user can create a pipe with the driver function <f OtxDrvCreatePipe>.
    A pipe is connected to physical or logical devices and mapped to
    specific time-slots with the driver function <f OtxDrvConnectPipe>.
    
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32 nTs;
  OTX_INT32 nDsp;

  // This Demo connect two devices together
  DemoLogf("DemoConnectFxsDtmfDialer FXS LI %d\n", potsLi);
  nDsp = potsLi;

  // Need to disconnect the 2 sets of pipes. The DTMF Dialer and the
  // PotsLi connection.
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_INPUT);        // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_OUTPUT);       // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsDialerTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_INPUT);        // Which end of the pipe 
  result = 
  OtxDrvDisconnectPipe(g_hPipes.hPotsDialerTx[nDsp], // Pipe to be disconnected
                       OTX_PIPE_OUTPUT);       // Which end of the pipe 

  /*
  ** DTMF directly to PotsLi device. Voice mixer not needed until voice channel
  ** is connected.
  */
  // -------------------------
  // Connect pipe: Dsp DTMF Dialer --> Dsp (PotsLi)
  // -------------------------
  nTs = DEMO_TS_DSP_DTMF_DIALER;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_INPUT);   

  nTs = DEMO_TS_DSP_POTS_LI_TX;
  DemoSetup64kPipeOneEnd(g_hPipes.hPotsDialerTx[nDsp], 
                         g_hPhysDevs.hTss, // Use TSS device to connect pipe
                         nDsp,             // Physical Highway (DSP=HWY 0-5)
                         nTs, 
                         OTX_PIPE_OUTPUT);   

  return(result);

}

void DemoInitializeLogicalDevices( void )
/*******************************************************************************
  @func
    Initialize the logical device. This function must be called after
    the devices are created and connected.
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32  i;

  DemoLogf("In DemoInitializeLogicalDevices\n");


  DemoLogf("Configuring Lis for country set=");
  switch (g_demoEnv.nSetId) {
  case OTX_CST_POTS_CFG_SET_USA:
    DemoLogf("USA");
    break;
  case OTX_CST_POTS_CFG_SET_GERMANY: 
    DemoLogf("Germany");
    break;
  case OTX_CST_POTS_CFG_SET_UK:
    DemoLogf("United Kingdom");
    break;
  case OTX_CST_POTS_CFG_SET_FRANCE:
    DemoLogf("France");
    break;
  case OTX_CST_POTS_CFG_SET_AUSTRALIA:
    DemoLogf("Australia");
    break;
  case OTX_CST_POTS_CFG_SET_JAPAN:
    DemoLogf("Japan");
    break;
  default:
    DemoLogf("UNKNOWN");
    break;
  }
  DemoLogf("\n");  

  for (i = g_firstUsableLi; i < DEMO_DSP_MAX; i++) {

    // Initialize the POTS LI logical devices
    result = OtxCstPotsInit(
      g_hLogicDevs.hPotsLi[i],
      g_demoEnv.law,
      g_demoEnv.nSetId
      );
    DemoCheckRc(g_hLogicDevs.hPotsLi[i], result);

    // Initialize the Voice Activity Detector
    result = OtxCstVoiceActivityDetectorInit(
      g_hLogicDevs.hVaDetector[i], 
      g_demoEnv.law
      ); 
    DemoCheckRc(g_hLogicDevs.hVaDetector[i], result);

    // Initialize the CID Detector
    result = OtxCstCidDetectorInit(
      g_hLogicDevs.hCidDetector[i], 
      g_demoEnv.law, 
      OTX_CST_CID_DETECTOR_STD_CFG
      ); 
    DemoCheckRc(g_hLogicDevs.hCidDetector[i], result);

    // Initialize the CPT Detector
    result = OtxCstCptDetectorInit(
      g_hLogicDevs.hCptDetector[i], 
      g_demoEnv.law, 
      OTX_TRUE,
      OTX_CST_CPT_DETECTOR_Q35_CFG
      ); 
    DemoCheckRc(g_hLogicDevs.hCptDetector[i], result);

    // Initialize the DTMF Detector
    result = OtxCstDtmfDetectorInit(
      g_hLogicDevs.hDtmfDetector[i], 
      g_demoEnv.law, 
      OTX_TRUE); 
    DemoCheckRc(g_hLogicDevs.hDtmfDetector[i], result);

    // Initialize the DTMF Dialers
    result = OtxCstDtmfDialerInit(
      g_hLogicDevs.hDtmfDialer[i], 
      g_demoEnv.law 
      ); 
    DemoCheckRc(g_hLogicDevs.hDtmfDialer[i], result);

    // Initialize the Echo Cancel Device
	/*
    result = OtxCstEchoCancelInit(
      g_hLogicDevs.hEchoCancel[i], 
      g_demoEnv.law, 
      OTX_CST_ECHO_CANCEL_32_MS); 
    DemoCheckRc(g_hLogicDevs.hEchoCancel[i], result);
	*/

    // Initialize the Voice Mixer
    result = OtxCstVoiceMixerInit(g_hLogicDevs.hVoiceMixer[i], 
                                  g_demoEnv.law, 
                                  3); 
    DemoCheckRc(g_hLogicDevs.hVoiceMixer[i], result);

  }
}


void DemoEnableLogicalDevices(void)
/*******************************************************************************
  @func
    Enable Configured Logical Devices
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  OTX_INT32  i;

  DemoLogf("In DemoEnableLogicalDevices\n");

  for (i = g_firstUsableLi; i < DEMO_DSP_MAX; i++) {

    result = OtxDrvEnable(g_hLogicDevs.hPotsLi[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hPotsLi[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hDtmfDetector[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hDtmfDetector[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hCidDetector[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hCidDetector[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hCptDetector[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hCptDetector[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hVaDetector[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hVaDetector[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hDtmfDialer[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hDtmfDialer[i], result);

    result = OtxDrvEnable(g_hLogicDevs.hVoiceMixer[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(g_hLogicDevs.hVoiceMixer[i], result);
  }
}


static void DemoCheckRc(IN OTX_HANDLE hDevice, IN OTX_RESULT result)
/*******************************************************************************
  @func
    Check the result from API call. If the result is a failure code then prompt
    the user if he wants to exit.
*******************************************************************************/
{
  
  if ( OTX_FAILURE(result) ) {

    if (hDevice == OTX_INVALID_HANDLE_VALUE) {
      DemoLogf("ERROR(%#lX [%d.%d])\n", 
               OTX_RESULT_CODE(result), 
               OTX_RESULT_SOURCE_ID(result), 
               OTX_RESULT_LINE_NUM(result));
    } else {
      OTX_RESULT otxRc;
      char msgStr[256];
      OtxAttribTypeE  eAttribType;    // Type of the attribute, if attribute exists
      OTX_UINT32      cbAttribValue;  // Size in bytes of attribute value (Get value with <f OtxDrvGetAttributeValue>)
      OTX_BOOL        bReadOnly;      // Is attribute writable or read-only
      OTX_UINT32      eDeviceType = 999;    // Device type for hDevice 
      OTX_UINT32      nDeviceNumber = 999;  // Device number for hDevice
      
      // Get the Device Type for hHandle
      otxRc = OtxDrvGetAttributeType(hDevice, 
                                     OTX_ATTR_DEVICE_TYPE, 
                                     &eAttribType, 
                                     &cbAttribValue, 
                                     &bReadOnly); 
      if (OTX_SUCCESS(otxRc)) {
        assert(eAttribType == OTX_ATTRIB_UINT32);
        assert(cbAttribValue == sizeof(OTX_UINT32));
        OtxDrvGetAttributeValueUint32(hDevice, 
                                      OTX_ATTR_DEVICE_TYPE, 
                                      &eDeviceType); 
      } 
      
      // Get the Device Number for hHandle
      otxRc = OtxDrvGetAttributeType(hDevice, 
                                     OTX_ATTR_DEVICE_NO, 
                                     &eAttribType, 
                                     &cbAttribValue, 
                                     &bReadOnly); 
      if (OTX_SUCCESS(otxRc)) {
        assert(eAttribType == OTX_ATTRIB_UINT32);
        assert(cbAttribValue == sizeof(OTX_UINT32));
        OtxDrvGetAttributeValueUint32(hDevice, 
                                      OTX_ATTR_DEVICE_NO, 
                                      &nDeviceNumber); 
      }
      
      // Convert the result code to a more descriptive string
      otxRc = OtxDrvResultCode2String(hDevice, result, 256, &msgStr[0]);
      if (OTX_FAILURE(otxRc)) {
        strcpy(msgStr, "Cannot translate this result code.");
      }
      DemoLogf("ERROR(%#lX [%d.%d]) Dev(%X,%d,%d): %s \n", 
               OTX_RESULT_CODE(result), 
               OTX_RESULT_SOURCE_ID(result), 
               OTX_RESULT_LINE_NUM(result), 
               hDevice, 
               (int) eDeviceType, 
               (int)nDeviceNumber, 
               msgStr);
    }

    // Save the result so that if an application is not using the console
    // the result code can be passed to the user's application.
    g_nDemoAppResultCode = result;
    if(g_bConsoleEnabled) {
      DemoExitQuestion();
    }
  }
}


static void DemoGetLastFailure(OTX_RESULT *result)
/*******************************************************************************
  @func
    Get the last failure code logged by the dmeo application
*******************************************************************************/
{
  // Pass back the current value for any failures
  *result = g_nDemoAppResultCode;
  // Clear it for the next check
  g_nDemoAppResultCode = OTX_S_OK;

  if(g_nCmdTimeoutCnt > 10) {
    // Show number of command timeouts
    if(g_nDbgSetting < DEMO_DBG_LEVEL_0) {
      DemoLogf("**** \n");
      DemoLogf("**** Received %d timeouts on host to DSP command interface\n", 
               g_nCmdTimeoutCnt);
      DemoLogf("**** \n");
      g_nCmdTimeoutCnt = 0; // Reset the count
    }
  }

  return;
}

void DemoExitQuestion(void)
/*******************************************************************************
  @func
    Prompts whether to exit the program. Usually called after an error 
    has been reported.

*******************************************************************************/
{
  short c;
  if (g_demoEnv.bContinueOnError) {
    DemoLogf("\n");
    DemoLogf("   Continue on ERROR is set\n");
    DemoLogf("\n");

    c = 'n';
  }
  else
  if (g_demoEnv.bExitOnError) {
    c = 'y';
  } else {
    DemoLogf("Do you want to exit (Y/N) ");
    DemoLogf("\n");
    c = OsaConsoleGetCh();
  }

  if (c == 'y' || c == 'Y') {
    // Clean up
    DemoExit(1);
  }

  DemoLogf("\n");
}


void DemoPrintTimeStamp(OTX_DATETIME nTimeStamp)
/*******************************************************************************
  @func
    Prints a timestamp in a MM-DD hh:mm:ss:mmm format, where

    MM  = month
    DD  = day (of month)
    hh  = hour of day
    mm  = minutes of day
    ss  = seconds of day
    mmm = milliseconds

*******************************************************************************/
{
  OTX_DATETIME nTimeStampMs;
  OTX_DATETIME nTimeStampSec;
  struct Osa_tm *ptCurrentDayAndTime;
  Osa_time_t nCurrentTimeSecs;
  
  // Subtract number of 100ns ticks between Jan 1, 1970 and Jan 1, 1600
  
  #if defined(__linux__)
    nTimeStamp.nUint64 = nTimeStamp.nUint64 - 116444736000000000LL;  
  #elif defined(WIN32)
    nTimeStamp.nUint64 = nTimeStamp.nUint64 - 116444736000000000;  
  #endif

  
  // Convert to seconds since Jan 1, 1970 
  // (so we can use this time with OsaStdLocalTime())
  nTimeStampSec.nUint64 = nTimeStamp.nUint64 / 10000000;
  
  // Calculate number of milliseconds 
  // (since number of seconds is not a very accurate way to report timestamp)
  nTimeStampMs.nUint64 = nTimeStamp.nUint64 / 10000   - 
                        (nTimeStampSec.nUint64 * 1000);
  
  nCurrentTimeSecs = nTimeStampSec.sUint32.nLow;
  ptCurrentDayAndTime = OsaStdLocalTime(&nCurrentTimeSecs);
  
  if (ptCurrentDayAndTime) {
    
    DemoLogf("%.2d-%.2d %.2d:%.2d:%.2d.%.3d ", 
      ptCurrentDayAndTime->tm_mon + 1,
      ptCurrentDayAndTime->tm_mday,
      ptCurrentDayAndTime->tm_hour,
      ptCurrentDayAndTime->tm_min, 
      ptCurrentDayAndTime->tm_sec,
      nTimeStampMs.sUint32.nLow
      );
  } else {
    DemoLogf("Error: Invalid timestamp (before Jan 1, 1970)\n");
  }
    
}


void  *DemoLineSensingFunction(void *lpParameter)  // thread data
/*******************************************************************************
  @func
    Function that keeps monitoring the Loop current for Far-End-Hangup conditions
*******************************************************************************/
{
  OTX_RESULT result;
  OTX_INT32  nCurrentLi;
  OTX_BOOL   nLiOffHook = OTX_TRUE; // always get one on startup

  g_bLineSensingThreadActive = OTX_TRUE; 

  DemoLogf("DemoLineSensingFunction Thread started\n");
  while (g_bLineSensingThreadActive) {

    for(nCurrentLi = g_firstUsableLi; nCurrentLi < DEMO_DSP_MAX; nCurrentLi++) {
      // If Li is offhook send a line sense command
      if(nLiOffHook) {
        result = OtxCstPotsSenseLine(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                     0x1006,   // User Assigned TASK REF ID
                                     150);     // Timeout in milliseconds
        if(OTX_FAILURE(result)) {
          if(OTX_RESULT_CODE(result) != OTX_E_BUSY) {
            DemoLogf("DemoLineSensingFunction Sense Line Poll failed 0x%X\n",
                      result);
          }
        }
        // Do not want to fill up DSP input queue, or get in the way of 
        // commands from the other tasks, so space out the sense line requests.
        OsaThreadSleep(40); // in milliseconds 
      }
      DemoFxoIsLiOffHook(nCurrentLi, 
                         &nLiOffHook,
                         NULL);
    }

    OsaThreadSleep(200); // in milliseconds
  }

  DemoLogf("DemoLineSensingFunction Thread terminating\n");
  return 0;
}


/*******************************************************************************
  @func
    Function that keeps reseting the Watchdog timer on the board
*******************************************************************************/
void  *DemoWatchDogFunction(
  void *lpParameter   // thread data
)
{
  OTX_RESULT result = OTX_S_OK;
  OTX_BOOL bEnabled;

  g_bWatchDogThreadActive = OTX_TRUE;

  DemoLogf("DemoWatchDogFunction Thread started\n");

  while (g_bWatchDogThreadActive) {

    result = OtxDrvGetAttributeValueBool(g_hPhysDevs.hBoardController0, 
                                         OTX_ATTR_BRD_WATCHDOG_TIMER_ENABLED,  
                                         &bEnabled); 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if (!bEnabled) {
      DemoLogf("\n*********** ");
      DemoLogf("Watchdog Timer timed out. Application must be restarted ");
      DemoLogf("***********\n");
      OsaThreadSleep(3000); // in milliseconds
      continue;
    }

    result = OtxDrvSetAttributeValueBool(g_hPhysDevs.hBoardController0, 
                                         OTX_ATTR_BRD_WATCHDOG_TIMER_RESET,  
                                         OTX_TRUE /* Any value will work */); 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    OsaThreadSleep(100); // in milliseconds
  }

  DemoLogf("DemoWatchDogFunction Thread terminating\n");
  return 0;

}


/*******************************************************************************
  @func
  Event handler for continuously answer a call on an FXO line.
  Used to report events to thread.
*******************************************************************************/
void  DemoEventFxoAnswerCaller(
  void *hwBase, 
  void *hwEvent, 
  void *hwParms,
  void *potsLiNum
)
{
  OTX_INT32  *pTmp1;
  OTX_UINT32 *pTmp2;
  OTX_UINT32 *pTmpLiNum;
  DemoHwEvent *pTmpEvent;

  pTmp1  = (OTX_UINT32 *) hwBase;
  pTmp2  = (OTX_UINT32 *) hwParms;
  pTmpLiNum  = (OTX_UINT32 *) potsLiNum;
  pTmpEvent = (DemoHwEvent *) hwEvent;

  // The following should be a queue but for this app a single
  // location will work.
  if(g_nContinuousAnswer) {
      // For now all we want is the event
    if (g_nFxoTaskCallEvent[*pTmpLiNum] == HwEvent_unused) {
        g_nFxoTaskCallEvent[*pTmpLiNum] = *pTmpEvent;
      }
  }

  if(g_nContinuousCalling) {
      // For now all we want is the event
    if (g_nFxoTaskCallEvent[*pTmpLiNum] == HwEvent_unused) {
        g_nFxoTaskCallEvent[*pTmpLiNum] = *pTmpEvent;
      }
  }

  return;
}

/*******************************************************************************
  @func
  Continuously answer a call on an FXO line
*******************************************************************************/
void  *DemoFxoAnswerCaller(
  void *lpParameter   // thread data
)
{
  OTX_UINT32 *pTmpPtr;
  OTX_UINT32 nPotsLiNumber;
  OTX_INT32  nHwBase  = 1;
  OTX_INT32  x;
  OTX_UINT32 nRingCnt = 0;
  OTX_UINT32 nLoopCnt = 0;
  OTX_UINT32 nWaitTime = DEMO_ANSWER_WAIT_TIME;
  OTX_BOOL nLiOffHook;
  OTX_RESULT result = OTX_S_OK;
  OTX_RESULT lastRecordedError;
  DemoDeviceCallState nLiState;

  pTmpPtr = (OTX_UINT32 *) lpParameter;
  nPotsLiNumber = *pTmpPtr; // Copy data locally

  nHwBase  = nPotsLiNumber;

  DemoInitializeEventHandler(nPotsLiNumber,
                             (void *) &nHwBase, 
                             DemoEventFxoAnswerCaller);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return((void *)&g_nDemoAppResultCode);
  }

  DemoLogf("---DemoFxoAnswerCaller Thread started FXO(%d)\n", nPotsLiNumber);

  OsaThreadSleep(500);

  g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;

  // Set Li to On-Hook so we know were we are
  DemoFxoTerminateCall(nPotsLiNumber, &nLiState);  
  
  // Stay here until user exit task or demo
  while (g_nContinuousAnswer) {
    OsaThreadSleep(40);

    if (g_nFxoTaskCallEvent[nPotsLiNumber] != HwEvent_unused) {

      switch (g_nFxoTaskCallEvent[nPotsLiNumber]) {

        case HwEvent_ring:
          DemoFxoIsLiOffHook(nPotsLiNumber,
                            &nLiOffHook,
                            &lastRecordedError);

          if(nLiOffHook) {
            // Offhook and ring signal. Maybe leftover ring event.
            // If more then 5 must be out on sync.
            if(nRingCnt > 5) {
              // Out of order, should be ONHOOK
              DemoLogf("\n");
              DemoLogf("---DemoFxoAnswerCaller Retry ONHOOK\n");
              DemoLogf("\n");

              DemoFxoTerminateCall(nPotsLiNumber, &nLiState );
              OsaThreadSleep(500); // Wait here to let thing settle
            }
          }
          else
          if(nRingCnt > 2) {
            // Answer the call
            DemoFxoAnswerCall(nPotsLiNumber, &nLiState );
            OsaThreadSleep(500); // give other side time to detect offhook
          }
          nRingCnt++;

          break;
        case HwEvent_digit_avail:
          // If we get a digit we must be connected
          DemoLogf("---DemoFxoAnswerCaller DTMF digit available\n");
        case HwEvent_connect:
          // Check to make sure we went offhook
          DemoFxoIsLiOffHook(nPotsLiNumber,
                            &nLiOffHook,
                            &lastRecordedError);

          if(!(nLiOffHook)) {
            // Out of order, should be OFFHOOK
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller Retry OFFHOOK\n");
            DemoLogf("\n");

            DemoFxoAnswerCall(nPotsLiNumber, &nLiState ); // Command lost retry
            OsaThreadSleep(500); // give other side time to detect offhook
          }


          // Check to make sure we went offhook
          DemoFxoIsLiOffHook(nPotsLiNumber,
                            &nLiOffHook,
                            &lastRecordedError);

          if(!(nLiOffHook)) {
            // Out of order, should be OFFHOOK
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller Error not able to go OFFHOOK\n");
            DemoLogf("\n");
          }
          else {

            DemoLogf("---DemoFxoAnswerCaller call connected\n");
            // Wait here for a while then disconnect
            for(x=nWaitTime; x>0; x--) {
              // Clear the last event, so we can get the new one
              g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;

              OsaThreadSleep(50);

              // Check to see if anything has happened,
              // like other end hanging up
              switch (g_nFxoTaskCallEvent[nPotsLiNumber]) {
                case HwEvent_ring:
                  if(nRingCnt > 5) {
                    DemoFxoTerminateCall(nPotsLiNumber, &nLiState );
                    OsaThreadSleep(200); // Wait here to let thing settle
                  }
                  DemoLogf("-----DemoFxoCalling ring\n");
                  break;
                case HwEvent_connect:
                  nRingCnt = 0;
                  DemoLogf("-----DemoFxoCalling call connected\n");
                  break;
                case HwEvent_digit_avail:
                  nRingCnt = 0;
                  DemoLogf("-----DemoFxoCalling DTMF digit available\n");
                  break;
                case HwEvent_init_completed:
                  DemoLogf("-----DemoFxoCalling Init Complete\n");
                  break;

                case HwEvent_error:
                  DemoLogf("-----Error event DemoFxoCalling received\n");
                case HwEvent_disconnect:
                  nRingCnt = 0;
                  DemoLogf("-----DemoFxoCalling call disconnected\n");
                case HwEvent_ring_tone:
                case HwEvent_busy_tone:
                  // Other end is slow to hangup the phone
                  DemoLogf("-----DemoFxoCalling far end terminated call early\n");
                  DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
                  nRingCnt = 0;
                  break;

                case HwEvent_unused:
                  break;

                case HwEvent_ptone_completed: // not supported at this time
                case HwEvent_buffer_arrived: 
                default:

                  // We have a driver event
                  // Printf the event data.
                  // In a real application branch based on the data
                  DemoLogf("----Unknown DemoFxoCalling event received\n");
                  DemoLogf("   g_nFxoTaskCallEvent = %d)\n", 
                           g_nFxoTaskCallEvent[nPotsLiNumber]);
                  nRingCnt = 0;
                  break;
              }
              g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
            }
          }

          g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
          // Hangup the phone
          DemoFxoTerminateCall(nPotsLiNumber, &nLiState );

          break;
        case HwEvent_disconnect:
          // Reset ring count for good measure
          nRingCnt = 0;
          nLoopCnt++;
          if(!(nLoopCnt%5)) {
            // Change answer timing
            nWaitTime = nWaitTime + 1;
            if(nWaitTime > (DEMO_ANSWER_WAIT_TIME * 2)) {
              nWaitTime = DEMO_ANSWER_WAIT_TIME;
            }
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller wait time is %d\n", nWaitTime);
            DemoLogf("\n");
          }

          if(!(nLoopCnt%10)) {
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller loop count %d\n", nLoopCnt);
            DemoLogf("---DemoFxoAnswerCaller wait time is %d\n", nWaitTime);
            DemoLogf("\n");
          }
          OsaThreadSleep(300); // give other side time to hangup

          // Check to make sure we went onhook
          DemoFxoIsLiOffHook(nPotsLiNumber,
                            &nLiOffHook,
                            &lastRecordedError);

          if(nLiOffHook) {
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller RETRY call termination\n");
            DemoLogf("\n");
            // Out of order, should be ONHOOK
            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
            OsaThreadSleep(500); // give other side time to hangup
          }

          // Check to make sure we went onhook
          DemoFxoIsLiOffHook(nPotsLiNumber,
                            &nLiOffHook,
                            &lastRecordedError);

          if(nLiOffHook) {
            DemoLogf("\n");
            DemoLogf("---DemoFxoAnswerCaller not able to hangup the phone\n");
            DemoLogf("---     Software Error, please exit answer thread.\n");
            DemoLogf("\n");
          }

          DemoLogf("---DemoFxoAnswerCaller call disconnected\n");
          break;
        case HwEvent_init_completed:
          DemoLogf("---DemoFxoAnswerCaller init complete\n");
          break;

        case HwEvent_busy_tone: // Not expected
        case HwEvent_ring_tone:
          nRingCnt = 0;
          DemoLogf("---DemoFxoAnswerCaller unexpected event (terminate call)\n");
          DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
        break;

        case HwEvent_error:
          DemoLogf("---Error event DemoFxoAnswerCaller received\n");
        case HwEvent_buffer_arrived: // not supported at this time
        case HwEvent_ptone_completed:
        default:
          nRingCnt = 0;
  
          // We have a driver event
          // Printf the event data.
          // In a real application branch based on the data
          DemoLogf("---Unknown DemoFxoAnswerCaller event received\n");
          DemoLogf("   g_nFxoTaskCallEvent = %d)\n", 
                   g_nFxoTaskCallEvent[nPotsLiNumber]);

          DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
          break;
      }

      // Clear the last event, so we can get the new one
      g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
    }
  } //  Make sure it is not time to exit thread

  // Cleanup befor exiting
  DemoFxoTerminateCall(nPotsLiNumber, &nLiState);

  // Remove event hanlder
  DemoInitializeEventHandler(nPotsLiNumber,
                             (void *) &nHwBase, 
                             NULL);
  return 0;
}


/*******************************************************************************
  @func
  Continuously makes a call on an FXO line
*******************************************************************************/
void  *DemoFxoCalling(
  void *lpParameter   // thread data
)
{
  OTX_UINT32 *pTmpPtr;
  OTX_UINT32 nPotsLiNumber;
  OTX_INT32  nHwBase  = 1;
  OTX_UINT32 nWaitForNextStateCnt = 0;
  OTX_UINT32 nRingCnt = 0;
  OTX_BOOL nLiOffHook;
  OTX_RESULT result = OTX_S_OK;
  OTX_RESULT lastRecordedError;
  DemoDeviceCallState nLiState;
  DemoDeviceCallState nEventHandlerState;
  DemoDeviceCallState nLiOurCurrentState = DEMO_ONHOOK;

  pTmpPtr = (OTX_UINT32 *) lpParameter;
  nPotsLiNumber = *pTmpPtr; // Copy data locally

  nHwBase  = nPotsLiNumber;

  DemoInitializeEventHandler(nPotsLiNumber,
                             (void *) &nHwBase, 
                             DemoEventFxoAnswerCaller);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return((void *)&g_nDemoAppResultCode);
  }

  // Set Li to On-Hook so we know were we are
  DemoFxoTerminateCall(nPotsLiNumber, &nLiState);  
  
  DemoLogf("+++DemoFxoCalling Thread started FXO(%d)\n", nPotsLiNumber);

  OsaThreadSleep(1000);

  // Check to see we did go on-hook
  DemoFxoGetLiState(nPotsLiNumber,
                    &nLiState,
                    &lastRecordedError);
  if(!((nLiState == DEMO_ONHOOK) || (nLiState == DEMO_MAKE_ONHOOK))) {
    DemoLogf("\n");
    DemoLogf("+++Error: DemoFxoCalling FXO(%d) is not On-Hook\n", nPotsLiNumber);
    DemoLogf("+++  Current state(%d) is %s\n", 
             nLiState, 
             g_sqszDeviceCallState[nLiState]);
    DemoLogf("\n");
  }

  g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;

  // Stay here until user exit task or demo
  while (g_nContinuousCalling) {
    OsaThreadSleep(500);

    if (g_nFxoTaskCallEvent[nPotsLiNumber] != HwEvent_unused) {

      switch (g_nFxoTaskCallEvent[nPotsLiNumber]) {

        case HwEvent_ring:
          DemoLogf("+++DemoFxoCalling ring\n");
          break;
        case HwEvent_connect:
          DemoLogf("+++DemoFxoCalling call connected\n");
          break;
        case HwEvent_disconnect:
          DemoLogf("+++DemoFxoCalling call disconnected\n");

          if(nLiOurCurrentState != DEMO_ONHOOK) {
            // We have a call open
            // Start our sequence again.
            nWaitForNextStateCnt = 0;
            // Clear the last event, so we can get the next one
            g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
            nLiOurCurrentState = DEMO_ONHOOK;
          }

          break;
        case HwEvent_digit_avail:
          DemoLogf("+++DemoFxoCalling DTMF digit available\n");
          break;
        case HwEvent_error:
          DemoLogf("+++Error event DemoFxoCalling received\n");
          break;
        case HwEvent_init_completed:
          DemoLogf("+++DemoFxoCalling Init Complete\n");
          break;
        case HwEvent_ring_tone:
          DemoLogf("+++DemoFxoCalling Ring Tone\n");
          nLiOurCurrentState = DEMO_RINGING;
          break;
        case HwEvent_busy_tone:
          // Other end is slow to hangup the phone
          DemoLogf("+++DemoFxoCalling busy tone start over\n");
          DemoLogf("+++    Hangup the FAR END phone.\n");
          if(nLiOurCurrentState == DEMO_OFFHOOK) {
            // We have a call open
            // Start our sequence again.
            nWaitForNextStateCnt = 0;
            // Clear the last event, so we can get the next one
            g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
            nLiOurCurrentState = DEMO_ONHOOK;
          }
          break;

        case HwEvent_ptone_completed: // not supported at this time
        case HwEvent_buffer_arrived: 
        default:
  
          // We have a driver event
          // Printf the event data.
          // In a real application branch based on the data
          DemoLogf("+++Unknown DemoFxoCalling event received\n");
          DemoLogf("   g_nFxoTaskCallEvent = %d)\n", 
                   g_nFxoTaskCallEvent[nPotsLiNumber]);
          break;
      }
      // Needed below for processing
      nEventHandlerState = g_nFxoTaskCallEvent[nPotsLiNumber];
      // Clear the last event, so we can get the next one
      g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
    }

    // See what our next state should be.
    switch (nLiOurCurrentState) {

      case DEMO_ONHOOK:
        DemoFxoIsLiOffHook(nPotsLiNumber,
                           &nLiOffHook,
                           &lastRecordedError);

        if(nLiOffHook) {
          if((nEventHandlerState == HwEvent_busy_tone) ||
             (nEventHandlerState == HwEvent_disconnect)) {
            // Call just terminated
            nWaitForNextStateCnt = 0;
          }
          else {
            nWaitForNextStateCnt = 0;

            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);

            DemoLogf("\n");
            DemoLogf("+++DemoFxoCalling not onhook RETRY terminate call\n");
            DemoLogf("\n");
          }
        }
        else {
          // Allow a pause between cycles
          nRingCnt = 0;
          nWaitForNextStateCnt++;
          // Only need to stop it one time
          if(DemoIsBurstDeviceEnabled()) {
            DemoFxoHaltBurstSendReceive(); // Stop BURST device
          }
          if(nWaitForNextStateCnt > 15) {

            // Clear the last event, so we can get the next one
            g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;

            // OFF-HOOK and dial number
            DemoFxoMakeCall(nPotsLiNumber,
                            &nLiState, 
                            g_DtmfPhoneStr);
            // Should check for busy tone, or other errors 
            // but let just move on to the next state.
            nLiOurCurrentState = DEMO_RINGING; // Phone should be ring
            nWaitForNextStateCnt = 0;
          }
        }
        break;

      case DEMO_STATE_CHANGE:
        nWaitForNextStateCnt++;
        nRingCnt++;
        if(!(nWaitForNextStateCnt % 5)) {
          // No ring signal detected
          nWaitForNextStateCnt = 0;
          nLiOurCurrentState = DEMO_OFFHOOK;
        }

        if(nRingCnt > 100) {
          DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
          // Start our sequence again.
          nWaitForNextStateCnt = 0;
          nRingCnt = 0;
          nLiOurCurrentState = DEMO_ONHOOK;
          // Clear the last event, so we can get the next one
          g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
          DemoLogf("\n");
          DemoLogf("+++DemoFxoCalling calling timeout start over\n");
          DemoLogf("+++   Far end is not answering phone.\n");
          DemoLogf("\n");
        }
        break;

      case DEMO_RINGING:
        // Maybe it is still being processed
        nRingCnt++;
        nWaitForNextStateCnt++;
        // If still ringing it will be set to ringing next
        // time we wake up.
        if(!(nRingCnt % 5)) {
          nWaitForNextStateCnt = 0;
          nLiOurCurrentState = DEMO_STATE_CHANGE;
        }

        if(nRingCnt > 100) {
          DemoFxoTerminateCall(nPotsLiNumber, &nLiState );
          // Start our sequence again.
          nWaitForNextStateCnt = 0;
          nRingCnt = 0;
          nLiOurCurrentState = DEMO_ONHOOK;
          // Clear the last event, so we can get the next one
          g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
          DemoLogf("\n");
          DemoLogf("+++DemoFxoCalling calling timeout start over\n");
          DemoLogf("+++   Far end is not answering phone.\n");
          DemoLogf("\n");
        }
        break;

      case DEMO_OFFHOOK:
        DemoFxoIsLiOffHook(nPotsLiNumber,
                          &nLiOffHook,
                          &lastRecordedError);

        if(nLiOffHook == OTX_FALSE) {
          // Maybe it is still being processed
          // or the far end hung up the phone
          nWaitForNextStateCnt++;
          if(nWaitForNextStateCnt > 2) {
            if(nWaitForNextStateCnt > 3) {
              // This could indicate the phone was offhook but
              // is now onhook. 
              DemoLogf("\n");
              DemoLogf("+++DemoFxoCalling Li went onhook out of sequence\n");
              DemoLogf("\n");
            }
            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
            // Start our sequence again.
            nWaitForNextStateCnt = 0;
            nLiOurCurrentState = DEMO_ONHOOK;
            // Clear the last event, so we can get the next one
            g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
            DemoLogf("\n");
            DemoLogf("+++DemoFxoCalling calling timeout start over\n");
            DemoLogf("\n");
          }
        }
        else {
          // Time for our next step which is to wait for other end to answer
          nWaitForNextStateCnt++;
          if(nWaitForNextStateCnt % 6) {
            if(DemoIsBurstDeviceEnabled()) {
              DemoFxoHaltBurstSendReceive(); // Stop BURST device
            }
            else {
              result =
              DemoFxoSetupBurstSendReceive(g_pRecvFile, 
                                           g_pSendFile,
                                           nPotsLiNumber, // Record test FXO
                                           0); // Only sending data on channel 0
              if(result == OTX_E_IN_USE) {
                DemoLogf("\n");
                DemoLogf("+++DemoFxoCalling Burst device still enabled. Closing\n");
                DemoLogf("\n");
                // Start our sequence again.
                nWaitForNextStateCnt = 0;
                // Clear the last event, so we can get the next one
                g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
                DemoFxoTerminateCall(nPotsLiNumber, &nLiState );
              }
              else
              if(OTX_FAILURE(result)) {
                DemoLogf("\n");
                DemoLogf("+++DemoFxoCalling Burst device not working.\n");
                DemoLogf("+++   Terminate calling task. SW Error\n");
                DemoLogf("\n");
              }
            }
          }

          if(nWaitForNextStateCnt > 50) {
            // Start our sequence again.
            nWaitForNextStateCnt = 0;
            // Clear the last event, so we can get the next one
            g_nFxoTaskCallEvent[nPotsLiNumber] = HwEvent_unused;
            DemoFxoTerminateCall(nPotsLiNumber, &nLiState);
            nLiOurCurrentState = DEMO_ONHOOK;
          }
        }

        break;

      default:
        break;
    }
  } //  Make sure it is not time to exit thread

  // Cleanup befor exiting
  DemoFxoTerminateCall(nPotsLiNumber, &nLiState ); // Phone Onhook

  // Remove event hanlder
  DemoInitializeEventHandler(nPotsLiNumber,
                             (void *) &nHwBase, 
                             NULL);
  return 0;
}

/*******************************************************************************
  @func
    Only used by the USER_APPLICATION device for debugging of DSP program code.
*******************************************************************************/
void DemoPrintCSTEvent(OtxEventDataS *pEventData) 
{
  OTX_RESULT otxRc;
  char msgStr[256];
  
  if (pEventData->m_nCode == OTX_USER_APPLICATION_EC_READ_DATA) {
    OTX_UINT8  buf[8192];
    OTX_UINT32 nBytesReturned;
    OTX_UINT32 nIoControlCode;      
    
    otxRc = OtxDspReadData(pEventData->m_hDevice, 
                           OTX_TASK_SYNC, 
                           buf, 
                           8192, 
                           &nBytesReturned, 
                           &nIoControlCode);
    if (OTX_RESULT_CODE(otxRc) == OTX_S_OK) {
      switch(nIoControlCode) {
      case 0x2ff:
        {
          char strBuf[1024];
          int k;
          sprintf(strBuf, "Len=%d :",nBytesReturned);
          for(k=0;k<(int)nBytesReturned;k+=2){
            sprintf(&strBuf[0] + strlen(strBuf), "%c",buf[k]);
          }
          sprintf(&strBuf[0] + strlen(strBuf), "\n");
          DemoLogf(strBuf);
        }
        break;
        
      case 0x0200 /*DEMO1_NOTIFY_DEBUG_DATA*/:
        {
          DemoLogf("DEMO1_NOTIFY_DEBUG_DATA (nRequestId=%d, nBytes=%d)\n", 
                   pEventData->m_nRequestId, nBytesReturned);
        }
        break;

      case 0x02FE:
        {
          static int counter = 0;

          if (counter++ % 5000 == 0) {
            DemoLogf("Got data\n");
          }

          if (g_fStreamFile) {
            fwrite((OTX_UINT8 *)buf, 
                   nBytesReturned, 
                   sizeof(OTX_UINT8), 
                   g_fStreamFile);
          }

        }
        break;
      default:
        DemoLogf("Unknown IoControlCode received in OtsDspReadData"
                 " (nIoControlCode = %d, nBytesReturned=%d, nRequestId=%d)\n", 
                 nIoControlCode, 
                 nBytesReturned, 
                 pEventData->m_nRequestId);
        break;
      }
    } else {
      OTX_RESULT errorCode = otxRc;
      otxRc = OtxDrvResultCode2String(pEventData->m_hDevice, 
                                      errorCode, 
                                      256, 
                                      &msgStr[0]);
      if (OTX_SUCCESS(otxRc)) {
        DemoLogf("User App[%d] Error: %s \n", 
                 pEventData->m_nSourceId, 
                 msgStr);
      } else {
        DemoLogf("User App[%d] Invalid Error Code: %ld\n", 
                 pEventData->m_nSourceId, 
                 errorCode);
      }
      
    }
    
  } else {
    
    otxRc = OtxDrvEventCode2String(pEventData->m_hDevice, 
                                   pEventData->m_nCode, 
                                   256, 
                                   &msgStr[0]);
    if (OTX_SUCCESS(otxRc)) {
      DemoLogf("User App[%d] Event: %s (nRequestId=%d)\n", 
               pEventData->m_nSourceId, 
               msgStr, 
               pEventData->m_nRequestId);
    } else {
      DemoLogf("User App[%d] Invalid Event: %ld (nRequestId=%d)\n", 
               pEventData->m_nSourceId, 
               pEventData->m_nCode, 
               pEventData->m_nRequestId);
    }
  }
}


/*******************************************************************************

  @func

  Convert a CPT (Call Progress Tone) Detection parameter to a string.

  @comm

*******************************************************************************/
static char *DemoCptParamToStr(int nParam) 
{
  static char strBuf[128];

  switch (nParam) {

  case OTX_CST_CPT_DETECTOR_NO_TONE:        
    return "Silence, No tone";
  case OTX_CST_CPT_DETECTOR_DIAL_TONE:      
    return "Dial Tone";
  case OTX_CST_CPT_DETECTOR_RING_TONE:      
    return "Ring Tone";
  case OTX_CST_CPT_DETECTOR_BUSY_TONE:      
    return "Busy Tone";
  case OTX_CST_CPT_DETECTOR_FASTBUSY_TONE:  
    return "FastBusy Tone";
  case OTX_CST_CPT_DETECTOR_LONG_TONE:      
    return "Long lasting tone for 1 second";
  case OTX_CST_CPT_DETECTOR_END_OF_TONE:    
    return "End of current tone";
  default: // Error
    // DemoLogf("Unrecognized CPT tone parameter (%d)\n", nParam);
    sprintf(strBuf, "Unrecognized CPT Parameter (nParam=0x%X)", nParam);
    return strBuf;
  }
}



/*******************************************************************************
  @func
    FXO Function that check for Events from the OTX Driver
*******************************************************************************/
void DemoFxoEvent(OtxEventDataS *pEventData)
{
  OTX_RESULT otxRc;
  char msgStr[256];

  switch (pEventData->m_eDeviceType) {
    
  case OTX_LDEVICE_USER_APPLICATION:
    // Events from the DspDemo1.out logical devices
    DemoPrintCSTEvent(pEventData);
    break;

  case OTX_DEVICE_DSP:
    {
      // Non-logical device related event from the DSPs
      otxRc = OtxDrvEventCode2String(pEventData->m_hDevice, 
                                     pEventData->m_nCode, 
                                     256, 
                                     &msgStr[0]);
      if (OTX_SUCCESS(otxRc)) {
        DemoLogf("DSP[%d] Event: %s \n", 
                 pEventData->m_nSourceId, 
                 msgStr);
      } else {
        DemoLogf("DSP[%d] Invalid Event: %ld \n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
      }
    }
    break;
    
  case OTX_LDEVICE_CST_DTMF_DIALER:
    {
      switch (pEventData->m_nCode) {
      case OTX_CST_DTMF_DIALER_EC_COMPLETE:
        DemoProcessDrvEvent(DEMO_DTMF_TRANISTION,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);

        break;
      default:
        DemoLogf("DtmfDialer[%d] Invalid Event: %ld \n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      }
    }
    break;


  case OTX_LDEVICE_CST_CPT_DETECTOR:
    {
      // Event from Cpt Detector
      switch (pEventData->m_nCode) {
      case OTX_CST_CPT_DETECTOR_EC_MTONESTART:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("CptDetector[%d] MTONESTART, %s\n", 
                     pEventData->m_nSourceId,
                     DemoCptParamToStr(pEventData->m_nParam));
          }
        }
        break;
        
      case OTX_CST_CPT_DETECTOR_EC_MTONE:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("CptDetector[%d] MTONE, Tone confirmed, %s\n", 
                     pEventData->m_nSourceId, 
                     DemoCptParamToStr(pEventData->m_nParam));
          }
        }
        break;
        
      case OTX_CST_CPT_DETECTOR_EC_MSIGNALEND:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("CptDetector[%d] MSIGNALEND, %s\n", 
                     pEventData->m_nSourceId, 
                     DemoCptParamToStr(pEventData->m_nParam));
          }

          switch (pEventData->m_nParam) {
            case OTX_CST_CPT_DETECTOR_NO_TONE:        
              break;
            case OTX_CST_CPT_DETECTOR_DIAL_TONE:      
              break;
            case OTX_CST_CPT_DETECTOR_RING_TONE:      
              // Ring Tone
            case OTX_CST_CPT_DETECTOR_BUSY_TONE:
              // Busy Tone
              DemoProcessDrvEvent(DEMO_TONE_DETECTED,        
                                  DEMO_FXO_POTS_TYPE, 
                                  pEventData->m_nSourceId,
                                  pEventData);
              
              break;
            case OTX_CST_CPT_DETECTOR_FASTBUSY_TONE:  
              break;
            case OTX_CST_CPT_DETECTOR_LONG_TONE:      
              break;
            case OTX_CST_CPT_DETECTOR_END_OF_TONE:    
              break;
            default: // Error
              DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                                  DEMO_FXO_POTS_TYPE, 
                                  pEventData->m_nSourceId,
                                  pEventData);
              break;
            }

        }
        break;
        
      case OTX_CST_CPT_DETECTOR_EC_MFAIL:
        {
          DemoLogf("CptDetector[%d] MFAIL, %s\n", 
                   pEventData->m_nSourceId, 
                   DemoCptParamToStr(pEventData->m_nParam));
        }
        break;
        
      case OTX_CST_CPT_DETECTOR_EC_MPATTERNEND:
        {
          DemoLogf("CptDetector[%d] MPATTERNEND, %s\n", 
                   pEventData->m_nSourceId, 
                   DemoCptParamToStr(pEventData->m_nParam));
        }
        break;
        
      default:
        DemoLogf("CptDetector[%d] Invalid Event: %ld \n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
        
      }
    }
    break;

  case OTX_LDEVICE_CST_DTMF_DETECTOR:
    {
      // Event from Dtmf Detector
      switch (pEventData->m_nCode) {
      case OTX_CST_DTMF_DETECTOR_EC_MTONESTART:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("DtmfDetector[%d] MTONE, DTMF tone detection started\n", 
                      pEventData->m_nSourceId);

            // This will produce two input digits. If you need to know
            // when the digit starts then maybe a new event is needed
            // to keep start and confirmed seperated.
            DemoProcessDrvEvent(DEMO_DIGIT_START_AVAILABLE,        
                                DEMO_FXO_POTS_TYPE, 
                                pEventData->m_nSourceId,
                                pEventData);
          }
        }
        break;
        
      case OTX_CST_DTMF_DETECTOR_EC_MTONE:
        {
          // Tone is confirmed
          DemoProcessDrvEvent(DEMO_DIGIT_AVAILABLE,        
                              DEMO_FXO_POTS_TYPE, 
                              pEventData->m_nSourceId,
                              pEventData);
        }
        break;
        
      case OTX_CST_DTMF_DETECTOR_EC_MSIGNALEND:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("DtmfDetector[%d] MSIGNALEND, DTMF digit %c\n", 
                     pEventData->m_nSourceId, 
                     DemoDtmfParamToChar(pEventData->m_nParam));
          }
        }
        break;
        
      case OTX_CST_DTMF_DETECTOR_EC_MFAIL:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("DtmfDetector[%d] MFAIL\n", pEventData->m_nSourceId);
          }
        }
        break;
        
      case OTX_CST_DTMF_DETECTOR_EC_MPATTERNEND:
        {
          if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
            DemoLogf("DtmfDetector[%d] MPATTERNEND\n", pEventData->m_nSourceId);
          }
        }
        break;
        
      default:
        DemoLogf("DtmfDetector[%d] Invalid Event: %ld \n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
        
      }
    }
    break;

  case OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR:
    {
      switch (pEventData->m_nCode) {
      case OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_NOISE:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("VoiceActivityDetector[%d] Noise present\n", 
                 pEventData->m_nSourceId);
        }
        break;
      case OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_NOISE_HANGOVER:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("VoiceActivityDetector[%d] Noise Hangover. "
                 "Possibly turning into voice.\n", 
                 pEventData->m_nSourceId);
        }
        break;
      case OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_VOICE:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("VoiceActivityDetector[%d] Voice present\n", 
                 pEventData->m_nSourceId);
        }
        break;
      case OTX_CST_VOICE_ACTIVITY_DETECTOR_EC_VOICE_HANGOVER:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("VoiceActivityDetector[%d] Voice Hangover. "
                 "Had voice, but possibly turning into noise.\n", 
                 pEventData->m_nSourceId);
        }
        break;
      default:
        DemoLogf("VoiceActivityDetector[%d] Invalid Event: %ld \n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      }
    }
    break;


  case OTX_LDEVICE_CST_LI_POTS:
    {
      OTX_UINT32 potsLiNumber = pEventData->m_nSourceId;
      // Event from Pots Li
      switch (pEventData->m_nCode) {

      case OTX_CST_POTS_RING_SIGNAL_DETECTED:        
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("PotsLi[%d] A ring signal has been detected\n", 
                   pEventData->m_nSourceId);
        }
        DemoProcessDrvEvent(DEMO_RINGING,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_END_RING_SIGNAL_DETECTED:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("PotsLi[%d] End of ring signal has been detected\n", 
                 pEventData->m_nSourceId);
        }
        DemoProcessDrvEvent(DEMO_STOP_RINGING,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_AUTO_END_RING_SIGNAL_DETECTED:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("PotsLi[%d] End of ring signal due to offhook has been detected\n", 
                 pEventData->m_nSourceId);
        }
        DemoProcessDrvEvent(DEMO_OFFHOOK,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);

        DemoProcessDrvEvent(DEMO_STOP_RINGING,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_TIP_RING_REVERSAL_DETECTED:
        DemoLogf("PotsLi[%d] Tip/Ring reversal detected. "
                 "The other end hung up upon us.\n", 
                 pEventData->m_nSourceId);
        break;
      case OTX_CST_POTS_CALLER_ID_DETECTED:
        DemoProcessDrvEvent(DEMO_CALLER_ID,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);

        break;
      case OTX_CST_POTS_OFF_HOOK_COMPLETE:
        DemoProcessDrvEvent(DEMO_OFFHOOK,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_ON_HOOK_COMPLETE:
        DemoProcessDrvEvent(DEMO_ONHOOK,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_ON_HOOK_LINE_MON_COMPLETE:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("PotsLi[%d] On-Hook Line Monitor mode command complete\n", 
                 pEventData->m_nSourceId);
        }
        DemoProcessDrvEvent(DEMO_ONHOOK,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
        break;
      case OTX_CST_POTS_SENSE_LINE_COMPLETE:
        if(pEventData->m_nSourceId < DEMO_LI_MAX) {
          g_sPotsDevs[potsLiNumber].mFxsLi.nLiLastSense = pEventData->m_nParam;
        }

        if(pEventData->m_nParam == 0) {
          // No voltage or current. Li is not connected to an active port
          // or the far end just hungup
          DemoProcessDrvEvent(DEMO_FAR_END_HANGUP,        
                              DEMO_FXO_POTS_TYPE, 
                              pEventData->m_nSourceId,
                              pEventData);

        }
        else
        if(g_sPotsDevs[pEventData->m_nSourceId].mFxoLi.bOffHook) {
          // We are in the OffHook state so line sensing will 
          // return loop current (3mA per bit)
          if(g_bLineSensePending[potsLiNumber] == OTX_TRUE) {
            g_bLineSensePending[potsLiNumber] = OTX_FALSE;
            DemoLogf("PotsLi[%d] Sense line command complete. "
                     "Loop current = %d mA (%d) above minimum\n", 
                     pEventData->m_nSourceId, 
                     3 * pEventData->m_nParam, 
                     pEventData->m_nParam);
          }
        } else {
          double nVal = 2.75 * pEventData->m_nParam;
          // We are in the OnHook state so line sensing will 
          // return line voltage (2.75V per bit)
          if(g_bLineSensePending[potsLiNumber] == OTX_TRUE) {
            g_bLineSensePending[potsLiNumber] = OTX_FALSE;
            DemoLogf("PotsLi[%d] Sense line command complete. "
                     "Line voltage = %2.1f V  (%d)\n", 
                     pEventData->m_nSourceId, 
                     (double) nVal, 
                     pEventData->m_nParam);
          }
        }
        break;
      case OTX_CST_POTS_PULSE_GEN_COMPLETE:
        if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
          DemoLogf("PotsLi[%d] Pulse Generator command complete\n", 
                 pEventData->m_nSourceId); 
        }
        break;
      case OTX_CST_POTS_READ_REG_COMPLETE:
#if 0 // Sense line testing put this back when finished
        DemoLogf("PotsLi[%d] ReadReg command complete Val=%d\n", 
                  pEventData->m_nSourceId, 
                  pEventData->m_nParam);
#endif
        break;
      case OTX_CST_POTS_WRITE_REG_COMPLETE:
        DemoLogf("PotsLi[%d] WriteReg command complete\n", 
                 pEventData->m_nSourceId);
        break;
      default:
        // Unexpected event from this device
        DemoLogf("PotsLi[%d] Unexpected Event (%d)\n", 
                 pEventData->m_nSourceId, 
                 pEventData->m_nCode);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXO_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);
      }
    }
    break;
  default:
    {
      // Unhandled event
      DemoLogf("FXO Event from an unknown object 0x%X\n", pEventData->m_hDevice);

      DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                          DEMO_FXO_POTS_TYPE, 
                          pEventData->m_nSourceId,
                          pEventData);
    }
    break;    
  }

  return;
}


/*******************************************************************************
  @func
    FXS Function that check for Events from the OTX Driver
*******************************************************************************/
void DemoFxsEvent(OtxEventDataS *pEventData)
{
  OTX_UINT32 slicState = 0;

// If no FXS lines are needed then there is no need to process the event.
#if DEMO_FXS_MAX != 0
  if(pEventData->m_eDeviceType == OTX_DEVICE_LI_SLIC) {
    // Determine the event
    switch (pEventData->m_nCode) {
      // Pulse Metering Active Timer Interrupt
      case (OTX_SLIC_PULSE_INACTIVE):
      // Pulse Metering Inactive Timer Interrupt
      case (OTX_SLIC_PULSE_ACTIVE):
      // Ring Trip Interrupt
      case (OTX_SLIC_RING_TRIP):  
      // Loop Closure Transition Interrupt
      case (OTX_SLIC_LOOP_STATE):  
      // Indirect Register Access Serviced
      case (OTX_SLIC_INDIRECT_ACCESS_RDY):
      // Common Mode Calibration Error
      case (OTX_SLIC_ERROR_CM_CAL):  
      // Continue Ringing Active Timer
      case (OTX_SLIC_RING_INACTIVE_CONT):  
      // Oscillator 1 Active Timer Interrupt
      case (OTX_SLIC_OSC1_INACTIVE):
      // Oscillator 1 Inactive Timer Interrupt
      case (OTX_SLIC_OSC1_ACTIVE):  
      // Oscillator 2 Active Timer Interrupt
      case (OTX_SLIC_OSC2_INACTIVE):
      // Oscillator 2 Inactive Timer Interrupt
      case (OTX_SLIC_OSC2_ACTIVE): 
      // Ringing Active Timer Interrupt
      case (OTX_SLIC_RING_INACTIVE):
      // Ringing Inactive Timer Interrupt.
      case (OTX_SLIC_RING_ACTIVE):  
        // Nothing more to do here
        break;

      // Power Alarm Q1 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ1):  
      // Power Alarm Q2 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ2):  
      // Power Alarm Q3 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ3):  
      // Power Alarm Q4 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ4):  
      // Power Alarm Q5 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ5):  
      // Power Alarm Q6 Interrupt
      case (OTX_SLIC_PWR_ALARM_PQ6):
        DemoLogf("    FXS[%d] Power Alarm!\n", pEventData->m_nSourceId);

        DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                            DEMO_FXS_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);                
        break;

      // DTMF Tone Detected
      case (OTX_SLIC_DTMF_DETECT):
        // DTMF digit is passed with event
        g_rawDigit = (OTX_UINT8) pEventData->m_nParam;
        DemoLogf("    FXS[%d] DTMF digit detected %X\n", 
                 pEventData->m_nSourceId,
                 g_rawDigit);

        break;

      // Slic indicates OFFHOOK condition
      case (OTX_SLIC_OFF_HOOK):  

        DemoProcessDrvEvent(DEMO_OFFHOOK,        
                            DEMO_FXS_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);

        // SLIC is off hook setup connection FSO to FXS
        DemoLogf("    FXS[%d] Off Hook phone making connection\n", 
                 pEventData->m_nSourceId);                               
        break;
      // Slic indicates ONHOOK condition
      case (OTX_SLIC_ON_HOOK):

        DemoProcessDrvEvent(DEMO_ONHOOK,        
                            DEMO_FXS_POTS_TYPE, 
                            pEventData->m_nSourceId,
                            pEventData);                
        break;

    default:
      DemoLogf("FXS[%d] Unknown Event: %ld \n", 
               pEventData->m_nSourceId, 
               pEventData->m_nCode);

      DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                          DEMO_FXS_POTS_TYPE, 
                          pEventData->m_nSourceId,
                          pEventData);
      break;
    }
  }
  else {
    DemoLogf("FXS[%d] Unknown m_eDeviceType %ld: m_nCode %ld \n",
             pEventData->m_nSourceId, 
             pEventData->m_eDeviceType,
             pEventData->m_nCode);


      DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                          DEMO_FXS_POTS_TYPE, 
                          pEventData->m_nSourceId,
                          pEventData);
  }
#else
  DemoLogf("FXS[%d] Unknown Event: %ld \n", 
           pEventData->m_nSourceId, 
           pEventData->m_nCode);
  DemoLogf("FXS interface is not enabled \n");
#endif

  return;
}

/*******************************************************************************
  @func
    Idle Function that check for Events from the OTX Driver
*******************************************************************************/
void  *DemoPotsLiFunction(
  void *lpParameter   // thread data
)
{
  OTX_UINT32 *pTmp; // Line number for this LI is passed in
  OTX_UINT32 nPotsLi; // Line number for this LI is passed in
  OTX_UINT32 nSlicState = 0;
  OtxEventDataS eventData;
  OTX_RESULT result = OTX_S_OK;

  pTmp = (OTX_UINT32 *) lpParameter; // Line number for this LI is passed in 
  nPotsLi = *pTmp; // Copy it into our memory
  DemoLogf("PotsLi[%d] Event Task Started\n", nPotsLi);
  

  while (1) {
    OtxDrvWaitForSingleEvent(g_sPotsDevs[nPotsLi].hNotificationEvent, 
                             OTX_TIME_INFINITY);
    //DemoLogf("Event signalled\n");
    do {
      result = OtxDrvGetEventData(g_sPotsDevs[nPotsLi].hEventQueue, &eventData); 
      DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);

      // One task is start per line (FXO/FXS). The eventData.m_nSourceId 
      // should be the same as the nPotsLi.
      if(nPotsLi != eventData.m_nSourceId) {
        if (OTX_RESULT_CODE(result) == OTX_S_OK) {
          DemoLogf("Error DemoPotsLiFunction[%d] received an event from LI(%d)\n",
                   nPotsLi,
                   eventData.m_nSourceId);
        }
      }
      else
      if (OTX_RESULT_CODE(result) == OTX_S_OK) {

        switch (eventData.m_eDeviceType) {

          case OTX_DEVICE_LI_SLIC:
            DemoFxsEvent(&eventData);
            break;

          case OTX_DEVICE_DSP:
          case OTX_LDEVICE_CST_DTMF_DIALER:
          case OTX_LDEVICE_CST_CPT_DETECTOR:
          case OTX_LDEVICE_CST_DTMF_DETECTOR:
          case OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR:
          case OTX_LDEVICE_CST_LI_POTS:
            DemoFxoEvent(&eventData);
            break;

          default:
        
            // We have a driver event
            // Printf the event data.
            // In a real application branch based on the data
            DemoPrintEvent(&eventData);
            break;
        }    
      }
    } while (OTX_RESULT_CODE(result) == OTX_S_OK);
  }

  return 0;
}


/*******************************************************************************
  @func
    Idle Function that check for Events from the OTX Driver
*******************************************************************************/
void  *DemoIdleFunction(
  void *lpParameter   // thread data
)
{
  OTX_INT32 i;
  OTX_UINT32 hookStatus;
  OTX_UINT32 slicState = 0;
  OtxEventDataS eventData;
  OTX_RESULT result = OTX_S_OK;

  // Give devices time to setup
  OsaThreadSleep(500);

  // setup FXS interface
  i = g_firstUsableLi;
  while(i < g_fxsLiInitialized) {
    OtxSlicGetHookState( g_hPhysDevs.hSlicLi[i], &hookStatus );
    if(hookStatus == OTX_SLIC_OFF_HOOK) {
      g_sPotsDevs[i].mFxsLi.bOffHook = OTX_TRUE;
    }
    else {
      g_sPotsDevs[i].mFxsLi.bOffHook = OTX_FALSE;
    }
    g_sPotsDevs[i].mFxsLi.nCallState = hookStatus;

    DemoLogf("FXS[%d] Hook Status %d \n", i, hookStatus);
    i++;
  }

  // Setup FXO interface
  i = g_firstUsableLi;
  while(i < g_fxoLiInitialized) {

    hookStatus = 0xFF; // Need to get this from DSP
    DemoLogf("FXO[%d] Hook Status %d \n", i, hookStatus);

    i++;
  }


  while (1) {
    OtxDrvWaitForSingleEvent(g_hNotificationEvent, OTX_TIME_INFINITY);
    //DemoLogf("Event signalled\n");
    do {
      result = OtxDrvGetEventData(g_hEventQueue, &eventData); 
      DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);

      if (OTX_RESULT_CODE(result) == OTX_S_OK) {

        switch (eventData.m_eDeviceType) {

          case OTX_DEVICE_LI_SLIC:
            // These events should be processed by DemoPotsLiFunction
            DemoLogf("FXS[%d] Receiced Event from Board Event Queue\n", 
                     eventData.m_nSourceId);
            DemoFxsEvent(&eventData);
            break;

          case OTX_DEVICE_DSP:
          case OTX_LDEVICE_CST_DTMF_DIALER:
          case OTX_LDEVICE_CST_CPT_DETECTOR:
          case OTX_LDEVICE_CST_DTMF_DETECTOR:
          case OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR:
          case OTX_LDEVICE_CST_LI_POTS:
            // These events should be processed by DemoPotsLiFunction
            DemoFxoEvent(&eventData);
            break;

          default:
        
            // We have a driver event
            // Printf the event data.
            // In a real application branch based on the data
            DemoPrintEvent(&eventData);
            break;
        }    
      }
    } while (OTX_RESULT_CODE(result) == OTX_S_OK);
  }

  return 0;

}





/*******************************************************************************
  @func
    Burst Sender Function
*******************************************************************************/
void DemoBurstSender(OTX_UINT32 nSourceId)
{
  OTX_RESULT  otxRc;
  OTX_UINT32  ui32;


  // validate parameters
  if (nSourceId != 0) {
    DemoLogf("DemoBurstSender: Invalid nSourceId(%d)!\n", nSourceId);
    return;
  }

  if (!g_sBurstDevs.mBurstSender.bActive) {
    // we're not active, so just return
    return;
  }

  if (g_sBurstDevs.mBurstSender.pTxFile) {
    // Prime the transmit buffer with 0xFF 
    // (only really needed for single TS transmission)
    memset(&g_sBurstDevs.mBurstSender.sqTxBuf[0], 
           0xFF, 
           sizeof(g_sBurstDevs.mBurstSender.sqTxBuf) / sizeof(g_sBurstDevs.mBurstSender.sqTxBuf[0]));

    if (g_sBurstDevs.mBurstSender.nTsToSend == -1) {
      // All TS
      g_sBurstDevs.mBurstSender.cbTxBuf = fread(
        &g_sBurstDevs.mBurstSender.sqTxBuf,
        sizeof(g_sBurstDevs.mBurstSender.sqTxBuf[0]),
        sizeof(g_sBurstDevs.mBurstSender.sqTxBuf) / sizeof(g_sBurstDevs.mBurstSender.sqTxBuf[0]),
        g_sBurstDevs.mBurstSender.pTxFile
      );

    } else {
      // Single TS
      OTX_UINT8 singleTsBuf[DEMO_BURST_BUF_SIZE / 32];
      int cbSingleTsBuf;
      int byteCount = 0;
      int x;
      
      cbSingleTsBuf = fread(
        &singleTsBuf,
        sizeof(singleTsBuf[0]),
        sizeof(singleTsBuf) / sizeof(singleTsBuf[0]),
        g_sBurstDevs.mBurstSender.pTxFile
        );

      
      // Dispurse the single TS to be transmitted in the whole transmit buffer 
      byteCount = 0;
      for ( x = g_sBurstDevs.mBurstSender.nTsToSend; 
            (byteCount < cbSingleTsBuf) && (x < DEMO_BURST_BUF_SIZE); 
            x += 32
          ) {
        g_sBurstDevs.mBurstSender.sqTxBuf[x] = singleTsBuf[byteCount++];
      }
      
      assert(byteCount == cbSingleTsBuf);
      g_sBurstDevs.mBurstSender.cbTxBuf = cbSingleTsBuf * 32;

      if (!feof(g_sBurstDevs.mBurstSender.pTxFile)) {
        assert(g_sBurstDevs.mBurstSender.cbTxBuf == DEMO_BURST_BUF_SIZE);
      } else {
        DemoLogf("DemoBurstSender[%d]: Reached EOF\n", nSourceId);
      }

    }
        
    if (g_sBurstDevs.mBurstSender.cbTxBuf > 0) {

      ui32 = g_sBurstDevs.mBurstSender.cbTxBuf;
      otxRc = OtxBurstSendData(g_hPhysDevs.hBurst, 
                               nSourceId, 
                               g_sBurstDevs.mBurstSender.sqTxBuf, 
                               &ui32);
      DemoCheckRc(g_hPhysDevs.hBurst, otxRc);

      // check the amount buffered w/ how much we requested to be buffered
      //  (since we set the trigger amount to the buffer size, there should
      //    have been room to buffer this, so these two should be the same).
      if((ui32 != g_sBurstDevs.mBurstSender.cbTxBuf) &&
         (g_sBurstDevs.mBurstSender.bVerbose)) {
        DemoLogf("DemoBurstSender[%d]: Burst buffer transmit size error\n", 
                nSourceId);
        DemoLogf("    Expected transfer size %d\n", 
                g_sBurstDevs.mBurstSender.cbTxBuf);
        DemoLogf("    Actual transfer size %d\n", ui32);
      }
      
      // This buffer was not full must be at the end of the file
      if(g_sBurstDevs.mBurstSender.cbTxBuf < DEMO_BURST_BUF_SIZE) {
        // Check to see if we need to start over
        if (g_sBurstDevs.mBurstSender.bFileLoop) {
          if (g_sBurstDevs.mBurstSender.bVerbose) {
            DemoLogf("DemoBurstSender[%d]: Transmission complete. \n"
                     "    Starting file from the beginning.\n", nSourceId);
          }
          // This process can take longer then allowed. Burst
          // device may still have underflow data error.
          rewind(g_sBurstDevs.mBurstSender.pTxFile);
        }
      }

    } else {

      if (g_sBurstDevs.mBurstSender.bFileLoop) {
        if (g_sBurstDevs.mBurstSender.bVerbose) {
          DemoLogf("DemoBurstSender[%d]: Transmission complete. "
                   "Starting file from the beginning.\n", nSourceId);
        }
        // This process can take longer then allowed. Burst
        // device may have underflow data error.
        rewind(g_sBurstDevs.mBurstSender.pTxFile);
      } else {
        DemoLogf("DemoBurstSender[%d]: Transmission complete. "
                 "Closing file\n", nSourceId);

        DemoFxoHaltBurstSendReceive();
      }
    }

  } else {
    // Send a text string (continously until aborted)

    // we MUST round amount to send to be bounded on the number of 
    // TS the highway hosts. (the buffer is representative of a burst
    // DMA buffer for all TS on the highway hosted, TS0-TSn)

    g_sBurstDevs.mBurstSender.cbTxBuf = g_sBurstDevs.mBurstSender.cbTxBuf;
    assert(g_sBurstDevs.mBurstSender.cbTxBuf == DEMO_BURST_BUF_SIZE);

    ui32 = g_sBurstDevs.mBurstSender.cbTxBuf;
    otxRc = OtxBurstSendData(g_hPhysDevs.hBurst, 
                             nSourceId, 
                             g_sBurstDevs.mBurstSender.sqTxBuf, 
                             &ui32);
    DemoCheckRc(g_hPhysDevs.hBurst, otxRc);

    // check the amount buffered w/ how much we requested to be buffered
    //  (since we set the trigger amount to the buffer size, there should
    //    have been room to buffer this, so these two should be the same).
    if(ui32 != g_sBurstDevs.mBurstSender.cbTxBuf) {
       DemoLogf("DemoBurstSender[%d]: Burst buffer transmit size error\n", 
                nSourceId);
       DemoLogf("    Expected transfer size %d\n", 
                g_sBurstDevs.mBurstSender.cbTxBuf);
       DemoLogf("    Actual transfer size %d\n", ui32);
    }    
  }

  return;
}

/*******************************************************************************
  @func
    Burst Receiver Function
*******************************************************************************/
void DemoBurstReceiver(OTX_UINT32 nSourceId)
{
  OTX_RESULT    otxRc;
  OTX_UINT8     buf[DEMO_BURST_BUF_SIZE];
  OTX_UINT32    ui32;
  OTX_UINT64    nFrameRefId;
  OTX_DATETIME  dtFrameRefTime;

  // validate parameters
  if (nSourceId < 0 || nSourceId > 2) {
    DemoLogf("DemoBurstReceiver: Invalid nSourceId(%d)...\n", nSourceId);
    return;
  }

  if (!g_sBurstDevs.mBurstReceiver.bActive) {
    // we're not active, so just return
    return;
  }

  // we want the frame reference id and time
  ui32 = sizeof(buf);
  otxRc = OtxBurstReadDataEx(g_hPhysDevs.hBurst, 
                             nSourceId, 
                             buf, 
                             &ui32, 
                             &nFrameRefId, 
                             &dtFrameRefTime);
  DemoCheckRc(g_hPhysDevs.hBurst, otxRc);

  // check the amount buffered w/ how much we requested to be buffered
  //  (since we set the trigger amount to the buffer size, there should
  //    have been room to buffer this, so these two should be the same).
  if((ui32 != sizeof(buf)) &&
     (g_sBurstDevs.mBurstReceiver.bVerbose)) {
     DemoLogf("DemoBurstReceiver[%d]: Burst buffer transmit size error\n", 
              nSourceId);
     DemoLogf("    Expected transfer size %d\n", 
              sizeof(buf));
     DemoLogf("    Actual transfer size %d\n", ui32);
  }    

  // echo if we're in verbose mode
  if (g_sBurstDevs.mBurstReceiver.bVerbose) {
    int x;

    DemoPrintTimeStamp(dtFrameRefTime);

    // Note: we only display the least significant 32 bits 
    // of the frame reference id.
    DemoLogf("BurstReceiver[%d] (len=%.5d) ID:%08x ", 
             nSourceId, 
             sizeof(buf), 
             (OTX_UINT32) (nFrameRefId & 0xffffffff));

    for (x = 0; (x < 32) && (x < (OTX_INT32) sizeof(buf)); x++) {
      // display the highway's currentLi's data
      if ((x % 8) == 0) DemoLogf("\n");
      DemoLogf("%.2X ", buf[x]);
    }
    DemoLogf("\n");
    DemoLogf("\n");
  }

  // write data to a file if desired
  if (g_sBurstDevs.mBurstReceiver.pRxFile) {
    int cbWritten;

    if (g_sBurstDevs.mBurstReceiver.nTsToRecord == -1) {
      // All TS
      cbWritten = fwrite(buf, 
                         sizeof(buf[0]), 
                         sizeof(buf), 
                         g_sBurstDevs.mBurstReceiver.pRxFile);
      if(cbWritten != (int) sizeof(buf)) {
        DemoLogf("BurstReceiver[%d] Error: Could not write data to file.  "
                 "(nFrameLen=%d, cbWritten=%d) \n", 
                 nSourceId, 
                 sizeof(buf), 
                 cbWritten);
      }
    } else {
      // Single TS
      OTX_UINT8 singleTsBuf[DEMO_BURST_BUF_SIZE/32];
      int byteCount = 0;
      int x;

      byteCount = 0;
      for(x = g_sBurstDevs.mBurstReceiver.nTsToRecord; x < (OTX_INT32) sizeof(buf); x += 32) {
        singleTsBuf[byteCount++] = buf[x];
      }
      cbWritten = fwrite(singleTsBuf, 
                         sizeof(singleTsBuf[0]), 
                         byteCount, 
                         g_sBurstDevs.mBurstReceiver.pRxFile);
      if (cbWritten != byteCount) {
        DemoLogf("BurstReceiver[%d] Error: Could not write data to file.  "
                 "(byteCount=%d, cbWritten=%d) \n", 
                 nSourceId, 
                 byteCount, 
                 cbWritten);
      }
    }
  }
}




void DemoPrintEvent(
/*******************************************************************************
  @func
    Prints a Driver Event.
*******************************************************************************/
  OtxEventDataS *pEventData
)
{
  OTX_RESULT otxRc;
  char msgStr[256];

  //DemoPrintTimeStamp(pEventData->m_nTimeStamp);

  switch (pEventData->m_eDeviceType) {
    
  case OTX_LDEVICE_USER_APPLICATION:
    // Events from the DspDemo1.out logical devices
    DemoPrintCSTEvent(pEventData);
    break;
    
  case OTX_DEVICE_BURST:
    {
      switch (pEventData->m_nCode) {
      case OTX_BURST_RECEIVER_EC_DATA_AVAILABLE:
        DemoBurstReceiver(pEventData->m_nRequestId);
        break;
      case OTX_BURST_SENDER_EC_BUF_DEPLETED:
        DemoBurstSender(pEventData->m_nRequestId);
        break;
      default:
        otxRc = OtxDrvEventCode2String(pEventData->m_hDevice, 
                                       pEventData->m_nCode, 
                                       256, 
                                       &msgStr[0]);
        if (OTX_SUCCESS(otxRc)) {
          DemoLogf("Burst[%d] Event: %s (%d)\n", 
                   pEventData->m_nSourceId, 
                   msgStr, 
                   pEventData->m_nParam);
        } else {
          DemoLogf("Burst[%d] Invalid Event: %ld \n", 
                   pEventData->m_nSourceId, 
                   pEventData->m_nCode);

          DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                              DEMO_FXO_POTS_TYPE, 
                              pEventData->m_nSourceId,
                              pEventData);
        }
        break;
      }
      
    }
    break;

  default:
    {
      // Unhandled event
      DemoLogf("Unknown Board Level Event hDevice 0x%X DeviceType 0x%X\n", 
                pEventData->m_hDevice,
                pEventData->m_eDeviceType);

      DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                          DEMO_FXO_POTS_TYPE, 
                          pEventData->m_nSourceId,
                          pEventData);
    }
    break;
    
  }
  
}

/*******************************************************************************

  @func

  Convert a DTMF parameter to a digit (char).

  @comm

*******************************************************************************/
static char DemoDtmfParamToChar(int nParam) {
  switch (nParam) {
  case 0:  // 0  (941Hz/1336Hz)
  case 1:  // 1  (697Hz/1209Hz)
  case 2:  // 2  (697Hz/1336Hz)
  case 3:  // 3  (697Hz/1477Hz)
  case 4:  // 4  (770Hz/1209Hz)
  case 5:  // 5  (770Hz/1336Hz)
  case 6:  // 6  (770Hz/1477Hz)
  case 7:  // 7  (852Hz/1209Hz)
  case 8:  // 8  (852Hz/1336Hz)
  case 9:  // 9  (852Hz/1477Hz)
    return '0' + nParam;
  case 10: // A  (697Hz/1633Hz)
  case 11: // B  (770Hz/1633Hz)
  case 12: // C  (852Hz/1633Hz)
  case 13: // D  (941Hz/1633Hz)
    return 'A' - 10 + nParam;
  case 14: // *  (941Hz/1209Hz)
    return '*';
    break;
  case 15: // #  (941Hz/1477Hz)
    return '#';
    break;
  default: // Error
    DemoLogf("Unrecognized DTMF tone parameter (%d)\n", nParam);
    return '-';
  }
}


OTX_INT32 DemoProcessUserCommand(char commandChar)
/*******************************************************************************
  @func
    Processes User Commands
*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;
  static OTX_INT32  nCurrentLi = 0;
  static OTX_INT32  nCmdLoopCnt = 0;
  static OTX_INT32  nFxoLiInUse = DEMO_LI_MAX + 1;

  // Check to see that it is a valid setting
  if((nCurrentLi < (OTX_INT32) g_firstUsableLi) || 
     (nCurrentLi >= DEMO_LI_MAX)) {
    if(nCmdLoopCnt == 0) {
      // First time though the loop. 
      // Need to set nCurrentLi to the first usable Li
      nCurrentLi = g_firstUsableLi;
    }
    else {
      DemoLogf("\n");
      DemoLogf("Warning: Current LI selection %d is out of range\n", 
               nCurrentLi);
      DemoLogf("\n");
    }
  }

  nCmdLoopCnt++;

  switch (commandChar) {

  case '?':
  case 'h':
  case 'H':
//    n/y    is used for the exit test question. It is not good to use it here

    DemoLogf("Cmd   Synopsis\n");
    DemoLogf("===   ===========================================================\n");
    DemoLogf(" ?    Display Help text\n");
    DemoLogf(" h    Ditto\n");
    DemoLogf(" q    Quit\n");

    DemoLogf(" 0-5  Select active POTS Line. LI%d is selected\n", nCurrentLi);
    DemoLogf(" f    Set active FXO Li Off-Hook or On-hook (toggle)\n");
    DemoLogf(" m    Set active FXO Li in On-Hook Line-Monitor mode\n");
    DemoLogf(" c    Line sense. Read line voltage or loop current FXO\n");
    DemoLogf(" D    Dial user specified DTMF digits on the active FXO Li\n");
    DemoLogf(" d    Call DTMF digits %s on the active FXO Li\n", g_sqNumber0);

    DemoLogf(" l    Flash/hook on the active FXO Li\n");
    DemoLogf(" r    Read a Register from the DAA\n");
    DemoLogf(" w    Write to a Register in the DAA\n");
    DemoLogf(" b    Get Debug data from the DSP\n");
    DemoLogf(" s    Stream receive data to file (toggle). For DSP debugging\n");
    DemoLogf(" e    Enable/Disable Burst (toggle)\n");
    DemoLogf(" a    Abort Burst Senders and Receivers\n");
    DemoLogf(" R    Start Burst Receiver. Prompt for file to recv\n");
    DemoLogf(" S    Start Burst Sender. Prompt for file to send\n");
    DemoLogf(" t    Start task to answer and disconnect call FXO(%d)\n", nCurrentLi);
    DemoLogf(" T    Terminate FXO answer caller task\n");
    DemoLogf(" k    Start task to continuously call FXO(%d)\n", nCurrentLi);
    DemoLogf(" K    Terminate FXO calling task\n");
    DemoLogf(" !    Terminate Watchdog Timer Thread (Crash test)\n");
    DemoLogf(" v    Toggle Burst Receiver Verbose mode\n");
    DemoLogf(" z    FXS Audio path configuration MENU\n");

    break;


  case 'k':
    {
      if(g_nContinuousAnswer == OTX_TRUE) {
        DemoLogf("\n");
        DemoLogf("  Continuous answer FXO task is already running!\n");
        DemoLogf("  Make sure both tasks are not using the same FXO line!\n");
        if(nFxoLiInUse == nCurrentLi) {
          DemoLogf("  Answer task is already using FXO Li(%d)\n", nFxoLiInUse);
        }
        else {
          DemoLogf("  Calling task is using a different FXO Li(%d)\n", 
                      nFxoLiInUse);
        }
        DemoLogf("\n");
      }
      else {
        // Set our current Li into the in use
        nFxoLiInUse = nCurrentLi;
      }

      // Continuously call a number on an FXO line
      if(g_nContinuousCalling == OTX_TRUE) {
        DemoLogf("Continuous calling FXO task is already running\n");
      }
      else {
        DemoLogf("Starting continuous calling on FXO(%d) task\n", nCurrentLi);

        g_nContinuousCalling = OTX_TRUE;

        // Allow task to run even if error is found
        g_demoEnv.bContinueOnError  = OTX_TRUE;

        // Start calling thread
        OsaThreadStartEx(DemoFxoCalling, (void *) &nCurrentLi);
      }

      DemoLogf("Done.\n");
    }
    break;

  case 'K':
    {
      // Halt continuous calling task
      if(g_nContinuousCalling == OTX_FALSE) {
        DemoLogf("Continuous calling FXO task was not running\n");
      }
      else {
        DemoLogf("Halt continuous calling FXO(%d) task\n", nCurrentLi);

        // Allow exit check to exit on request
        g_demoEnv.bContinueOnError  = OTX_FALSE;

        if(nCurrentLi == nFxoLiInUse) {
          nFxoLiInUse = DEMO_LI_MAX + 1;
        }

        g_nContinuousCalling = OTX_FALSE;
        OsaThreadSleep(500);  // Let task wakeup to see it is time to quite
      }

      DemoLogf("Done.\n");
    }
    break;


  case 't':
    {
      if(g_nContinuousCalling == OTX_TRUE) {
        DemoLogf("\n");
        DemoLogf("  Continuous calling FXO task is already running!\n");
        DemoLogf("  Make sure both tasks are not using the same FXO line!\n");
        if(nFxoLiInUse == nCurrentLi) {
          DemoLogf("  Calling task is already using FXO Li(%d)\n", nFxoLiInUse);
        }
        else {
          DemoLogf("  Answer task is using a different FXO Li(%d)\n", 
                      nFxoLiInUse);
        }
        DemoLogf("\n");
      }
      else {
        // Set our current Li into the in use
        nFxoLiInUse = nCurrentLi;
      }

      // Continuously answer a call on an FXO line
      if(g_nContinuousAnswer == OTX_TRUE) {
        DemoLogf("Continuous answer FXO task is already running\n");
      }
      else {
        DemoLogf("Starting continuous answer FXO(%d) task\n", nCurrentLi);

        // Allow task to run even if error is found
        g_demoEnv.bContinueOnError  = OTX_TRUE;

        g_nContinuousAnswer = OTX_TRUE;

        // Start the answer thread
        OsaThreadStartEx(DemoFxoAnswerCaller, (void *) &nCurrentLi);
      }

      DemoLogf("Done.\n");
    }
    break;

  case 'T':
    {
      // Halt continuously answer task
      if(g_nContinuousAnswer == OTX_FALSE) {
        DemoLogf("Continuous answer FXO task was not running\n");
      }
      else {
        DemoLogf("Halt continuous answer FXO(%d) task\n", nCurrentLi);

        // Allow exit check to exit on request
        g_demoEnv.bContinueOnError  = OTX_FALSE;

        if(nCurrentLi == nFxoLiInUse) {
          nFxoLiInUse = DEMO_LI_MAX + 1;
        }

        g_nContinuousAnswer = OTX_FALSE;
        OsaThreadSleep(500);  // Let task wakeup to see it is time to quite
      }

      DemoLogf("Done.\n");
    }
    break;




  case 'd':
    {
      // Dial a hard-coded number ...
      OTX_HANDLE hHandle = g_hLogicDevs.hDtmfDialer[nCurrentLi];

      DemoLogf("Sending digits on Pots Li#%d: '%s'", nCurrentLi, g_sqNumber0);

      // Start Dialing DTMF number, Non-Blocking call, will receive Event when completed
      result = OtxCstDtmfDial(hHandle, 
                              (unsigned char *)g_sqNumber0, 
                              strlen(g_sqNumber0), 
                              DEMO_TASK_REF, 
                              OTX_TIME_INFINITY); 
      DemoCheckRc(hHandle, result);

      DemoLogf("Done.\n");
    }
    break;

  case 'D':

    {
      // Dial a user specified number ...
      char strBuf[32];
      OTX_HANDLE hHandle = g_hLogicDevs.hDtmfDialer[nCurrentLi];

      DemoLogf("Phone number to Dial from Pots Li#%d: ", nCurrentLi);
      OsaConsoleGetStr(strBuf);
      DemoLogf("\n");
      DemoLogf("Pots Li#%d Dialing number '%s'\n", nCurrentLi, strBuf);

      if(strBuf[0]) {
        if(g_sPotsDevs[nCurrentLi].mFxoLi.bOffHook) {
          // Start Dialing DTMF number, Non-Blocking call, 
          // will receive Event when completed
          result = DemoFxoSendDtmfDigits(nCurrentLi, 
                                         NULL,
                                         (char *)strBuf);
          DemoCheckRc(hHandle, result);
        }
        else {
          DemoLogf("Pots Li#%d Waiting for line to go off hook\n", nCurrentLi);
          // Need to take FXS offhook then dialing DTMF number, Non-Blocking call, 
          // will receive Event when completed
          result = DemoFxoMakeCall(nCurrentLi, 
                                   NULL,
                                   (char *)strBuf);
          DemoCheckRc(hHandle, result);
        }
      }
      else {
        DemoLogf("No data DTMF string.\n");
      }

      DemoLogf("Done.\n");
    }
    break;

  case 'a':
    {
      if (DemoIsBurstDeviceEnabled()) {
        if (g_sBurstDevs.mBurstReceiver.pRxFile) {
          DemoLogf("DemoBurstReceiver: Closing file\n");
          fclose(g_sBurstDevs.mBurstReceiver.pRxFile);
          g_sBurstDevs.mBurstReceiver.pRxFile = NULL;
        }
        g_sBurstDevs.mBurstReceiver.bActive = OTX_FALSE;
        
        if (g_sBurstDevs.mBurstReceiver.pRxFile) {
          DemoLogf("mBurstSender: Closing file\n");
          fclose(g_sBurstDevs.mBurstSender.pTxFile);
          g_sBurstDevs.mBurstSender.pTxFile = NULL;
        }
        g_sBurstDevs.mBurstSender.bActive   = OTX_FALSE;
      } else {
        DemoLogf("The Burst device is not enabled. Command ignored\n");
      }
    }
    break;

  case 'e':
    if (DemoIsBurstDeviceEnabled()) {
      // by disabling the Burst device, we stop the process of transferring 
      // data from the hardware to the driver via DMA.
      DemoLogf("Disable g_hPhysDevs.hBurst\n");
      result = OtxDrvDisable(g_hPhysDevs.hBurst, OTX_TASK_SYNC, 5000L);
      DemoCheckRc(g_hPhysDevs.hBurst, result);
    } else {
      // by enabling the Burst device, we start the process of transferring 
      // data from the hardware to the driver via DMA.  The data is stored 
      // in the Burst device's buffer for later processing to connected 
      // logical devices.
      DemoLogf("Enable g_hPhysDevs.hBurst\n");
      result = OtxDrvEnable(g_hPhysDevs.hBurst, OTX_TASK_SYNC, 5000L);
      DemoCheckRc(g_hPhysDevs.hBurst, result);
    }
    break;

  case 'R':
    {
      char sqzBuf[OTX_MAX_PATH];
      OTX_UINT32 nHighwayNo;
      static OTX_INT32 nTsToRecord = -1;

      if(g_demoEnv.law == OTX_DATA_FORMAT_UINT16) {
        DemoLogf("Not supported at this time, OTX_DATA_FORMAT_UINT16\n");
      }

      if (DemoIsBurstDeviceEnabled()) {
        nHighwayNo = 0;
        if (g_sBurstDevs.mBurstReceiver.bActive == OTX_FALSE || 
            g_sBurstDevs.mBurstReceiver.pRxFile == NULL) {
          DemoLogf("BurstReceiver[%d]. Please enter file to receive: ", 
                   nHighwayNo);
          OsaConsoleGetStr(sqzBuf);
          if (sqzBuf[0] == '\0') {
            DemoLogf("  No file enterred abort capture.\n");
            break;
          }
          g_sBurstDevs.mBurstReceiver.pRxFile = fopen(sqzBuf, "wb");
          if (g_sBurstDevs.mBurstReceiver.pRxFile == NULL) {
            DemoLogf("Error: Could not open file %s \n", sqzBuf);
            break;
          }
          
          DemoLogf("BurstReceiver.\n");
          DemoLogf("Please enter single TS[0-31] to receive to file (-1=All): ");
          OsaConsoleGetStr(sqzBuf);
          if (sqzBuf[0] == '\0') {
            DemoLogf("  No TS enterred abort capture.\n");
            break;
          } else {
            nTsToRecord = strtol(sqzBuf, NULL, 0);
          }
          g_sBurstDevs.mBurstReceiver.nTsToRecord = nTsToRecord;
          
          g_sBurstDevs.mBurstReceiver.bActive = OTX_TRUE;
        } else {
          DemoLogf("Burst Receiver Thread already running.\n");
        }
      } else {
        DemoLogf("The Burst device is not enabled. Command ignored\n");
      }
    }
    break;

  case 'S':
    {
      char sqzBuf[OTX_MAX_PATH];
      static OTX_INT32 nTsToSend = 0;
      if(g_demoEnv.law == OTX_DATA_FORMAT_UINT16) {
        DemoLogf("Not supported at this time, OTX_DATA_FORMAT_UINT16\n");
      }
      
      if (DemoIsBurstDeviceEnabled()) {
        if (g_sBurstDevs.mBurstSender.bActive == OTX_FALSE) {
          DemoLogf("BurstSender[%d]. Please enter file to send: ");
          
          OsaConsoleGetStr(sqzBuf);
          if (sqzBuf[0] == '\0') {
            break;
          }
          g_sBurstDevs.mBurstSender.pTxFile = fopen(sqzBuf, "rb");
          if (g_sBurstDevs.mBurstSender.pTxFile == NULL) {
            DemoLogf("Error: Could not open file %s \n", sqzBuf);
            break;
          }

          DemoLogf("BurstSender:\n");
          DemoLogf("Sending data from file on TS%d of the Burst highway\n", 
                   nTsToSend);
          
          g_sBurstDevs.mBurstSender.bActive = OTX_TRUE;
        } else {
          DemoLogf("Burst Sender already running.\n");
        }
      } else {
        DemoLogf("The Burst device is not enabled. Command ignored\n");
      }
    }
    break;

  case 'b':
    {
      DemoLogf("Debug Dump for Dsp#%d\n", nCurrentLi);
      OtxDrvDbgDump(g_hPhysDevs.hDsp[nCurrentLi], 0);
    }
    break;

  case 'f':
    // Check to see if LI is already OFF Hook
    if(g_sPotsDevs[nCurrentLi].mFxoLi.bOffHook) {
      // Set Active Pots Li On-Hook ...
      DemoLogf("Pots Li#%d On-hook\n", nCurrentLi);
      result = OtxCstPotsOnHook(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                0x1001, 
                                2000);
      if (OTX_RESULT_CODE(result) == OTX_E_BUSY) {
        DemoLogf("Command timeout please retry\n");
      }
      else {
        DemoCheckRc(g_hLogicDevs.hPotsLi[nCurrentLi], result);
      }
    }
    else {
      // Set Active Pots Li Off-Hook ...
      DemoLogf("Pots Li#%d Off-hook\n", nCurrentLi);
      result = OtxCstPotsOffHook(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                 0x1000, 
                                 2000); 
      if (OTX_RESULT_CODE(result) == OTX_E_BUSY) {
        DemoLogf("Command timeout please retry\n");
      }
      else {
        DemoCheckRc(g_hLogicDevs.hPotsLi[nCurrentLi], result);
      }
    }
    break;

  case 'm':
    // Set Active Pots Li in On-Hook Line Monitor mode ...
    DemoLogf("Pots Li#%d On-hook Line-Monitor mode\n", nCurrentLi);
    result = OtxCstPotsOnHookLineMon(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                     0x1001, 
                                     2000); 
    DemoCheckRc(g_hLogicDevs.hPotsLi[nCurrentLi], result);
    break;

  case 'c':
    {
      // Line Sense
      OTX_INT32 potsLi;
  
      for(potsLi = g_firstUsableLi; potsLi < DEMO_LI_MAX; potsLi++) {
        DemoLogf("Pots Li#%d Line Sense Value %d\n", 
                 potsLi,
                 g_sPotsDevs[potsLi].mFxsLi.nLiLastSense);
      }

      // Let the next sense line value be displayed for this LI
      for(potsLi = g_firstUsableLi; potsLi < DEMO_LI_MAX; potsLi++) {
        g_bLineSensePending[potsLi] = OTX_TRUE;
      }
    }
    break;

  case 'l':
    // Flash Hook
    DemoLogf("Pots Li#%d Hook Flash\n", nCurrentLi);
    result = OtxCstPotsHookFlash(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                 200, 
                                 0x1002, 
                                 2000); 
    DemoCheckRc(g_hLogicDevs.hPotsLi[nCurrentLi], result);
    break;

  case 'p':
    {
      // Pulse dial
      OTX_INT32 c;
      DemoLogf("Pots Li#%d Pulse Dialing. Press digit to dial... [0-9] ", 
               nCurrentLi);
      c = OsaConsoleGetCh();
      DemoLogf("\n");
      result = OtxCstPotsPulseDial(g_hLogicDevs.hPotsLi[nCurrentLi], 
                                   c, 
                                   0x1003, 
                                   2000); 
      DemoCheckRc(g_hLogicDevs.hPotsLi[nCurrentLi], result);
      DemoLogf("Done.\n");
    }
    break;

  case '0':
  case '1':
  case '2':
  case '3':
  case '4':
  case '5':
    // Select current Li
    {
      OTX_INT32 nLi = commandChar - '0';
      
      nCurrentLi = nLi;
      g_liConNumber_1 = nCurrentLi;
      DemoLogf("Li#%d Selected ....\n", nCurrentLi);
    }
    break;

#if 1 // Only for DSP program debugging
  case 's':
    {
      char sqzBuf[OTX_MAX_PATH];
      
      if (g_fStreamFile) {
        fclose(g_fStreamFile);
        g_fStreamFile = NULL;
        DemoLogf("Closed streaming file\n");
      } else {
        
        DemoLogf("Please enter file to receive: ");
        OsaConsoleGetStr(sqzBuf);
        if (sqzBuf[0] == '\0') {
          break;
        }
        
        if ((g_fStreamFile = fopen(sqzBuf, "wb")) == NULL) {
          DemoLogf("Error: Could not open file %s \n", sqzBuf);
          break;
        }
      }
    }
    break;

  
  case 'r':
    {
      OTX_UINT32 nCmd = 1; // 1 = Read
      static OTX_UINT8 nRegister = 2; 
      static OTX_UINT8 nDummy2 = 0; 
      static OTX_UINT8 nDummy3 = 0; 
      char strBuf[64];
      
      DemoLogf("Read DAA register. Register [%d]\n ", nRegister);
      OsaConsoleGetStr(strBuf);
      if (*strBuf) {
        nRegister = (OTX_UINT8)strtol(strBuf, NULL, 0);
      }

      nCmd = (nDummy3 << 3*8) | (nDummy2 << 2*8) | (nRegister << 1*8) | nCmd;
      result = OtxDrvDbgDump(g_hLogicDevs.hPotsLi[nCurrentLi], nCmd);
      
    }
    break;

  
  case 'w':
    {
      OTX_UINT32 nCmd = 2; // 2 = Write
      static OTX_UINT8 nRegister = 2; 
      static OTX_UINT8 nVal = 0; 
      static OTX_UINT8 nDummy3 = 0; 
      char strBuf[64];
      
      DemoLogf("Write DAA register. Register [%d]\n ", nRegister);
      OsaConsoleGetStr(strBuf);
      if (*strBuf) {
        nRegister = (OTX_UINT8)strtol(strBuf, NULL, 0);
      }

      DemoLogf("Please enter value [0x%.2X] ", nVal);
      OsaConsoleGetStr(strBuf);
      if (*strBuf) {
        nVal = (OTX_UINT8)strtol(strBuf, NULL, 0);
      }

      nCmd = (nDummy3 << 3*8) | (nVal << 2*8) | (nRegister << 1*8) | nCmd;
      result = OtxDrvDbgDump(g_hLogicDevs.hPotsLi[nCurrentLi], nCmd);
      
    }
    break;
#endif


  case 'z':
    DemoLogf("\nSLIC Receive Path Audio Configuration\n");

    {
      OTX_UINT32 exitMenu = 0;
      char strBuf[256];

      while( exitMenu == 0 ) {
        // Display help menu for user first
        exitMenu = DemoSlicReceiveConfigMenu('?');
        
        if(exitMenu == 0) {
          // Get user input
          OsaConsoleGetStr(strBuf);

          exitMenu = DemoSlicReceiveConfigMenu(strBuf[0]);
        }
      }

    }

    DemoLogf("\nAudio Configuration done\n");

    break;
    
  case 'v':
    {
      if (g_sBurstDevs.mBurstReceiver.bVerbose) {
        g_sBurstDevs.mBurstReceiver.bVerbose = OTX_FALSE;
      } else {
        g_sBurstDevs.mBurstReceiver.bVerbose = OTX_TRUE;
      }
      DemoLogf("Burst Receiver Verbose is now %s\n", 
               g_sBurstDevs.mBurstReceiver.bVerbose ? "ON" : "OFF");
    }
    break;


  case '!':
    {
      DemoLogf("Terminating WatchDog Thread (Crash test)\n");
      g_bWatchDogThreadActive = OTX_FALSE;
    }
    break;

  case '~':
    {
      char strBuf[12];
      OTX_INT32 nSleepTime;
      
      DemoLogf("Enter milliseconds to sleep :");
      OsaConsoleGetStr(strBuf);
      
      if (strBuf[0]) {
        nSleepTime = strtol(strBuf, NULL, 0);
        DemoLogf("Sleeping %d milliseconds\n", nSleepTime);
        OsaThreadSleep(nSleepTime);
      }
      
    }
    break;
    
  case 'q':
  case 'Q':
    // Quit ...
    return 1;
    break;

  default:
    DemoLogf("Unknown command. Press '?' for help, 'q' to quit\n");
    break;
  }

  return 0;
}


/*******************************************************************************

  @func

  Processes User Commands for SLIC audio path setup

  @comm

  This code is case sensitive.

*******************************************************************************/
OTX_INT32 DemoSlicReceiveConfigMenu(char commandChar)
{
  char strBuf[256];
  OTX_UINT32 regValueL = 0;
  OTX_RESULT result = OTX_S_OK;

  if(g_liConNumber_1 == DEMO_NO_LI_CONNECTED) {
      DemoLogf("\n");
      DemoLogf("Audio Path Configuration Requires FXO to FXS Connection\n");
      DemoLogf("\n");
      return 1;
  }

  switch(commandChar)   {

  case 'a':

    DemoLogf("Audio Receive Path Gain\n");

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("\nRegister value was 0x%X\n", regValueL);
    // Bit 0 and 1 are used to set Analog receive path gain
    regValueL = regValueL & 0x03;

    switch(regValueL)   {

      case 0:
        DemoLogf("Gain set to 0 dB\n");
      break;
      case 1:
        DemoLogf("Gain set to -3.5 dB\n");
      break;
      case 2:
        DemoLogf("Gain set to 3.5 dB\n");
      break;
      case 3:
        DemoLogf("Analog receive path muted\n");
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    DemoLogf("Enter Option \n");
    DemoLogf("0: for O db Gain\n");
    DemoLogf("1: for -3.5 db Gain\n");
    DemoLogf("2: for 3.5 db Gain\n");
    DemoLogf("3: Analog receive path muted\n");
    DemoLogf("> ");
    OsaConsoleGetStr(strBuf);

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);
    regValueL = regValueL & ~(0x03);

    switch(strBuf[0])   {

      case '0':
        DemoLogf("Gain set to 0 dB\n");
      break;
      case '1':
        DemoLogf("Gain set to -3.5 dB\n");
        regValueL = regValueL | 0x01;
      break;
      case '2':
        DemoLogf("Gain set to 3.5 dB\n");
        regValueL = regValueL | 0x02;
      break;
      case '3':
        DemoLogf("Analog receive path muted\n");
        regValueL = regValueL | 0x03;
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    result = OtxDrvWriteReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                             9,     // Audio gain control register
                             regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);


    
    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("Register value is 0x%X\n", regValueL);

    DemoLogf("Done\n");

  break;


  case 'A':

    DemoLogf("Audio Transmit Path Gain\n");

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("\nRegister value was 0x%X\n", regValueL);
    // Bit 0 and 1 are used to set Analog receive path gain
    regValueL = regValueL & 0x0C;

    switch(regValueL)   {

      case 0:
        DemoLogf("Gain set to 0 dB\n");
      break;
      case 0x04:
        DemoLogf("Gain set to -3.5 dB\n");
      break;
      case 0x08:
        DemoLogf("Gain set to 3.5 dB\n");
      break;
      case 0x0C:
        DemoLogf("Analog transmit path muted\n");
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    DemoLogf("Enter Option \n");
    DemoLogf("0: for O db Gain\n");
    DemoLogf("1: for -3.5 db Gain\n");
    DemoLogf("2: for 3.5 db Gain\n");
    DemoLogf("3: Analog receive path muted\n");
    DemoLogf("> ");
    OsaConsoleGetStr(strBuf);

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);
    regValueL = regValueL & ~(0x0C);

    switch(strBuf[0])   {

      case '0':
        DemoLogf("Gain set to 0 dB\n");
      break;
      case '1':
        DemoLogf("Gain set to -3.5 dB\n");
        regValueL = regValueL | 0x04;
      break;
      case '2':
        DemoLogf("Gain set to 3.5 dB\n");
        regValueL = regValueL | 0x08;
      break;
      case '3':
        DemoLogf("Analog transmit path muted\n");
        regValueL = regValueL | 0x0C;
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    result = OtxDrvWriteReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                             9,     // Audio gain control register
                             regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);


    
    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            9,     // Audio gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("Register value is 0x%X\n", regValueL);

    DemoLogf("Done\n");

  break;

  case 'b':

    DemoLogf("Audio Hybrid Gain\n");

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            11,     // Audio Hybrid gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("\nRegister value was 0x%X\n", regValueL);
    // Bit 0, 1, and 2 are used to set Hybrid gain
    regValueL = regValueL & 0x07;

    switch(regValueL)   {

      case 0:
        DemoLogf("Gain set to 4.08 dB\n");
      break;
      case 1:
        DemoLogf("Gain set to 2.5 dB\n");
      break;
      case 2:
        DemoLogf("Gain set to 1.16 dB\n");
      break;
      case 3:
        DemoLogf("Gain set to 0 dB\n");
      break;
      case 4:
        DemoLogf("Gain set to -1.02 dB\n");
      break;
      case 5:
        DemoLogf("Gain set to -1.94 dB\n");
      break;
      case 6:
        DemoLogf("Gain set to -2.77 dB\n");
      break;
      case 7:
        DemoLogf("Audio Hybrid off\n");
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    DemoLogf("Enter Option \n");
    DemoLogf("0: for 4.08 db Gain\n");
    DemoLogf("1: for 2.5 db Gain\n");
    DemoLogf("2: for 1.16 db Gain\n");
    DemoLogf("3: for O db Gain\n");
    DemoLogf("4: for -1.02 db Gain\n");
    DemoLogf("5: for -1.94 db Gain\n");
    DemoLogf("6: for -2.77 db Gain\n");
    DemoLogf("7: Audio Hybrid off\n");
    DemoLogf("> ");
    OsaConsoleGetStr(strBuf);

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            11,     // Audio Hybrid gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    regValueL = regValueL & ~(0x07);

    switch(strBuf[0])   {

      case '0':
        DemoLogf("Gain set to 4.08 dB\n");
      break;
      case '1':
        DemoLogf("Gain set to 2.5 dB\n");
        regValueL = regValueL | 0x01;
      break;
      case '2':
        DemoLogf("Gain set to 1.16 dB\n");
        regValueL = regValueL | 0x02;
      break;
      case '3':
        DemoLogf("Gain set to 0 dB\n");
        regValueL = regValueL | 0x03;
      break;
      case '4':
        DemoLogf("Gain set to -1.02 dB\n");
        regValueL = regValueL | 0x04;
      break;
      case '5':
        DemoLogf("Gain set to -1.94 dB\n");
        regValueL = regValueL | 0x05;
      break;
      case '6':
        DemoLogf("Gain set to -2.77 dB\n");
        regValueL = regValueL | 0x06;
      break;
      case '7':
        DemoLogf("Audio Hybrid off\n");
        regValueL = regValueL | 0x07;
      break;

      default:
        DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    result = OtxDrvWriteReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                             11,     // Audio Hybrid gain control register
                             regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);
    
    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            11,     // Audio Hybrid gain control register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("Register value is 0x%X\n", regValueL);

    DemoLogf("Done\n");

  break;

  case 'c':

    DemoLogf("DC-DC Converter Voice Band Noise Squelch\n");

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("\nRegister value was 0x%X\n", regValueL);
    // Bit 1 used to enable audio band noise squelch
    regValueL = regValueL & 0x02;

    if(regValueL) {
      DemoLogf("Voice band squelch enabled\n");
    }
    else {
      DemoLogf("Voice band squelch disabled\n");
    }

    DemoLogf("Enter (y) to enable (n) to disable squelch \n> ");
    OsaConsoleGetStr(strBuf);

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);


    if((strBuf[0] == 'y') || (strBuf[0] == 'Y')) {
      regValueL = regValueL | 0x02;
    }
    else
    if((strBuf[0] == 'n') || (strBuf[0] == 'N')) {
      regValueL = regValueL & ~(0x02);
    }
    else {
      DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    result = OtxDrvWriteReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                             108,     // Si3210 Enhancement register
                             regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);
    
    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("Register value is 0x%X\n", regValueL);

    DemoLogf("Done\n");

  break;


  case 'd':

    DemoLogf("DC-DC Converter Voice Band Noise Squelch Responce Time\n");

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("\nRegister value was 0x%X\n", regValueL);
    // Bit 1 used to enable audio band noise squelch
    regValueL = regValueL & 0x20;

    if(regValueL) {
      DemoLogf("Voice band squelch ENHANCED Algorithm\n");
    }
    else {
      DemoLogf("Voice band squelch NORMAL Algorithm\n");
    }

    DemoLogf("Enter (y) to enhanced (n) to Normal squelch \n> ");
    OsaConsoleGetStr(strBuf);

    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);


    if((strBuf[0] == 'y') || (strBuf[0] == 'Y')) {
      regValueL = regValueL | 0x20;
    }
    else
    if((strBuf[0] == 'n') || (strBuf[0] == 'N')) {
      regValueL = regValueL & ~(0x20);
    }
    else {
      DemoLogf("Software application error. Unsupported option.\n");
      return 0;
    }

    result = OtxDrvWriteReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                             108,     // Si3210 Enhancement register
                             regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);
    
    result = OtxDrvReadReg8(g_hPhysDevs.hSlicLi[g_liConNumber_1],
                            108,     // Si3210 Enhancement register
                            &regValueL);
    DemoCheckRc(g_hPhysDevs.hSlicLi[g_liConNumber_1], result);

    DemoLogf("Register value is 0x%X\n", regValueL);

    DemoLogf("Done\n");

  break;


  case 'Q':
    return 1;
  break;

  case '0':
  case '1':
  case '2':
  case '3':
  case '4':
  case '5':
    // Select current Li
    {
      OTX_INT32 nLi = commandChar - '0';
      
      g_liConNumber_1 = nLi;
      DemoLogf("SLIC #%d Selected ....\n", g_liConNumber_1);
    }
  break;

  default:
    DemoLogf("\nCmd Si3210 Audio Receive Path Configuration\n");
    DemoLogf("The following changes can be made on an active line.\n");
    DemoLogf("===  ========\n");
    DemoLogf(" Q   Return to Main Menu\n");
    DemoLogf(" 0-5 Select active SLIC. #%d is now active\n", g_liConNumber_1);
    DemoLogf(" A   Set Transmit Audio Gain\n");
    DemoLogf(" a   Set Receive Audio Gain\n");
    DemoLogf(" b   Set Receive Hybrid Gain\n");
    DemoLogf(" c   Set Receive DC-DC Converter Noise Squelch\n");
    DemoLogf(" d   Set Receive DC-DC Converter Noise Squelch Response\n");
    DemoLogf("\n > ");
  break;
  }
  
  return 0;
}



/*******************************************************************************

  @func

  Parse the program's command line arguments and calls upon
  requested actions.

  There are some optional switches that can be used following
  the driver name on the command line. Switches are are
  separated by spaces, and can appear in arbitrary order.
  Switches consist of a hyphen and a letter:

  @comm

*******************************************************************************/
static void DemoParseCmdLineArgs(int argc, char *argv[], DemoEnvT *envP) {
  short  i;

  // Set reasonable defaults before reading from command line
  envP->bExitOnError      = OTX_FALSE;
  envP->logFileName       = g_pLogFile;
  envP->outFileName       = NULL;
  envP->law               = OTX_DATA_FORMAT_COMPAND8_U_LAW;
  envP->boardNo           = DEMO_DEFAULT_BOARD_NO;
  envP->fxoStartNo        = DEMO_DEFAULT_FXO_NO;
  envP->fxoMaxNo          = DEMO_FXO_MAX;
  envP->fxsMaxNo          = DEMO_FXS_MAX;
  envP->nSetId            = OTX_CST_POTS_CFG_SET_USA;
  envP->nBoardType        = OTX_DEVICE_ARNI_6X6_PCI;

  for (i = 1; i < argc; i++) {        // Scan command line arguments
    if (*(argv[i]+1) == 'Z') {   // Command input string -- case sensitive
      envP->pszInputStr = argv[i]+2;
    } else {    
      
      OsaStdStrUpr(argv[i]);
      if (*argv[i] == '-' || *argv[i] == '/') {  // Is argument a legal switch?
        if (*(argv[i]+1) == 'L') {   // Log file
          envP->logFileName = argv[i]+2;

        } else if (*(argv[i]+1) == 'O') {   // DSP out file
          envP->outFileName = argv[i]+2;

        } else if (*(argv[i]+1) == 'B') {   // Board number
          envP->boardNo = strtoul(argv[i]+2, NULL, 0);

        } else if (*(argv[i]+1) == 'F') {   // FXO number
          envP->fxoStartNo = strtoul(argv[i]+2, NULL, 0);
          g_firstUsableLi = envP->fxoStartNo;

        } else if (OsaToUpper(*(argv[i]+1)) == 'T') {   // Board Type
          if        (OsaToUpper(*(argv[i] + 2)) == 'A') {
            envP->nBoardType  = OTX_DEVICE_ARNI_6X6_PCI_PLUS;
          } else if (OsaToUpper(*(argv[i] + 2)) == 'B') {
            envP->nBoardType  = OTX_DEVICE_ARNI_6_FXO_PCI_PLUS;
            envP->fxsMaxNo = 0; // no FXS on this card
          } else if (OsaToUpper(*(argv[i] + 2)) == 'C') {
            envP->nBoardType  = OTX_DEVICE_ARNI_6_FXS_PCI_PLUS;
            envP->fxoMaxNo = 0; // no FXO on this card
          } else if (OsaToUpper(*(argv[i] + 2)) == 'D') {
            envP->nBoardType  = OTX_DEVICE_ARNI_6X3_PCI_PLUS;
            envP->fxsMaxNo = 3; // MAX 3 FXS on this card
          } else if (OsaToUpper(*(argv[i] + 2)) == 'J') {
            envP->nBoardType  = OTX_DEVICE_ARNI_6X6_PCI;
          } else {            
            DemoLogf("Error: Unknown command line switch %s\n", argv[i]);
            DemoHelpPanel();
            OsaConsoleExit();
            exit(1);
          }

        } else if (*(argv[i]+1) == 'C') {   // Companding Law
          if (*(argv[i]+2) == 'A') {   // A-law
            envP->law = OTX_DATA_FORMAT_COMPAND8_A_LAW;
          } else if (*(argv[i]+2) == 'U') {   // U-law
            envP->law = OTX_DATA_FORMAT_COMPAND8_U_LAW;
          } else {
            DemoLogf("Error: Invalid companding law command line switch %s\n", 
                     argv[i]);
            DemoHelpPanel();
            OsaConsoleExit();
            exit(1);
          }

        } else if (*(argv[i]+1) == 'S') {   // Configuration Set
          if (*(argv[i]+2) == 'U') {          // USA
            envP->nSetId = OTX_CST_POTS_CFG_SET_USA;
          } else if (*(argv[i]+2) == 'G') {   // Germany
            envP->nSetId = OTX_CST_POTS_CFG_SET_GERMANY;
          } else if (*(argv[i]+2) == 'E') {   // UK
            envP->nSetId = OTX_CST_POTS_CFG_SET_UK;
          } else if (*(argv[i]+2) == 'F') {   // France
            envP->nSetId = OTX_CST_POTS_CFG_SET_FRANCE;
          } else if (*(argv[i]+2) == 'A') {   // Australia
            envP->nSetId = OTX_CST_POTS_CFG_SET_AUSTRALIA;
          } else if (*(argv[i]+2) == 'J') {   // Japan
            envP->nSetId = OTX_CST_POTS_CFG_SET_JAPAN;
          } else {
            DemoLogf("Error: Unsupported country specific configuration set %s\n", 
                     argv[i]);
            DemoHelpPanel();
            OsaConsoleExit();
            exit(1);
          }

        } else {
          DemoLogf("Error: Unknown command line switch %s\n", argv[i]);
          DemoHelpPanel();
          OsaConsoleExit();
          exit(1);
        }
      } else {
        DemoLogf("Error: Unknown command line switch %s\n", argv[i]);
        DemoHelpPanel();
        OsaConsoleExit();
        exit(1);
      }
    }
  }

}


static void DemoHelpPanel()
/*******************************************************************************
  @func
    Displays a help for the command line.
*******************************************************************************/
{
  DemoLogf("\nCommand line switches:\n");
  DemoLogf(" /L<fileName>    : Log file name\n");
  DemoLogf(" /B<boardNo>     : Board number (Default is %d)\n", 
           DEMO_DEFAULT_BOARD_NO);
  DemoLogf(" /F<fxoStartNo>  : FXO number to configure (Default is %d)\n", 
           DEMO_DEFAULT_FXO_NO);
  DemoLogf(" /T[A|B|C|D|J]   : Board Type used for the demo, where\n");
  DemoLogf("                    A  = Use Arni-6-PCI-Plus Board\n");
  DemoLogf("                    B  = Use Arni-6-FXO-PCI-Plus Board\n");
  DemoLogf("                    C  = Use Arni-6-FXS-PCI-Plus Board\n");
  DemoLogf("                    D  = Use Arni-6x3-PCI-Plus Board\n");
  DemoLogf("                    J  = Use Arni-6-PCI Board\n");
  DemoLogf(" /C[A|U]         : Voice Compression Codec, where\n");
  DemoLogf("                    A  = A-law\n");
  DemoLogf("                    U  = u-law (default)\n");
  DemoLogf(" /S[U|G|E|F|A|J] : Country specific setting, where\n");
  DemoLogf("                    U  = Li Configuration for USA (default)\n");
  DemoLogf("                    G  = Li Configuration for Germany\n");
  DemoLogf("                    E  = Li Configuration for United Kingdom\n");
  DemoLogf("                    F  = Li Configuration for France\n");
  DemoLogf("                    A  = Li Configuration for Australia\n");
  DemoLogf("                    J  = Li Configuration for Japan\n");
  DemoLogf(" /O<fileName>    : DSP Out file name (for debugging only)\n");
}


static void DemoLogf(char *formatStr, ...)
/*******************************************************************************
  @func
    Displays a message on the screen and prints it to the logfile.
*******************************************************************************/
{
  va_list argList;

  OsaMutexLock(&g_demoLogfCritSec);

  va_start(argList, formatStr);

  if(g_bConsoleEnabled) {
    // User has enabled the console. Display data.
    OsaConsolePrintF(formatStr, argList);
  }
  if(g_pDemoLogFile) {
    vfprintf(g_pDemoLogFile, formatStr, argList);

    fflush( g_pDemoLogFile );
  }

  if(g_fLogUtility) {
    (g_fLogUtility)(formatStr, argList);
  }

  va_end(argList);

  OsaMutexUnlock(&g_demoLogfCritSec);
}



/*******************************************************************************
*******************************************************************************/
#if 0
#ifdef __cplusplus
int mainCpp(int argc, char *argv[]) // Not used in application
#else
int main(int argc, char *argv[])
#endif
{
  OTX_INT32  exitFlag = 0;
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  char       commandChar;

  g_hNotificationEvent    = OTX_INVALID_EVENT_VALUE;
  g_hEventQueue           = OTX_INVALID_HANDLE_VALUE;
  g_pDemoLogFile          = NULL;
  g_fStreamFile           = NULL;
  g_bWatchDogThreadActive = OTX_FALSE;
  g_bConsoleEnabled       = OTX_FALSE;   // Start with consol disabled
  g_liConNumber_1         = DEMO_NO_LI_CONNECTED;
  g_liConTimeSlot         = 0;
  g_firstUsableLi         = DEMO_DSP_FIRST;
  g_nDemoAppResultCode    = OTX_S_OK; // Start with good status


  // Main needs the console
  result = DemoInitializeDebugConsole();
  if ( OTX_FAILURE(result) ) {
    // Delete allocated resources
    DemoAppExit();
  }

  DemoParseCmdLineArgs(argc, argv, &g_demoEnv);

  if (g_demoEnv.pszInputStr) {
    OsaConsoleInput(g_demoEnv.pszInputStr);
  }

  // Setup hardware
  result = DemoInitialize();
  if ( OTX_FAILURE(result) ) {
    // Delete allocated resources
    DemoAppExit();
  }

  DemoLogf("%s, %s, Odin TeleSystems Inc.\n", argv[0], __DATE__);

  // Main Loop. 
  // Loop here and wait for Events from the driver or commands from the user

  if(g_demoEnv.law == OTX_DATA_FORMAT_UINT16) {
    // The pipe definitions are for 8 bit data only (u-law, A-law)
    DemoLogf("Not supported at this time, OTX_DATA_FORMAT_UINT16\n");
  }
  else {
    DemoLogf("\nPress 'h' for help, 'q' to quit ...\n");

    while (!exitFlag) {
      commandChar = OsaConsoleGetCh();
      exitFlag = DemoProcessUserCommand(commandChar);
    }
  }
  // Delete allocated resources
  DemoAppExit();

  return 0;
}
#endif

/*******************************************************************************
*******************************************************************************/
static int DemoExit(int nExitCode)
{

  DemoLogf("\nExiting...\n");

  // Important to disable the Watchdog Timer since we will not be reseting 
  // it after we exit the application. 
  OtxDrvSetAttributeValueBool(g_hPhysDevs.hBoardController0, 
                              OTX_ATTR_BRD_WATCHDOG_TIMER_ENABLED,  
                              OTX_FALSE);

  g_bWatchDogThreadActive = OTX_FALSE;

  if (DemoIsBurstDeviceEnabled()) {
    if (g_sBurstDevs.mBurstReceiver.pRxFile) {
      DemoLogf("DemoExit: Closing burst file\n");
      fclose(g_sBurstDevs.mBurstReceiver.pRxFile);
      g_sBurstDevs.mBurstReceiver.pRxFile = NULL;
    }
    g_sBurstDevs.mBurstReceiver.bActive = OTX_FALSE;
    
    if (g_sBurstDevs.mBurstReceiver.pRxFile) {
      DemoLogf("DemoExit: Closing burst file\n");
      fclose(g_sBurstDevs.mBurstSender.pTxFile);
      g_sBurstDevs.mBurstSender.pTxFile = NULL;
    }
    g_sBurstDevs.mBurstSender.bActive   = OTX_FALSE;
  }

  OsaThreadSleep(100);   // give threads a chance to exit

  // Clean up
  if(g_bConsoleEnabled) {
    OsaConsoleExit();
  }
  OtxDrvReleaseLib();

  if(g_bConsoleEnabled) {
    exit(nExitCode);
  }

  return(OTX_S_OK);
}





/*******************************************************************************
@func
  POTS Li set state
*******************************************************************************/
void DemoSetState(DemoDeviceCallState newState, 
                  OTX_UINT32 deviceNumber,
                  DemoDevicePotsType potsType,
                  DemoDeviceCallState checkState)
{
  struct sPotsLi *pPotsLi;
  
  // Make sure that we do not try to set it to state that is handled 
  // by the driver assert (newState >= OTX_SLIC_CS_END_OF_STATES);
  if(newState < DEMO_CALL_END_OF_STATES) {
    if(g_nDbgSetting < DEMO_DBG_LEVEL_1) {
      DemoLogf("**** %s[%d] Setting %d state, %s\n",
               potsType ? "FXS" : "FXO",
               deviceNumber,
               newState, 
               g_sqszDeviceCallState[newState]);
    }
  }
  else {
    DemoLogf("Error DemoSetState: State %d not valid\n", newState);

    return;
  }

  if(deviceNumber >= DEMO_LI_MAX) {
    DemoLogf("Error: deviceNumber %d not valid.  %d state\n", 
              deviceNumber, newState);
  }
  else {
    if(potsType == DEMO_FXS_POTS_TYPE) {
      // Setup pointers to current LI state
      pPotsLi = &g_sPotsDevs[deviceNumber].mFxsLi;
    }
    else
    if(potsType == DEMO_FXO_POTS_TYPE) {
      // Setup pointers to current LI state
      pPotsLi = &g_sPotsDevs[deviceNumber].mFxoLi;
    }
    else {
      DemoLogf("Error DemoSetState: DemoDevicePotsType %d not valid\n", 
               potsType);
      return;
    }

    if(newState == DEMO_EVENT_ERROR) {
      DemoLogf("Error event PotsLi[%d] State was = %s\n", 
               deviceNumber,
               g_sqszDeviceCallState[newState]);
      // There are no more state changes expected
      pPotsLi->nNextCallState = DEMO_NO_ACTION_NEEDED;
      pPotsLi->nLastCallState = DEMO_NO_ACTION_NEEDED;
      // Check to make sure memory was returned
      if(pPotsLi->pDtmfStr) {
        free(pPotsLi->pDtmfStr);
        pPotsLi->pDtmfStr = NULL;
      }    
    }

    if(newState == DEMO_NO_ACTION_NEEDED) {
      // There are no more state changes expected
      pPotsLi->nNextCallState = DEMO_NO_ACTION_NEEDED;
      pPotsLi->nLastCallState = DEMO_NO_ACTION_NEEDED;
      // Check to make sure memory was returned
      if(pPotsLi->pDtmfStr) {
        free(pPotsLi->pDtmfStr);
        pPotsLi->pDtmfStr = NULL;
        // Why has this not been done before now
        DemoLogf("SW sync error PotsLi[%d] State was = %s\npDtmfStr should be NULL\n", 
                 deviceNumber,
                 g_sqszDeviceCallState[newState]);
      }
      
      pPotsLi->nPrevCallState = pPotsLi->nCallState;
    }
    else {

      // Perfrom some SW sequence verification for transition states.
      // This is intended for debuging.
      if(pPotsLi->nNextCallState < DEMO_LI_INIT_COMPLETE) {
        // Next state was set to an active state. Perform a
        // check to make sure events are processed as expected.
        if((pPotsLi->nNextCallState != newState) &&
           (pPotsLi->nLastCallState != newState) &&  // Ended up in correct state
           (checkState != DEMO_NO_ACTION_NEEDED)) {
          DemoLogf("    SW sync warning PotsLi[%d]\n"
                   "   Expected %s\n   Actual %s\n", 
                   deviceNumber,
                   g_sqszDeviceCallState[pPotsLi->nNextCallState],
                   g_sqszDeviceCallState[newState]);
        }
      }

      pPotsLi->nPrevCallState = pPotsLi->nCallState;
      pPotsLi->nCallState = newState;
    }
  }

  return;
}


/*******************************************************************************
  @func
    POTS Li state Machine. 
    This function performs the state transition needed for POTS sequencing
*******************************************************************************/
void DemoFxoStateMachine(OTX_UINT32 deviceNumber)
{
//  OTX_RESULT result = OTX_S_OK;

  struct sPotsLi *pPotsLi;

  // Setup pointers to current LI state
  pPotsLi = &g_sPotsDevs[deviceNumber].mFxoLi;

  // Display the current state if it is a transition state
  if(pPotsLi->nCallState != DEMO_NO_ACTION_NEEDED) {
    DemoLogf("Li %d Current state %s [%d]\n", 
             deviceNumber,
             g_sqszDeviceCallState[pPotsLi->nCallState], 
             pPotsLi->nCallState);
  }

  switch (pPotsLi->nCallState)      
  {           

    default:
        DemoLogf("Error: Unsupported event device %d\n", deviceNumber);
    break;

  }

}


OTX_RESULT DemoFxoSetupBurstSendReceive(char *pRecvFile, 
                                        char *pSendFile,
                                        OTX_INT32 nTsToRecord,
                                        OTX_INT32 nTsToSend)
/*******************************************************************************

  @func
  DemoFxoSetupBurstSendReceive(char *pRecvFile, 
                               char *pSendFile,
                               OTX_INT32 nTsToRecord,
                               OTX_INT32 nTsToSend)

  This function is available to C++ application development.
  The function is used in C++ application to initialize sending and 
  receiving data using the burst device. Calling function will need
  to pass into the function the name of the recieve and send files,
  as well as the timeslot being used. The options for the TS input
  are a single timeslot (0-31) or all timeslots (-1).

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_UINT32  nTxBufSize;
  OTX_UINT32  nTxItemSize;
  OTX_UINT32  ui32;
  OTX_UINT32  nDrvTxBufSize;
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  char *pInitDataBuf;
  char nSilence;

  // Check to see if the burst device is already active
  if(g_sBurstDevs.mBurstReceiver.bActive == OTX_FALSE && 
     g_sBurstDevs.mBurstSender.bActive   == OTX_FALSE &&
     g_sBurstDevs.mBurstReceiver.pRxFile == NULL      && 
     g_sBurstDevs.mBurstSender.pTxFile   == NULL      && 
     DemoIsBurstDeviceEnabled()          == OTX_FALSE) {

    g_sBurstDevs.mBurstReceiver.pRxFile = fopen(pRecvFile, "wb");
    if (g_sBurstDevs.mBurstReceiver.pRxFile == NULL) {
      DemoLogf("Error: Could not open file %s. Command aborted.\n", 
               pRecvFile);

      result = OTX_E_ACCESSDENIED;
      return result;
    }
    
    g_sBurstDevs.mBurstReceiver.nTsToRecord = nTsToRecord;
                   
    DemoLogf("Burst Receiver:\n");
    if (nTsToRecord == -1) {
      DemoLogf("Recording all 32 Burst Timeslots into file %s\n", 
               pRecvFile);
    } else {
      DemoLogf("Recording TS%d of Burst Highway into file %s\n", 
               nTsToRecord, 
               pRecvFile);
    }

    // BurstSender
    g_sBurstDevs.mBurstSender.pTxFile = fopen(pSendFile, "rb");
    if (g_sBurstDevs.mBurstSender.pTxFile == NULL) {
      DemoLogf("Error: Could not open file %s \n", pSendFile);

      result = OTX_E_ACCESSDENIED;
      return result;
    }

    g_sBurstDevs.mBurstSender.nTsToSend = nTsToSend;
    
    DemoLogf("BurstSender:\n"); 
    if(g_demoEnv.law == OTX_DATA_FORMAT_UINT16) {
      DemoLogf("Sending data on TS%d-%d of the Burst highway from file %s\n", 
               nTsToSend, 
               nTsToSend + 1,
               pSendFile);
    }
    else {
      DemoLogf("Sending data on TS%d of the Burst highway from file %s\n", 
               nTsToSend,
               pSendFile);
    }

    /*
    ** Initialize data in Burst buffer
    */
    switch (g_demoEnv.law) {
      case OTX_DATA_FORMAT_COMPAND8_A_LAW:
        nSilence = (char) DEMO_A_LAW_SILENCE; // silence in a-law mode
        break;                         
      case OTX_DATA_FORMAT_COMPAND8_U_LAW:
        nSilence = (char) DEMO_U_LAW_SILENCE; // silence in u-law mode
        break;
      case OTX_DATA_FORMAT_UINT16:
        nSilence = 0; // silence in Linear data mode
        break;
    }

    // Prime the application transmit buffer with silence
    nTxItemSize = sizeof(g_sBurstDevs.mBurstSender.sqTxBuf[0]);
    nTxBufSize = sizeof(g_sBurstDevs.mBurstSender.sqTxBuf) / nTxItemSize;
    memset(&g_sBurstDevs.mBurstSender.sqTxBuf[0], 
           nSilence, 
           nTxBufSize);

    // Prime the OTX driver transmit buffer with silence
    //OTX_ATTR_BURST_SENDER_FIFO_SIZE, Host buffer
    result = OtxDrvGetAttributeValueUint32(g_hPhysDevs.hBurst, 
                                           OTX_ATTR_BURST_SENDER_FIFO_SIZE,
                                           &nDrvTxBufSize); 
    DemoCheckRc(g_hPhysDevs.hBurst, result);

    /*
    ** Prime burst transmit buffer in OTX driver with silence.
    ** This data will be transmitted then the data from the 
    ** input file will be transmitted.
    */
    DemoLogf("Load Burst transmit buffer with silence.\n");

    pInitDataBuf = (char *) malloc(nDrvTxBufSize);

    memset(pInitDataBuf, 
           nSilence, 
           nDrvTxBufSize);
    
    ui32 = nDrvTxBufSize;
    result = OtxBurstInitSendBuffer(g_hPhysDevs.hBurst, 
                                    0, 
                                    pInitDataBuf, 
                                    &ui32);
    // Finished with this buffer. 
    // Return it here while we have the chance.
    free(pInitDataBuf);
    DemoCheckRc(g_hPhysDevs.hBurst, result);

    // Check the amount transferred with how much we 
    // requested to be sent they should be the same.
    if((ui32 != nDrvTxBufSize) &&
       (g_sBurstDevs.mBurstSender.bVerbose)) {
       DemoLogf("Burst buffer transmit size error.\n");
       DemoLogf("    Expected transfer size %d\n", nDrvTxBufSize);
       DemoLogf("    Actual transfer size %d\n", ui32);
    }

#if 0 // DMA start signal not needed for this demo
    // This will create a lot of events which can cause the system to
    // become slow to respond to user inputs.
    // Enable DMA start signal for first DMA transfer
    result = OtxDrvSetAttributeValueBool(g_hPhysDevs.hBurst, 
                                         OTX_ATTR_BURST_DMA_RECEIVE_SIGNAL,  
                                         OTX_TRUE); 
    DemoCheckRc(g_hPhysDevs.hBurst, result);
    result = OtxDrvSetAttributeValueBool(g_hPhysDevs.hBurst, 
                                         OTX_ATTR_BURST_DMA_SEND_SIGNAL,  
                                         OTX_TRUE); 
    DemoCheckRc(g_hPhysDevs.hBurst, result);
    // This counter is used to limit the number of events produced
    g_nDmaEventCnt = 0;
#endif
    g_sBurstDevs.mBurstReceiver.bActive = OTX_TRUE;
    g_sBurstDevs.mBurstSender.bActive   = OTX_TRUE;

    // By enabling the Burst device, we start the process of transferring 
    // data from the hardware to the driver via DMA. The data is stored in 
    // the Burst receive buffer. Data is also being transferred from the
    // Burst send buffer to the hardware via a second DMA channel.
    DemoLogf("Enable g_hPhysDevs.hBurst\n");
    result = OtxDrvEnable(g_hPhysDevs.hBurst, OTX_TASK_SYNC, 5000L);
    DemoCheckRc(g_hPhysDevs.hBurst, result);
  } 
  else {
    result = OTX_E_IN_USE;
  }

  return result;
}







/*******************************************************************************
**
** Exported Function
**
*******************************************************************************/



OTX_RESULT DemoInitializeDebugConsole( void )
/*******************************************************************************

  @func
  DemoInitializeDebugConsole( void )

  This function is used in C++ application to initialize the OTX debug console.
  This function is normally part of the main() in other OTXapplication demos.
  It is not needed for C++ application and is provided only as a diagnostic
  tool.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  g_bConsoleEnabled = OTX_TRUE;
  OsaConsoleInit();

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoInitializeEventHandler(
  OTX_UINT32 potsLiNumber,
  void *hwBase, 
  void (*EventHandler)(void *hwBase, void *hwEvent, void *hwParms, void *potLiNum))
/*******************************************************************************

  @func
  DemoInitializeEventHandler( 
              OTX_UINT32 potsLiNumber,
              void *hwBase, 
              void (*EventHandler)(void *hwBase,  (Value assigned by user)
                                   void *hwEvent, (DemoHwEvent)
                                   void *hwParms, (Value returned by event) 
                                   void *potLiNum (FXO line number)
                                  ))


  This function is used in C++ application to initialize the callback function.
  Each of the LI's will need to be configured with an event handler, even if
  they are the same object.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_UINT32 bufferSize;
  OTX_TASK_REF *pTmpPtr;
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoInitializeEventHandler: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }
  pTmpPtr = (OTX_TASK_REF *) hwBase;
  // User value to be returned with event
  g_sPotsDevs[potsLiNumber].mFxoLi.hwBase = (OTX_TASK_REF) *pTmpPtr; 
  g_sPotsDevs[potsLiNumber].mFxoLi.EventHandler = EventHandler;

  // For now just use the default string
  bufferSize = OsaStrLen(g_nDefaultParms) + 2;
  g_sPotsDevs[potsLiNumber].mFxoLi.evtTxtParms = (char *) malloc(bufferSize);
  if(g_sPotsDevs[potsLiNumber].mFxoLi.evtTxtParms) {
    sprintf( g_sPotsDevs[potsLiNumber].mFxoLi.evtTxtParms, "%s%d", 
             g_nDefaultParms, // Default string
             potsLiNumber);   // with LI number
  }
  else {
    result = OTX_E_OUTOFMEMORY;
    DemoCheckRc(OTX_INVALID_HANDLE_VALUE, g_nDemoAppResultCode);
  }

  return(result);
}


OTX_RESULT DemoConfigureHardware( DemoEnvT *DemoSetup,
                                  void (*LogUtility)(char *formatStr,va_list argList) )
/*******************************************************************************

  @func
  DemoConfigureHardware( DemoEnvTSP *DemoSetup )

  DemoSetup can be a NULL pointer which indicates use of only default vaules.
  It can also point to a data structure which will be used to over write
  the default values. 

  This function is used in C++ application to configure the OTX hardware
  and software. These system setting are normally changed in the function 
  DemoParseCmdLineArgs which is part of the main() in most OTX application 
  demos. If DemoSetup is a null pointer then the default setting are used.
  This function call is needed to at least configure the setting to the
  default values.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  g_nDemoAppResultCode = OTX_S_OK; // Start with good status

  // Set reasonable defaults before reading user data
  g_demoEnv.bExitOnError      = OTX_FALSE;
  g_demoEnv.bContinueOnError  = OTX_FALSE; // used to allow background task to run
  g_demoEnv.outFileName       = NULL;
  g_demoEnv.logFileName       = g_pLogFile;
  g_demoEnv.law               = OTX_DATA_FORMAT_COMPAND8_U_LAW;
  g_demoEnv.boardNo           = DEMO_DEFAULT_BOARD_NO;
  g_demoEnv.fxoStartNo        = DEMO_DEFAULT_FXO_NO;
  g_demoEnv.fxoMaxNo          = DEMO_FXO_MAX;
  g_demoEnv.fxsMaxNo          = DEMO_FXS_MAX;
  g_demoEnv.nSetId            = OTX_CST_POTS_CFG_SET_USA;
  g_demoEnv.nBoardType        = OTX_DEVICE_ARNI_6X6_PCI;


  if(LogUtility) {
    // Setup log Utility function from user
    g_fLogUtility = LogUtility;
  }
  else {
    // Setup default utility
    g_fLogUtility = NULL; // None needed at this time
  }

  // Check to see if any changes are needed to the default settings
  if(DemoSetup != NULL) {
//    DemoLogf("Some non-default values were used in application\n");

    // If NULL pointer keep default setting
    if(DemoSetup->outFileName != NULL) {   // DSP out file
      g_demoEnv.outFileName = DemoSetup->outFileName;
    } 
    
    // If negative value was sent keep the default setting
    if(DemoSetup->boardNo >= 0) {   // Board number
      g_demoEnv.boardNo = DemoSetup->boardNo;
    }
    
    // If negative value was sent keep the default setting
    if(DemoSetup->fxoStartNo >= 0) {   // FXO number
      g_demoEnv.fxoStartNo = DemoSetup->fxoStartNo;
      g_firstUsableLi = g_demoEnv.fxoStartNo;
    }
    
    // If negative value was sent keep the default setting
    if(DemoSetup->fxoMaxNo >= 0) {   // Total FXO number
      g_demoEnv.fxoMaxNo = DemoSetup->fxoMaxNo;
    } 

    // If negative value was sent keep the default setting
    if(DemoSetup->fxsMaxNo >= 0) {   // Total FXS number
      g_demoEnv.fxsMaxNo = DemoSetup->fxsMaxNo;
    }
   
    // If negative value was sent keep the default setting
    if(DemoSetup->nBoardType >= 0) {   // Board Type
      g_demoEnv.nBoardType = DemoSetup->nBoardType;
    } 
      
    // If negative value was sent keep the default setting
    if(DemoSetup->law >= 0) {   // Companding Law
      g_demoEnv.law = DemoSetup->law;
    } 
    
    // If negative value was sent keep the default setting
    if(DemoSetup->nSetId >= 0) {   // Configuration Set
      g_demoEnv.nSetId = DemoSetup->nSetId;
    }
  }
  else {
//    DemoLogf("Default values used in application\n");
  }

  return(g_nDemoAppResultCode);
}


OTX_RESULT DemoInitialize( void )
/*******************************************************************************

  @func
  DemoInitialize( void )

  This function is used in C++ application to initialize the OTX hardware
  and software. This function is normally part of the main() in other OTX
  application demos.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_INT32  indexCnt = 0;
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_EVENT  hNotificationEvent;
  OTX_HANDLE hEventQueue;

  g_nDemoAppResultCode = OTX_S_OK; // Start with good status

  OsaMutexInit(&g_demoLogfCritSec);

  if ((g_pDemoLogFile = fopen(g_demoEnv.logFileName, "wt")) == NULL) {
    if(g_bConsoleEnabled) {
      printf("Couldn't open logfile %s\n", g_demoEnv.logFileName);
    }
    g_nDemoAppResultCode = OTX_E_CALL_FAIL;
    DemoCheckRc(OTX_INVALID_HANDLE_VALUE, g_nDemoAppResultCode);
    return(g_nDemoAppResultCode);
  }

  DemoLogf("Odin TeleSystems Inc.\n", __DATE__);
  DemoLogf("Arni-6x6-PCI, Basic FXO Demo Program.\n");

  DemoLogf("Log file is %s\n", g_demoEnv.logFileName);
  DemoLogf("Board number %d\n", g_demoEnv.boardNo);
  DemoLogf("FXO   number %d\n", g_demoEnv.fxoStartNo);
  if (g_demoEnv.outFileName) {
    DemoLogf("Out file to be loaded is %s\n", g_demoEnv.outFileName);
  }

  // Query Library revision
  {
    char szVersionInfo[255];
    OTX_BOOL bIsStaticLinkedLibrary;
    char szLibFileName[64];
    result = OtxDrvGetAttributeValueSz(OTX_LIB_HANDLE, 
                                       OTX_ATTR_LIB_REV_STR, 
                                       szVersionInfo, 
                                       255); 
    DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    result = OtxDrvGetAttributeValueBool(OTX_LIB_HANDLE, 
                                         OTX_ATTR_LIB_TYPE_STATIC, 
                                         &bIsStaticLinkedLibrary); 
    DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    result = OtxDrvGetAttributeValueSz(OTX_LIB_HANDLE, 
                                       OTX_ATTR_LIB_FILE_NAME, 
                                       szLibFileName, 
                                       64); 
    DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    
    DemoLogf("Library version %s (filename %s, %s linked)\n", 
             szVersionInfo, 
             szLibFileName, 
             bIsStaticLinkedLibrary ? "static":"dynamic");
  }


  // Connect to the Driver
  DemoLogf("Connecting lib...\n");
  result = OtxDrvConnectLib(); 
  switch (OTX_RESULT_CODE(result)) {
  case OTX_RES_HANDLE:
    DemoLogf("Error: Could not connect to the OTX library.\n"
             "Possible cause: OTX Driver not loaded\n");
    break;
  case OTX_RES_NOT_SUPPORTED:
    DemoLogf("Error: Mismatch between OTX Driver revision and "
             "OTX Library revision.\nRevisions must match.\n");
    break;
  default:
    break;
  }
  DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }


  // Create Event Queues for Driver --> Application Communications
  DemoCreateEventQueue(&g_hNotificationEvent, &g_hEventQueue);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }


  // Setup event gueue for each of the LIs to process calls
  DemoCreateEventQueue(&hNotificationEvent, 
                       &hEventQueue);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // For now a single event gueue is used by each FXO/FXS LI
  for(indexCnt = 0; indexCnt < DEMO_LI_MAX; indexCnt++) {

    // Setup event gueue for each of the LIs to process calls
    // Create Event Queues for Driver --> Application Communications
    DemoCreateEventQueue(&g_sPotsDevs[indexCnt].hNotificationEvent, 
                         &g_sPotsDevs[indexCnt].hEventQueue);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }


    // Let us setup some the other globals
    g_sPotsDevs[indexCnt].mFxoLi.pDtmfStr = (char *) NULL; // No DTMF string 
    g_sPotsDevs[indexCnt].mFxoLi.bOffHook = OTX_FALSE; // ON-Hook
    g_sPotsDevs[indexCnt].mFxoLi.nLiConnected = DEMO_NO_LI_CONNECTED;
    g_sPotsDevs[indexCnt].mFxoLi.nCallState     = DEMO_INITIALIZING;
    g_sPotsDevs[indexCnt].mFxoLi.nPrevCallState = DEMO_INITIALIZING;
    g_sPotsDevs[indexCnt].mFxoLi.nNextCallState = DEMO_NO_ACTION_NEEDED;
    g_sPotsDevs[indexCnt].mFxoLi.nLastCallState = DEMO_NO_ACTION_NEEDED;
    // Clear pointer to event handler callback function
    g_sPotsDevs[indexCnt].mFxoLi.hwBase = 0; 
    g_sPotsDevs[indexCnt].mFxoLi.EventHandler = NULL;
    g_sPotsDevs[indexCnt].mFxoLi.hwParms = 0;
    g_sPotsDevs[indexCnt].mFxoLi.evtTxtParms = g_nDefaultParms; 

    g_sPotsDevs[indexCnt].mFxsLi.pDtmfStr = (char *) NULL; // No DTMF string 
    g_sPotsDevs[indexCnt].mFxsLi.bOffHook = OTX_FALSE; // ON-Hook
    g_sPotsDevs[indexCnt].mFxsLi.nLiConnected = DEMO_NO_LI_CONNECTED;
    g_sPotsDevs[indexCnt].mFxsLi.nCallState     = DEMO_INITIALIZING;
    g_sPotsDevs[indexCnt].mFxsLi.nPrevCallState = DEMO_INITIALIZING;
    g_sPotsDevs[indexCnt].mFxsLi.nNextCallState = DEMO_NO_ACTION_NEEDED;
    g_sPotsDevs[indexCnt].mFxsLi.nLastCallState = DEMO_NO_ACTION_NEEDED;
    // Clear pointer to event handler callback function
    g_sPotsDevs[indexCnt].mFxsLi.hwBase = 0;
    g_sPotsDevs[indexCnt].mFxsLi.EventHandler = NULL;
    g_sPotsDevs[indexCnt].mFxsLi.hwParms = 0;
    g_sPotsDevs[indexCnt].mFxsLi.evtTxtParms = g_nDefaultParms; 

    g_bLineSensePending[indexCnt] = OTX_FALSE;

  }

  // Connect (get handles) to the physical devices on the Arni-16-PCI board
  DemoOpenPhysicalDevices();
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // Read Serial Number from the board
  {
    OtxAttribTypeE  eAttribType;    // Type of the attribute, if attribute exists
    OTX_UINT32      cbAttribValue;  // Size in bytes of attribute value (Get value with <f OtxDrvGetAttributeValue>)
    OTX_BOOL        bReadOnly;      // Is attribute writable or read-only
    char *pszSerialNumber;

    result = OtxDrvGetAttributeType(g_hPhysDevs.hBoardController0, 
                                    OTX_ATTR_BRD_SERIAL_NUMBER, 
                                    &eAttribType, 
                                    &cbAttribValue, 
                                    &bReadOnly); 
    // Evaluate and save this result in the application log 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    assert(eAttribType == OTX_ATTRIB_SZ);
    assert(bReadOnly == OTX_TRUE);
    pszSerialNumber = (char *) malloc(cbAttribValue * sizeof(char));
    result = OtxDrvGetAttributeValueSz(g_hPhysDevs.hBoardController0, 
                                       OTX_ATTR_BRD_SERIAL_NUMBER, 
                                       pszSerialNumber, 
                                       cbAttribValue); 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    DemoLogf("Board Serial Number: %s\n", pszSerialNumber);
    free(pszSerialNumber);
  }

  // Read Build Number from the board
  {
    OtxAttribTypeE  eAttribType;    // Type of the attribute, if attribute exists
    OTX_UINT32      cbAttribValue;  // Size in bytes of attribute value (Get value with <f OtxDrvGetAttributeValue>)
    OTX_BOOL        bReadOnly;      // Is attribute writable or read-only
    char *pszBrdBuildNumber;

    result = OtxDrvGetAttributeType(g_hPhysDevs.hBoardController0, 
                                    OTX_ATTR_BRD_BUILD, 
                                    &eAttribType, 
                                    &cbAttribValue, 
                                    &bReadOnly); 
    // Evaluate and save this result in the application log 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    assert(eAttribType == OTX_ATTRIB_SZ);
    assert(bReadOnly == OTX_TRUE);
    pszBrdBuildNumber = (char *) malloc(cbAttribValue * sizeof(char));
    result = OtxDrvGetAttributeValueSz(g_hPhysDevs.hBoardController0, 
                                       OTX_ATTR_BRD_BUILD, 
                                       pszBrdBuildNumber, 
                                       cbAttribValue); 
    // Evaluate and save this result in the application log 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    DemoLogf("Board Build Number: %s\n", pszBrdBuildNumber);
    free(pszBrdBuildNumber);
  }

  {
    // Read CPLD Build Numbers from the board
    OtxAttribTypeE  eAttribType;    // Type of the attribute, if attribute exists
    OTX_UINT32      cbAttribValue;  // Size in bytes of attribute value (Get value with <f OtxDrvGetAttributeValue>)
    OTX_BOOL        bReadOnly;      // Is attribute writable or read-only
    char *pszCpldBuildNumbers;
    
    result = OtxDrvGetAttributeType(g_hPhysDevs.hBoardController0, 
                                    OTX_ATTR_BRD_CPLD_BUILD, 
                                    &eAttribType, 
                                    &cbAttribValue, 
                                    &bReadOnly); 
    // Evaluate and save this result in the application log 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    assert(eAttribType == OTX_ATTRIB_SZ);
    assert(bReadOnly == OTX_TRUE);
    pszCpldBuildNumbers = (char *) malloc(cbAttribValue * sizeof(char));
    result = OtxDrvGetAttributeValueSz(g_hPhysDevs.hBoardController0, 
                                       OTX_ATTR_BRD_CPLD_BUILD, 
                                       pszCpldBuildNumbers, 
                                       cbAttribValue); 
    // Evaluate and save this result in the application log 
    DemoCheckRc(g_hPhysDevs.hBoardController0, result);
    if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
      return(g_nDemoAppResultCode);
    }
    DemoLogf("CPLD Build:\n%s", pszCpldBuildNumbers);

    free(pszCpldBuildNumbers);

  }

  // Enable Physical devices. Their device state should now be OTX_DEVICE_WORKING
  DemoEnablePhysicalDevices();
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // Create and get handles to the Logical devices needed by this application
  DemoCreateLogicalDevices();
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // Create and get handles to the Pipe devices needed by this application
  // Connect Pipes to Physical and Logical Devices
  DemoConnectDevices();
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // Initialized the Connected Logical Devices
  DemoInitializeLogicalDevices();
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }

  // Enable Logical devices. Their device state should now be OTX_DEVICE_WORKING
  DemoEnableLogicalDevices(); 

  OsaThreadStart(DemoIdleFunction);
  if ( OTX_FAILURE(g_nDemoAppResultCode) ) {
    return(g_nDemoAppResultCode);
  }
  
  // For now a single event gueue is used by each FXO/FXS LI
  for(indexCnt = 0; indexCnt < DEMO_LI_MAX; indexCnt++) {
    g_sqPotsLiTask[indexCnt].nFxo = indexCnt;
    g_sqPotsLiTask[indexCnt].nFxs = indexCnt;
    g_sqPotsLiTask[indexCnt].nDsp = indexCnt;
    OsaThreadStartEx(DemoPotsLiFunction, 
                     (void *) &g_sqPotsLiTask[indexCnt].nDsp);
  }

  // Start the Line Sensing Thread, which requests period line sensing from  
  // the PotsLi to faciliate monitoring of Far-End-Hangup conditions
  OsaThreadStart(DemoLineSensingFunction);

  
  return(g_nDemoAppResultCode);
}


OTX_RESULT DemoAppExit( void )
/*******************************************************************************

  @func
  DemoAppExit( void )

  This function is used in C++ application to exit and cleanup the OTX 
  resources. This function is normally part of the main() in other OTX 
  application demos.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_UINT32 indexCnt;

  g_bLineSensingThreadActive = OTX_FALSE;
  // Answer task contiuously answers incomming calls
  if(g_nContinuousAnswer) {
    g_nContinuousAnswer = OTX_FALSE;
    OsaThreadSleep(500);  // Let task wakeup to see it is time to quite
  }
  // Calling task continuously makes calls
  if(g_nContinuousCalling) {
    g_nContinuousCalling = OTX_FALSE;
    OsaThreadSleep(500);  // Let task wakeup to see it is time to quite
  }

  // Delete allocated resources
  DemoExit(0);

  for(indexCnt = 0; indexCnt < DEMO_LI_MAX; indexCnt++) {
    if(g_sPotsDevs[indexCnt].mFxoLi.evtTxtParms) {
      free(g_sPotsDevs[indexCnt].mFxoLi.evtTxtParms);
      g_sPotsDevs[indexCnt].mFxoLi.evtTxtParms = NULL;
    }
    if(g_sPotsDevs[indexCnt].mFxoLi.pDtmfStr) {
      free(g_sPotsDevs[indexCnt].mFxoLi.pDtmfStr);
      g_sPotsDevs[indexCnt].mFxoLi.pDtmfStr = NULL;
    }
  }

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoProcessDrvEvent(DemoDeviceCallState DemoEventCode,        
                               DemoDevicePotsType potsType, 
                               OTX_UINT32 potsLiNumber,
                               OtxEventDataS *pEventData)
/*******************************************************************************

  @func
  DemoProcessDrvEvent(OTX_UINT32 OtxEventCode,        
                      OTX_UINT32 potsType, 
                      OTX_UINT32 potsLiNumber,
                      OtxEventDataS *pEventData)

  This function is used in C++ application to convert the OTX driver events
  to the C++ application event. This function will need to be customized by  
  the user for thier application. This function also performs the necessary 
  hardware calls needed by the OTX event. This function is not actually 
  called by the C++ application but is called by the OTX event thread to 
  perform the tasks requested by the C++ application. 


  @comm

  This function returns OTX_S_OK if successful or
  an OTX error code if failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  // C++ application developer will need to add and modify the code
  // within this function as needed to achieve their requirements.
  // This is the entry point for all OTX to Demo events. The user 
  // could modify this function for thier application.

  if(potsLiNumber > DEMO_LI_MAX) {
    // Software error. not a valid Li number
    // In a real application branch based on the data
    DemoLogf("DemoProcessDrvEvent: potsLiNumber not valid %d\n", potsLiNumber);

    g_nDemoAppResultCode = OTX_E_UNEXPECTED;
  }
  else {

    // Determine the interface that produced the event
    switch (potsType) {
      // FXS Interface
      case (DEMO_FXS_POTS_TYPE):  
  #if DEMO_FXS_MAX != 0      
        DemoProcessFxsEvent(DemoEventCode,        
                            potsType, 
                            potsLiNumber,
                            pEventData);
  #endif
        break;

      // FXO Interface
      case (DEMO_FXO_POTS_TYPE):  
  #if DEMO_FXO_MAX != 0
        DemoProcessFxoEvent(DemoEventCode,        
                            potsType, 
                            potsLiNumber,
                            pEventData);
  #endif
      break;

      // Burst Interface
      case (DEMO_BURST_DATA_TYPE):  
        // Not used at this time
      break;

      default:

        // Software error. not a valide type
        // In a real application branch based on the data
        DemoLogf("DemoProcessDrvEvent: potsType not valid 0x%x\n", potsType);

        g_nDemoAppResultCode = OTX_E_UNEXPECTED;
      break;
    }
  }
  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoProcessFxsEvent(DemoDeviceCallState DemoEventCode,        
                               DemoDevicePotsType potsType, 
                               OTX_UINT32 potsLiNumber,
                               OtxEventDataS *pEventData)
/*******************************************************************************

  @func
  DemoProcessFxsEvent(OTX_UINT32 OtxEventCode,        
                      OTX_UINT32 potsType, 
                      OTX_UINT32 potsLiNumber)

  This function is used in C++ application to convert the OTX driver events
  to the C++ application event. This function will need to be customized by  
  the user for thier application. This function also performs the necessary 
  hardware calls needed by the OTX event. This function is not actually 
  called by the C++ application but is called by the OTX event thread to 
  perform the tasks requested by the C++ application.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  
#if DEMO_FXS_MAX == 0
  // FXS is not used by this application
  result = OTX_E_NOTIMPL;
  DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);

#else
  OTX_UINT32 slicState = 0;
  
  // Determine the interface that produced the event
  switch (DemoEventCode) {

    case (DEMO_MAKE_BUSY):
    break;

    case (DEMO_STATE_CHANGE):
    break;

    case (DEMO_INITIALIZING):
    break;

    case (DEMO_MAKE_RING_BACK):
    break;

    case (DEMO_MAKE_REORDER):
    break;

    case (DEMO_MAKE_CONGESTION):
    break;

    case (DEMO_OFFHOOK):  

      // SLIC is off hook setup connection FSO to FXS
      g_liConNumber_1 = potsLiNumber;
      if(g_sPotsDevs[potsLiNumber].mFxsLi.bOffHook == OTX_FALSE) {
        DemoLogf("    FXS[%d] Off Hook phone making connection\n", 
                 potsLiNumber);

        g_liConNumber_1 = potsLiNumber;
        // Each slic will have a fixed location within the data stream.
        // Slic0 will be at TS0 and TS1, 
        // Slic1 will be at TS3 and TS4... Slic5 will be at TS15 and TS16
        g_liConTimeSlot = (OTX_UINT16) ((potsLiNumber * 3));

        // Connect slic audio for device starting the call
        result = OtxSlicEnableAudio( g_hPhysDevs.hSlicLi[potsLiNumber], 
                                     &slicState );  
        DemoCheckRc(g_hPhysDevs.hSlicLi[potsLiNumber], result);

        if(slicState == OTX_SLIC_CS_ONHOOK) {
          // If the phone was just put back into the cradle the event
          // would be in the queue. It should be processed shortly.
          DemoLogf("Warning: Driver state indicates Li%d OTX_SLIC_CS_ONHOOK\n", 
                   potsLiNumber);
        } 
    
        // Set Active Pots Li Off-Hook ...
        DemoLogf("    Pots FXS#%d Off-hook\n", potsLiNumber);
        result = OtxCstPotsOffHook(g_hLogicDevs.hPotsLi[potsLiNumber], 
                                   0x1000, 
                                   2000); 
        DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

        DemoSetState(DEMO_OFFHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_ONHOOK); // Check SW sync

        g_sPotsDevs[potsLiNumber].mFxsLi.bOffHook = OTX_TRUE;
        g_sPotsDevs[potsLiNumber].mFxsLi.nLiConnected = potsLiNumber;
      }
      else {
        DemoLogf("    FXS[%d] Off Hook: phone already Off Hook\n", 
                 potsLiNumber);

        // Call setstate just incase SW is not in sync with HW
        DemoSetState(DEMO_OFFHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_OFFHOOK); // Check SW sync
      }
      g_liConNumber_1 = DEMO_NO_LI_CONNECTED;
  
    break;

    // Slic indicates ONHOOK condition
    case (DEMO_ONHOOK):

      g_liConNumber_1 = potsLiNumber; 
      if(g_sPotsDevs[potsLiNumber].mFxsLi.bOffHook == OTX_TRUE) {
        // Set Active Pots Li On-Hook ...
        DemoLogf("    Pots FXS#%d On-hook\n", potsLiNumber);
        result = OtxCstPotsOnHook(g_hLogicDevs.hPotsLi[potsLiNumber], 
                                  0x1001, 
                                  2000); 
        DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

        DemoSetState(DEMO_ONHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_OFFHOOK); // Check SW sync
        g_sPotsDevs[potsLiNumber].mFxsLi.bOffHook = OTX_FALSE;
        g_sPotsDevs[potsLiNumber].mFxsLi.nLiConnected = DEMO_NO_LI_CONNECTED;
      }
      else {
        DemoLogf("    FXS[%d] On Hook: phone already On Hook\n", 
                 potsLiNumber);

        // Call setstate just incase SW is not in sync with HW
        DemoSetState(DEMO_ONHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_ONHOOK); // Check SW sync
      }
      g_liConNumber_1 = DEMO_NO_LI_CONNECTED;
      
    break;


    case (DEMO_FLASHHOOK):
    break;

    case (DEMO_DIGIT_AVAILABLE):
    break;

    case (DEMO_DIGIT_AVAILABLE):
    break;

    case (DEMO_DIGIT_START_AVAILABLE):
    break;

    case (DEMO_CALLER_ID):
    break;

    case (DEMO_RINGING):
    break;

    case (DEMO_STOP_RINGING):
    break;

    case (DEMO_DTMF_TRANISTION):
    break;

    case (DEMO_LI_INIT_COMPLETE):
    break;

    case (DEMO_FAR_END_HANGUP):
      // FXS (SLIC) does not have a far end
    break;

    case (DEMO_EVENT_ERROR):
    break;

    case (DEMO_NO_ACTION_NEEDED):
    break;

    default:

      // We have a driver event that is not needed defined.
      DemoLogf("Unknown Process FXS %d event 0x%x\n", 
               potsLiNumber, DemoEventCode);

    break;
  }  
#endif

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoProcessFxoEvent(DemoDeviceCallState DemoEventCode,        
                               DemoDevicePotsType potsType, 
                               OTX_UINT32 potsLiNumber,
                               OtxEventDataS *pEventData)
/*******************************************************************************

  @func
  DemoProcessFxoEvent(OTX_UINT32 OtxEventCode,        
                      OTX_UINT32 potsType, 
                      OTX_UINT32 potsLiNumber)

  This function is used in C++ application to convert the OTX driver events
  to the C++ application event. This function will need to be customized by  
  the user for thier application. This function also performs the necessary 
  hardware calls needed by the OTX event. This function is not actually 
  called by the C++ application but is called by the OTX event thread to 
  perform the tasks requested by the C++ application.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  
#if DEMO_FXO_MAX == 0
  // FXS is not used by this application
  result = OTX_E_NOTIMPL;
  DemoCheckRc(OTX_INVALID_HANDLE_VALUE, result);

#else
  OTX_RESULT otxRc;
  struct sPotsLi *pPotsLi;
  DemoDeviceCallState *pCurrentState;
  DemoDeviceCallState *pPrevState;

  // Setup pointers to current LI state
  pPotsLi = &g_sPotsDevs[potsLiNumber].mFxoLi;
  pPrevState = &g_sPotsDevs[potsLiNumber].mFxoLi.nPrevCallState;
  pCurrentState = &g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;

  // Determine the interface that produced the event
  switch (DemoEventCode) {
    case (DEMO_INITIALIZING):
    break;

    case (DEMO_STATE_CHANGE):
    break;

    case (DEMO_MAKE_BUSY):
    break;

    case (DEMO_MAKE_RING_BACK):
    break;

    case (DEMO_MAKE_REORDER):
    break;

    case (DEMO_MAKE_CONGESTION):
    break;

    case (DEMO_MAKE_OFFHOOK):
    break;

    case (DEMO_MAKE_ONHOOK):
      // Onhook remove old Caller ID
      g_szCallerId[potsLiNumber][0] = 0;
    break;

    case (DEMO_ONHOOK):
      // Onhook remove old Caller ID
      g_szCallerId[potsLiNumber][0] = 0;

      DemoLogf("FXO[%d] On-Hook command complete\n", 
               pEventData->m_nSourceId);

      DemoSetState(DEMO_ONHOOK, 
                   potsLiNumber, 
                   potsType,
                   DEMO_OFFHOOK); // Verify SW is in sync);
      pPotsLi->bOffHook = OTX_FALSE;
      pPotsLi->nLiConnected = DEMO_NO_LI_CONNECTED;

      if((pPotsLi->EventHandler)) {
        // User has setup an EventHandler
        DemoHwEvent nNewEvent;
        nNewEvent = HwEvent_disconnect;
        (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                (DemoHwEvent *) &nNewEvent, 
                                &(pPotsLi->hwParms),
                                &potsLiNumber);
      }

      if(pPotsLi->nLastCallState == DEMO_ONHOOK) {
        // Nothing more to do send event status
        DemoSetState(DEMO_NO_ACTION_NEEDED, 
                     potsLiNumber, 
                     potsType,
                     DEMO_NO_ACTION_NEEDED); // No check is needed
      }
      
      break;

    case (DEMO_OFFHOOK):
      // POTS LI FXO received an OFF HOOK event
      if(pPotsLi->bOffHook == OTX_FALSE) {

        DemoSetState(DEMO_OFFHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_ONHOOK); // Verify SW is in sync
        pPotsLi->bOffHook = OTX_TRUE; // Line is off hook
        pPotsLi->nLiConnected = potsLiNumber;
      }
      else {
        DemoSetState(DEMO_OFFHOOK, 
                     potsLiNumber, 
                     potsType,
                     DEMO_OFFHOOK); // Verify SW is in sync

        DemoLogf("FXO[%d] Was already Off-Hook\n", 
                 pEventData->m_nSourceId);
      }

      if((pPotsLi->EventHandler)) {
        // User has setup an EventHandler
        DemoHwEvent nNewEvent;
        nNewEvent = HwEvent_connect;
        (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                (DemoHwEvent *) &nNewEvent, 
                                &(pPotsLi->hwParms),
                                &potsLiNumber);
      }

      if(pPotsLi->nLastCallState == DEMO_OFFHOOK) {
        // Nothing more to do send event status
        DemoSetState(DEMO_NO_ACTION_NEEDED, 
                     potsLiNumber, 
                     potsType,
                     DEMO_NO_ACTION_NEEDED); // No check is needed
        if((pPotsLi->EventHandler)) {
          // User has setup an EventHandler
          DemoHwEvent nNewEvent;
          nNewEvent = HwEvent_init_completed;
          (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                  (DemoHwEvent *) &nNewEvent, 
                                  &(pPotsLi->hwParms),
                                  &potsLiNumber);
        }
      }
      else {
        // See if we have DTMF data to send
        if(pPotsLi->pDtmfStr) {

          OsaThreadSleep(500);

          DemoSetState(DEMO_SEND_DTMF, 
                       potsLiNumber, 
                       potsType,
                       DEMO_NO_ACTION_NEEDED); // No check is needed

          otxRc = DemoFxoSendDtmfDigits(potsLiNumber, 
                                        NULL, // already have this information
                                        pPotsLi->pDtmfStr);
          // Evaluate and save this result in the application log 
          DemoCheckRc(pEventData->m_hDevice, otxRc);
          // Return memory used to hold DTMF string
          free(pPotsLi->pDtmfStr);
          pPotsLi->pDtmfStr = NULL;
          if(OTX_FAILURE(otxRc)) {
            // Update the state
            DemoSetState(DEMO_EVENT_ERROR, 
                         potsLiNumber,
                         potsType,
                         DEMO_EVENT_ERROR); // Check to see if SW in sync
            // Error did the user provide EventHandler
            if((pPotsLi->EventHandler)) {
              // User has setup an EventHandler
              DemoHwEvent nNewEvent;
              nNewEvent = HwEvent_error;
              (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                      (DemoHwEvent *) &nNewEvent, 
                                      &(pPotsLi->hwParms),
                                      &potsLiNumber);
            }
          }
          else {
            // DTMF sent. Need to wait for DTMF complete
            // Keep track of were we are going
            pPotsLi->nNextCallState = DEMO_DTMF_TRANISTION;
          }
        }
        else {
          // Need to wait for dial tone?
          // Maybe this should be done before sending DTMF?

        }
      }
      DemoLogf("FXO[%d] Off-Hook command complete\n", 
               pEventData->m_nSourceId);

    break;

    case (DEMO_FLASHHOOK):
    break;

    case (DEMO_DIGIT_START_AVAILABLE):
    break;

    case (DEMO_DIGIT_AVAILABLE):
      {
        char digitDtmf;

        digitDtmf = DemoDtmfParamToChar(pEventData->m_nParam);

        // When Dialing we also receive DTMF
        if((pPotsLi->nCallState == DEMO_SEND_DTMF)     ||
           (pPotsLi->nPrevCallState == DEMO_SEND_DTMF) ||
           (pPotsLi->nLastCallState == DEMO_DTMF_TRANISTION) ) {
          // Digits are being sent

          DemoLogf("FXO[%d] Received its own digit - DtmfDetector digit %c\n", 
                   pEventData->m_nSourceId, 
                   digitDtmf);

        }
        else {
          DemoSetState(DEMO_DIGIT_AVAILABLE, 
                       potsLiNumber, 
                       potsType, 
                       DEMO_NO_ACTION_NEEDED); // No error check needed

          DemoLogf("FXO[%d] DtmfDetector MTONESTART, DTMF digit %c\n", 
                   pEventData->m_nSourceId, 
                   digitDtmf);

          // If an EventHandler is setup use it to send this digit
          if((pPotsLi->EventHandler)) {
            DemoHwEvent nNewEvent;
            char dataBuf[2];
            dataBuf[0] = digitDtmf;
            dataBuf[1] = '\0'; // terminate string

            // User has setup a eventhandler
            nNewEvent = HwEvent_digit_avail;
            (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                    (DemoHwEvent *) &nNewEvent, 
                                    dataBuf,
                                    &potsLiNumber);
          }
        }
      }
    break;

    case (DEMO_LOOP_TRANSITION):
    break;

    case (DEMO_CALLER_ID):
      {

        DemoLogf("FXO[%d] Caller ID detected.\n", 
                 pEventData->m_nSourceId);

        if(pEventData->m_nParam == OTX_CST_CALLER_ID_EC_NOERROR) {

          DemoSetState(DEMO_CALLER_ID, 
                       potsLiNumber, 
                       potsType,
                       DEMO_OFFHOOK); // Check to see if SW in sync

          g_szCallerId[potsLiNumber][0] = 0;

          // TODO: Move this code to a function
          otxRc = OtxDrvGetAttributeValueSz(pEventData->m_hDevice, 
                                            OTX_ATTR_CST_POTS_CALLER_ID, 
                                            g_szCallerId[potsLiNumber], 
                                            DEMO_MAX_CALLER_ID_STRING); 
          if (OTX_SUCCESS(otxRc)) {
            DemoLogf("PotsLi[%d] Caller Id = \"%s\"\n", 
                     potsLiNumber, 
                     g_szCallerId[potsLiNumber]);
          } 
          else 
          if (OTX_RESULT_CODE(otxRc) == OTX_E_BUSY) {
            DemoLogf("PotsLi[%d] Caller Id Overrun. Caller Id string lost. "
                     "Reseting the condition\n", 
                     potsLiNumber);
            OtxDrvSetAttributeValueSz(pEventData->m_hDevice, 
                                      OTX_ATTR_CST_POTS_CALLER_ID, 
                                      NULL); 
          } else {
            // Evaluate and save this result in the application log 
            DemoCheckRc(pEventData->m_hDevice, otxRc);
            DemoLogf("FXO[%d] Unexpected return code from "
                     "OtxDrvGetAttributeValueSz (otxRc=0x%X)\n", 
                     potsLiNumber, 
                     otxRc);
          }
        } 
        else {
          // Make sure value from last time is not reused
          g_szCallerId[potsLiNumber][0] = 0;
          DemoLogf("FXO[%d] Caller Id detection failure. nCode=%d\n", 
                   pEventData->m_nSourceId, 
                   pEventData->m_nParam);
        }

      }
    break;

    case (DEMO_MAKE_RINGING):
    break;

    case (DEMO_RINGING):

      DemoLogf("FXO[%d] Ring signal has been detected\n", 
               pEventData->m_nSourceId);

      // POTS LI FXO received ringing event
      if(pPotsLi->bOffHook == OTX_TRUE) {
        DemoLogf("SW sync error FXO[%d] Ring detected but phone Off-Hook\n", 
                 pEventData->m_nSourceId);
      }
      // Need to signal application phone is ringing
      if((pPotsLi->EventHandler)) {
        // User has setup a eventhandler
        DemoHwEvent nNewEvent;
        nNewEvent = HwEvent_ring;
        (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                (DemoHwEvent *) &nNewEvent, 
                                &(pPotsLi->hwParms),
                                &potsLiNumber);
      }

      DemoSetState(DEMO_RINGING, 
                   potsLiNumber, 
                   potsType,
                   DEMO_STOP_RINGING); // Check to see if SW in sync

    break;

    case (DEMO_STOP_RINGING):
      DemoLogf("FXO[%d] End of ring signal has been detected\n", 
               pEventData->m_nSourceId);
      // Check to see if this state has already been processed
      if((pPotsLi->nCallState != DEMO_RINGING) &&
         (pPotsLi->nPrevCallState != DEMO_RINGING)) {
        // Need to signal application phone is ringing
        if((pPotsLi->EventHandler)) {
          // User has setup a eventhandler
          DemoHwEvent nNewEvent;
          nNewEvent = HwEvent_ring;
          (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                  (DemoHwEvent *) &nNewEvent, 
                                  &(pPotsLi->hwParms),
                                  &potsLiNumber);
        }
      }

      DemoSetState(DEMO_STOP_RINGING, 
                   potsLiNumber, 
                   potsType,
                   DEMO_RINGING); // Check to see if SW in sync 
    break;

    case (DEMO_DTMF_TRANISTION):
      DemoLogf("FXO DtmfDialer[%d] Completed DTMF dialing of %d digits\n", 
               pEventData->m_nSourceId, 
               pEventData->m_nParam);

      // POTS LI FXO received an OFF HOOK event
      if(pPotsLi->bOffHook == OTX_FALSE) {
        DemoLogf("SW sync error PotsLi[%d] Should be set to Off-Hook\n", 
                 pEventData->m_nSourceId);
      }


      DemoSetState(DEMO_DTMF_TRANISTION, 
                   potsLiNumber, 
                   potsType,
                   DEMO_OFFHOOK); // Check to see if SW in sync

      if(pPotsLi->nLastCallState == DEMO_DTMF_TRANISTION) {
        // No additional state transition are expected
        DemoSetState(DEMO_NO_ACTION_NEEDED, 
                     potsLiNumber, 
                     potsType,
                     DEMO_NO_ACTION_NEEDED); // No error check needed

        // Send DEMO_LI_INIT_COMPLETE event
        if((pPotsLi->EventHandler)) {
          // User has setup a eventhandler
          DemoHwEvent nNewEvent;
          nNewEvent = HwEvent_init_completed;
          (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                  (DemoHwEvent *) &nNewEvent, 
                                  &(pPotsLi->hwParms),
                                  &potsLiNumber);
        }
      }
      else {
        // Need to wait for call to be answerred
      }
      
      
    break;

    case (DEMO_LI_INIT_COMPLETE):
      // Perform cleanup if needed
      DemoSetState(DEMO_LI_INIT_COMPLETE, 
                   potsLiNumber, 
                   potsType,
                   DEMO_NO_ACTION_NEEDED); // No error check needed
    break;

    case (DEMO_FAR_END_HANGUP):

      if(pPotsLi->bOffHook == OTX_TRUE) {
        // We are OFFHOOK so this could be an far end hang up or
        // the phone has been disconnected. In either case put the
        // LI into an onhook state.
        // Nothing more to do send event status
        DemoSetState(DEMO_STATE_CHANGE, 
                     potsLiNumber, 
                     potsType,
                     DEMO_NO_ACTION_NEEDED); // No check is needed
        if((pPotsLi->EventHandler)) {
          // User has setup an EventHandler, let them determine correct action.
          DemoHwEvent nNewEvent;
          nNewEvent = HwEvent_disconnect;
          (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                  (DemoHwEvent *) &nNewEvent, 
                                  &(pPotsLi->hwParms),
                                  &potsLiNumber);
        }
        else {
          // No event handler was setup. Perform the line termination
          DemoFxoTerminateCall(potsLiNumber, NULL);
        }
      }
      else {
        // The Li may not be connected to an active port. 
        // There should be a voltage or current.
        if((pPotsLi->nPrevCallState != DEMO_ONHOOK) &&
           (pPotsLi->nPrevCallState != DEMO_STATE_CHANGE)) {
          DemoSetState(DEMO_STATE_CHANGE, 
                       potsLiNumber, 
                       potsType,
                       DEMO_NO_ACTION_NEEDED); // No check is needed
          
          // Make sure we are in the on hook state.
          DemoFxoTerminateCall(potsLiNumber, NULL);

          DemoLogf("FXO[%d] May not be connected to an active line.\n",
                   potsLiNumber);
          if((pPotsLi->EventHandler)) {
            // User has setup an EventHandler
            DemoHwEvent nNewEvent;
            nNewEvent = HwEvent_disconnect;
            (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                    (DemoHwEvent *) &nNewEvent, 
                                    &(pPotsLi->hwParms),
                                    &potsLiNumber);
          }
        }
      }
    break;

    case (DEMO_TONE_DETECTED):
      // Just pass on the ones that are currently defined
      switch (pEventData->m_nParam) {
        case OTX_CST_CPT_DETECTOR_NO_TONE:        
          break;
        case OTX_CST_CPT_DETECTOR_DIAL_TONE:      
          break;
        case OTX_CST_CPT_DETECTOR_RING_TONE:      
          // Ring Tone
          if((pPotsLi->EventHandler)) {
            // User has setup an EventHandler
            DemoHwEvent nNewEvent;
            nNewEvent = HwEvent_ring_tone;
            (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                    (DemoHwEvent *) &nNewEvent, 
                                    &(pPotsLi->hwParms),
                                    &potsLiNumber);
          }
          break;
        case OTX_CST_CPT_DETECTOR_BUSY_TONE:
          // Busy Tone
          if((pPotsLi->EventHandler)) {
            // User has setup an EventHandler
            DemoHwEvent nNewEvent;
            nNewEvent = HwEvent_busy_tone;
            (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                    (DemoHwEvent *) &nNewEvent, 
                                    &(pPotsLi->hwParms),
                                    &potsLiNumber);
          }          
          break;
        case OTX_CST_CPT_DETECTOR_FASTBUSY_TONE:  
          break;
        case OTX_CST_CPT_DETECTOR_LONG_TONE:      
          break;
        case OTX_CST_CPT_DETECTOR_END_OF_TONE:    
          break;
        default: // Error
          DemoProcessDrvEvent(DEMO_EVENT_ERROR,        
                              DEMO_FXO_POTS_TYPE, 
                              pEventData->m_nSourceId,
                              pEventData);
          break;
        }
    break;

    case (DEMO_EVENT_ERROR):
      DemoLogf("FXO[%d] Error event\n", pEventData->m_nSourceId);

      // send error to EventHandler
      if((pPotsLi->EventHandler)) {
        // User has setup a eventhandler
        DemoHwEvent nNewEvent;
        nNewEvent = HwEvent_error;
        (pPotsLi->EventHandler)(&(pPotsLi->hwBase), 
                                (DemoHwEvent *) &nNewEvent, 
                                &(pPotsLi->hwParms),
                                &potsLiNumber);
      }

      // perform cleanup
      DemoSetState(DEMO_EVENT_ERROR, 
                   potsLiNumber, 
                   potsType,
                   DEMO_NO_ACTION_NEEDED); // No error check needed

    break;

    case (DEMO_NO_ACTION_NEEDED):
      // Perform cleanup if needed
      DemoSetState(DEMO_NO_ACTION_NEEDED, 
                   potsLiNumber, 
                   potsType,
                   DEMO_NO_ACTION_NEEDED); // No error check needed
    break;

    default:

      // We have a driver event That is not needed
    break;

  }
#endif

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);

}


OTX_RESULT DemoFxoGetLiState(OTX_UINT32 potsLiNumber, 
                             DemoDeviceCallState *nLiState,
                             OTX_RESULT *nlastRecordedError)
/*******************************************************************************

  @func
  DemoFxoGetLiState(OTX_UINT32 potsLiNumber, 
                    DemoDeviceCallState *nLiState,
                    OTX_RESULT *nlastRecordedError)

  This function is available to C++ application development.
  The function is used in C++ application to read the current call state
  "DemoDeviceCallState" of the POTS line. It also returns the last recoded 
  OTX driver error which is passed back to the caller using nlastRecordedError.

  @comm

  This function returns OTX_S_OK if successful or
  an OTX error code if the call failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoRejectCall: Pots Li#%d out of range", potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }
  // Check to see if the pointer is valid.
  if(nlastRecordedError) {
    // get the demo application results
    DemoGetLastFailure(nlastRecordedError);
  }

  return(result);
}


OTX_RESULT DemoFxoIsLiOffHook(OTX_UINT32 potsLiNumber, 
                              OTX_BOOL *nLiOffHook,
                              OTX_RESULT *nlastRecordedError)
/*******************************************************************************

  @func
  DemoFxoIsLiOffHook(OTX_UINT32 potsLiNumber, 
                     OTX_BOOL *nLiOffHook,
                     OTX_RESULT *nlastRecordedError)

  This function is available to C++ application development.
  The function is used in C++ application to returns OTX_TRUE if the Li
  is offhook or OTX_FALSE if the Li in onhook. The line state is passed 
  by reference using nLiOffHook. It also returns the last recoded OTX 
  driver error.

  @comm

  This function returns OTX_S_OK if successful or
  an OTX error code if the call failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoRejectCall: Pots Li#%d out of range", potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the hook state. This should be a valid (not NULL) pointer. 
  if(nLiOffHook) {
    *nLiOffHook = g_sPotsDevs[potsLiNumber].mFxoLi.bOffHook;
  }

  if(nlastRecordedError) {
    // get the demo application results
    DemoGetLastFailure(nlastRecordedError);
  }

  return(result);
}


OTX_RESULT DemoFxoAnswerCall(OTX_UINT32 potsLiNumber, 
                             DemoDeviceCallState *nLiState)
/*******************************************************************************

  @func
  DemoFxoAnswerCall(OTX_UINT32 potsLiNumber)

  This function is available to C++ application development.
  The function is used in C++ application to answer an incoming FXO call.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_INT32 timeoutCount = 0;

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoAnswerCall: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Set Active Pots Li Off-Hook ...
  DemoLogf("Pots Li#%d Off-hook\n", potsLiNumber);

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }
  // Check to see we need to set the last state.
  if(g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState == DEMO_NO_ACTION_NEEDED) {
    // Just waiting for the Off Hook event.
    g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_OFFHOOK;
  }
  g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_OFFHOOK;

  for(timeoutCount = 0; timeoutCount < DEMO_RETRY_COUNT; timeoutCount++) {
    result = OtxCstPotsOffHook(g_hLogicDevs.hPotsLi[potsLiNumber], 
                               DEMO_TASK_REF,   // OTX_TASK_REF
                               2000);           // OTX_TIME
    if ((OTX_RESULT_CODE(result) == OTX_E_BUSY)) {
      // Driver IO Request buffer is full. We need to retry this command.
      OsaThreadSleep(20); // IO buffer is Busy, give DSP time to proceess
    }
    else {
      // Command is in DSP queue
      g_nCmdTimeoutCnt += timeoutCount;
      timeoutCount = DEMO_LOOP_DONE; 
    }
  }
  if((timeoutCount >= DEMO_RETRY_COUNT) && 
     (timeoutCount < DEMO_LOOP_DONE)) {
    DemoLogf("DemoFxoAnswerCall: Timed out waiting on DSP IO request\n");

    g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_NO_ACTION_NEEDED;
    g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_NO_ACTION_NEEDED;
  }
  // Evaluate and save this result in the application log 
  DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoFxoTerminateCall(OTX_UINT32 potsLiNumber, 
                                DemoDeviceCallState *nLiState)
/*******************************************************************************

  @func
  DemoFxoTerminateCall(OTX_UINT32 potsLiNumber)

  This function is available to C++ application development.
  The function is used in C++ application to terminate an FXO call and return 
  the LI to an idle state waiting for the next call. This function performs 
  the sending of the IO command to the DSP, the ONHOOK event is not complete 
  until the DSP sends the driver event that the ONHOOK has been performed.  

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_INT32 timeoutCount = 0;

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoTerminateCall: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Set Active Pots Li On-Hook ...
  DemoLogf("Pots Li#%d On-hook\n", potsLiNumber);

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }

  g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_MAKE_ONHOOK;
  g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_ONHOOK;

  for(timeoutCount = 0; timeoutCount < DEMO_RETRY_COUNT; timeoutCount++) {
    result = OtxCstPotsOnHook(g_hLogicDevs.hPotsLi[potsLiNumber], 
                              DEMO_TASK_REF + 1,   // OTX_TASK_REF
                              2000);               // OTX_TIME
    if ((OTX_RESULT_CODE(result) == OTX_E_BUSY)) {
      // Driver IO Request buffer is full. We need to retry this command.
      OsaThreadSleep(20); // IO buffer is Busy, give DSP time to proceess
    } 
    else {
      // Command is in DSP queue
      g_nCmdTimeoutCnt += timeoutCount;
      timeoutCount = DEMO_LOOP_DONE; 
    }
  }
  if((timeoutCount >= DEMO_RETRY_COUNT) && 
     (timeoutCount < DEMO_LOOP_DONE)) {
    DemoLogf("DemoFxoTerminateCall: Timed out waiting on DSP IO request\n");

    g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_NO_ACTION_NEEDED;
    g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_NO_ACTION_NEEDED;
  }
  // Evaluate and save this result in the application log 
  DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoFxoMakeCall(OTX_UINT32 potsLiNumber,
                           DemoDeviceCallState *nLiState,
                           char *strDtmfDigits)
/*******************************************************************************

  @func
  DemoFxoMakeCall(OTX_UINT32 potsLiNumber)

  This function is available to C++ application development.
  The function is used in C++ application to make an outgoing FXO call. The
  calling function will need to supply a null terminate ASC character string 
  contains the DTMF digits. This string will be used in dialing the phone 
  number once the line has been setup.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_UINT32 bufferSize;


  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoMakeCall: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }

  if(g_sPotsDevs[potsLiNumber].mFxsLi.bOffHook == OTX_TRUE) {
    // Call started with LI OFF Hook
    DemoLogf("DemoFxoMakeCall: Pots Li#%d Is already OFF HOOK", potsLiNumber);
  }

  // Check input vaules and setup structure for call
  if(strDtmfDigits == NULL) {
    // Not a valid pointer no digits to dial 
    DemoLogf("Pots Li#%d DTMP string pointer not valid", potsLiNumber);
    // Just take the phone off hook
    g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_MAKE_OFFHOOK;
    g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_MAKE_OFFHOOK;
  }
  else {
    // Save off digits for use once the phone is off hook
    bufferSize = OsaStrLen(strDtmfDigits) + 1; // Include Null character
    if(bufferSize != 0) {
      g_sPotsDevs[potsLiNumber].mFxoLi.pDtmfStr = (char *) malloc(bufferSize);
      OsaStrNCpy( g_sPotsDevs[potsLiNumber].mFxoLi.pDtmfStr, // To 
                  strDtmfDigits,                             // From
                  bufferSize);                            

      g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_SEND_DTMF;
      g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_DTMF_TRANISTION;
    }
    else {
      // No data in buffer
      DemoLogf("DemoFxoMakeCall: Pots Li#%d DTMF string buffer empty", 
               potsLiNumber);
      result = OTX_E_INVALIDARG;
      return(result);
    }
  }

  // Need to setup the FXO line for dialing. 1st set the 
  // phone line to OFF-Hook
  result = DemoFxoAnswerCall(potsLiNumber, NULL);
  if ( OTX_FAILURE(result) ) {
    // No need to continue not able to take the phone Off-Hook
    return(result);
  }
  // Need to wait for the DSP Off Hook event

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoFxoRejectCall(OTX_UINT32 potsLiNumber, 
                             DemoDeviceCallState *nLiState)
/*******************************************************************************

  @func
  DemoFxoRejectCall(OTX_UINT32 potsLiNumber)

  This function is available to C++ application development.
  The function is used in C++ application to reject an incoming FXO call.

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code


  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoRejectCall: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}


OTX_RESULT DemoFxoSendDtmfDigits(OTX_UINT32 potsLiNumber, 
                                 DemoDeviceCallState *nLiState,
                                 char *strDtmfDigits )
/*******************************************************************************

  @func
  DemoFxoSendDtmfDigits(OTX_UINT32 potsLiNumber, 
                        DemoDeviceCallState *nLiState,
                        char *strDtmfDigits )

  This function is available to C++ application development.
  The function is used in C++ application to send a string of digits to an 
  active FXO call. 

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_HANDLE hHandle;
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_INT32 timeoutCount = 0;


  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoSendDtmfDigits: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  hHandle = g_hLogicDevs.hDtmfDialer[potsLiNumber];

  if(strlen(strDtmfDigits) == 0) {
    // LI number out of range
    DemoLogf("DemoFxoSendDtmfDigits: Li#%d No data in number buffer.", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }

  if(strDtmfDigits == NULL) {
    // Not a valid pointer
    DemoLogf("FXO Li#%d DTMF string pointer not valid", potsLiNumber);
    result = OTX_E_INVALIDARG;
  }
  else {

    DemoLogf("FXO Li#%d Dialing number %s\n", potsLiNumber, strDtmfDigits);

    g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_DIGIT_AVAILABLE;
    g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_DTMF_TRANISTION;

    // Dial a user specified number ...
    // Start Dialing DTMF number, 
    // Non-Blocking call, will receive Event when completed
    for(timeoutCount = 0; timeoutCount < DEMO_RETRY_COUNT; timeoutCount++) {
      result = OtxCstDtmfDial(hHandle, 
                              (unsigned char *)strDtmfDigits, 
                              strlen(strDtmfDigits), 
                              DEMO_TASK_REF,             // OTX_TASK_REF
                              OTX_TIME_INFINITY);        // OTX_TIME
      if ((OTX_RESULT_CODE(result) == OTX_E_BUSY)) {
        // Driver IO Request buffer is full. We need to retry this command.
        OsaThreadSleep(20); // IO buffer is Busy, give DSP time to proceess
      } 
      else {
        // Command is in DSP queue exit for loop
        g_nCmdTimeoutCnt += timeoutCount;
        timeoutCount = DEMO_LOOP_DONE; 
      }
    }
    if((timeoutCount >= DEMO_RETRY_COUNT) && 
       (timeoutCount < DEMO_LOOP_DONE)) {
      DemoLogf("\n");
      DemoLogf("DemoFxoSendDtmfDigits: Timed out waiting on DSP IO request\n");

      g_sPotsDevs[potsLiNumber].mFxoLi.nNextCallState = DEMO_NO_ACTION_NEEDED;
      g_sPotsDevs[potsLiNumber].mFxoLi.nLastCallState = DEMO_NO_ACTION_NEEDED;
    }
  }
  // Evaluate and save this result in the application log 
  DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}



OTX_RESULT DemoFxoGetCallerId(OTX_UINT32 potsLiNumber, 
                              DemoDeviceCallState *nLiState,
                              char *strCallerId)
/*******************************************************************************

  @func
  DemoFxoGetCallerId(OTX_UINT32 potsLiNumber, 
                     DemoDeviceCallState *nLiState,
                     char *strCallerId )

  This function is available to C++ application development.
  The function is used in C++ application to get the last valid caller ID

  @comm

  This function returns OTX_S_OK if the initialization was successful or
  an OTX error code if initialization failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_INT32 nWaitCnt;

  if(potsLiNumber >= DEMO_LI_MAX) {
    // LI number out of range
    DemoLogf("DemoFxoSendDtmfDigits: Pots Li#%d out of range", 
             potsLiNumber);
    result = OTX_E_INVALIDARG;
    return(result);
  }

  // Pass back the current call state. It may be useful to the caller
  // for error checking.
  if(nLiState) {
    *nLiState = g_sPotsDevs[potsLiNumber].mFxoLi.nCallState;
  }

  if(g_szCallerId[potsLiNumber][0] == 0) {
    // No caller ID was set. Maybe it is not time, wait for 2nd ring.
    for(nWaitCnt=10; nWaitCnt>1; nWaitCnt--){
      OsaThreadSleep(50); // in milliseconds 
      if(g_szCallerId[potsLiNumber][0] != 0) {
        nWaitCnt=0; // Exit the loop, found ID
      }
    }
  }
  // Give the user the string
  strCallerId = g_szCallerId[potsLiNumber];

  // Evaluate and save this result in the application log 
  DemoCheckRc(g_hLogicDevs.hPotsLi[potsLiNumber], result);

  // get the demo application results
  DemoGetLastFailure(&result);
  return(result);
}

#if 0
OTX_RESULT DemoFxoHaltBurstSendReceive(void)
/*******************************************************************************

  @func
  DemoFxoHaltBurstSendReceive(void)

  This function is available to C++ application development.
  The function is used in C++ application to stop sending and 
  receiving data using the burst device.

  @comm

  This function returns OTX_S_OK if successful or
  an OTX error code if failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code
  OTX_RESULT resultFunct = OTX_S_OK;  // Return code from fuction call
  OTX_UINT32  nTxBufSize;
  OTX_UINT32  nTxItemSize;
  OTX_UINT32  ui32;
  FILE        *pRxFile;
  FILE        *pTxFile;
  char nSilence;

  // Save off file pointers
  pRxFile = g_sBurstDevs.mBurstReceiver.pRxFile;
  pTxFile = g_sBurstDevs.mBurstSender.pTxFile;
  // Stop using file pointers in event thread
  g_sBurstDevs.mBurstReceiver.pRxFile = NULL;
  g_sBurstDevs.mBurstSender.pTxFile   = NULL;

  /*
  ** Set data in Burst buffer to silence
  */
  switch (g_demoEnv.law) {
    case OTX_DATA_FORMAT_COMPAND8_A_LAW:
      nSilence = (char) DEMO_A_LAW_SILENCE; // silence in a-law mode
      break;                         
    case OTX_DATA_FORMAT_COMPAND8_U_LAW:
      nSilence = (char) DEMO_U_LAW_SILENCE; // silence in u-law mode
      break;
    case OTX_DATA_FORMAT_UINT16:
      nSilence = 0; // silence in Linear data mode
      break;
  }

  // Prime the application transmit buffer with silence
  nTxItemSize = sizeof(g_sBurstDevs.mBurstSender.sqTxBuf[0]);
  nTxBufSize = sizeof(g_sBurstDevs.mBurstSender.sqTxBuf) / nTxItemSize;
  memset(&g_sBurstDevs.mBurstSender.sqTxBuf[0], 
         nSilence, 
         nTxBufSize);

  // Send a buffer to prevent get under run error during this transition
  ui32 = nTxBufSize;
  OtxBurstSendData(g_hPhysDevs.hBurst, 
                   0, 
                   g_sBurstDevs.mBurstSender.sqTxBuf, 
                   &ui32);

  // Disable DMA start signal for first DMA transfer
  resultFunct = 
    OtxDrvSetAttributeValueBool(g_hPhysDevs.hBurst, 
                                OTX_ATTR_BURST_DMA_RECEIVE_SIGNAL,  
                                OTX_FALSE);
  if(OTX_FAILURE(resultFunct)){
    result = resultFunct;
    DemoCheckRc(g_hPhysDevs.hBurst, result);
  }
  resultFunct = 
    OtxDrvSetAttributeValueBool(g_hPhysDevs.hBurst, 
                                OTX_ATTR_BURST_DMA_SEND_SIGNAL,  
                                OTX_FALSE); 
  if(OTX_FAILURE(resultFunct)){
    result = resultFunct;
    DemoCheckRc(g_hPhysDevs.hBurst, result);
  }

  g_sBurstDevs.mBurstReceiver.bActive = OTX_FALSE;
  g_sBurstDevs.mBurstSender.bActive   = OTX_FALSE;

  if(DemoIsBurstDeviceEnabled()) {
    // by disabling the Burst device, we stop the process of 
    // transferring data from the hardware to the driver via DMA.
    DemoLogf("Disable g_hPhysDevs.hBurst\n");
    resultFunct = 
      OtxDrvDisable(g_hPhysDevs.hBurst, OTX_TASK_SYNC, 5000L);
    if(OTX_FAILURE(resultFunct)){
      result = resultFunct;
      DemoCheckRc(g_hPhysDevs.hBurst, result);
    }
  } 

  // Now that burst is disabled close active files
  if (pRxFile) {
    DemoLogf("DemoBurstReceiver: Closing file\n");
    fclose(pRxFile);
  }

  if (pTxFile) {
    DemoLogf("mBurstSender: Closing file\n");
    fclose(pTxFile);
  }

  g_sBurstDevs.mBurstReceiver.bVerbose = OTX_FALSE;
  DemoLogf("Burst Receiver Verbose is now %s\n", 
           g_sBurstDevs.mBurstReceiver.bVerbose ? "ON" : "OFF");

  g_sBurstDevs.mBurstSender.bVerbose = OTX_FALSE;
  DemoLogf("Burst Sender Verbose is now %s\n", 
           g_sBurstDevs.mBurstSender.bVerbose ? "ON" : "OFF");

  return result;
}
#else
OTX_RESULT DemoFxoHaltBurstSendReceive(void)
/*******************************************************************************

  @func
  DemoFxoHaltBurstSendReceive(void)

  This function is available to C++ application development.
  The function is used in C++ application to stop sending and 
  receiving data using the burst device.

  @comm

  This function returns OTX_S_OK if successful or
  an OTX error code if failed.

*******************************************************************************/
{
  OTX_RESULT result = OTX_S_OK;  // OTX Standard Return Code

  return result;

}
#endif 

/*******************************************************************************

  @func

    Returns the state of the Burst device (enabled or disabled).

*******************************************************************************/
OTX_BOOL DemoIsBurstDeviceEnabled(void)
{
  OTX_RESULT result = OTX_S_OK;
  OtxDeviceStateE  eDevState;

  result = OtxDrvGetState(g_hPhysDevs.hBurst, &eDevState); 
  DemoCheckRc(g_hPhysDevs.hBurst, result);

  if (eDevState == OTX_DEVICE_WORKING) {
    return OTX_TRUE; // The burst device is enabled
  } else {
    return OTX_FALSE; // The burst device is not enabled
  }
}

#ifdef __cplusplus
}
#endif